@@ -17,7 +17,7 @@
  */
 #include "bstapp.h"
 
-#include "PKG_config.h"
+#include "topconfig.h"
 
 #include "bstactivatable.h"
 #include "bstsongshell.h"
@@ -54,6 +54,7 @@ static gboolean bst_app_can_activate            (BstActivatable *activatable,
                                                  gulong          action);
 static void     bst_app_request_update          (BstActivatable *activatable);
 static void     bst_app_update_activatable      (BstActivatable *activatable);
+static BstMenuConfig* demo_entries_create       (const gchar    *path);
 
 
 /* --- menus --- */
@@ -61,65 +62,82 @@ static gchar       *bst_app_factories_path = "<BstApp>";
 static BstMenuConfigEntry menubar_entries[] =
 {
 #define CB(action) (bst_app_menu_callback), (BST_ACTION_ ## action)
-  { "/_File",                           NULL,           NULL, 0,                        "<Branch>" },
-  { "/File/<<<<<<",                     NULL,           NULL, 0,                        "<Tearoff>" },
-  { "/File/_New",                       "<ctrl>N",      CB (NEW_PROJECT),               "<Item>" },
-  { "/File/_Open...",                   "<ctrl>O",      CB (OPEN_PROJECT),              "<Item>" },
-  { "/File/_Merge...",                  "<ctrl>M",      CB (MERGE_PROJECT),             "<Item>" },
-  { "/File/_Save",                      NULL,           CB (SAVE_PROJECT),              "<Item>" },
-  { "/File/Save _As...",                NULL,           CB (SAVE_PROJECT_AS),           "<Item>" },
-  { "/File/-----",                      NULL,           NULL, 0,                        "<Separator>" },
-  { "/File/_Dialogs",                   NULL,           NULL, 0,                        "<Branch>" },
-  { "/File/Dialogs/<<<<<<",             NULL,           NULL, 0,                        "<Tearoff>" },
-  { "/File/Dialogs/Procedure _Browser...", NULL,        CB (SHOW_PROC_BROWSER),         "<Item>" },
-  { "/File/Dialogs/_Preferences...",    NULL,           CB (SHOW_PREFERENCES),          "<Item>" },
-  { "/File/Dialogs/Device _Monitor...", NULL,           CB (SHOW_DEVICE_MONITOR),       "<Item>" },
-  { "/File/-----",                      NULL,           NULL, 0,                        "<Separator>" },
-  { "/File/_Close",                     "<ctrl>W",      CB (CLOSE_PROJECT),             "<Item>" },
-  { "/File/_Exit",                      "<ctrl>Q",      CB (EXIT),                      "<Item>" },
-  { "/_Project",                        NULL,           NULL, 0,                        "<Branch>" },
-  { "/Project/<<<<<<",                  NULL,           NULL, 0,                        "<Tearoff>" },
-  { "/Project/_Play",                   "<ctrl>P",      CB (START_PLAYBACK),            "<Item>" },
-  { "/Project/_Stop",                   "<ctrl>S",      CB (STOP_PLAYBACK),             "<Item>" },
-  { "/Project/-----",                   NULL,           NULL, 0,                        "<Separator>" },
-  { "/Project/New Song",                NULL,           CB (NEW_SONG),                  "<Item>" },
-  { "/Project/New Custom Synthesizer",  NULL,           CB (NEW_CSYNTH),                "<Item>" },
-  { "/Project/New MIDI Synthesizer",    NULL,           CB (NEW_MIDI_SYNTH),            "<Item>" },
-  { "/Project/Remove Synth",            NULL,           CB (REMOVE_SYNTH),              "<Item>" },
-  { "/Project/-----",                   NULL,           NULL, 0,                        "<Separator>" },
-  { "/Project/Rack Editor",             NULL,           CB (RACK_EDITOR),               "<Item>" },
-  { "/Project/-----",                   NULL,           NULL, 0,                        "<Separator>" },
-  { "/Project/Rebuild",                 NULL,           CB (REBUILD),                   "<Item>" },
-  { "/_Edit",                           NULL,           NULL, 0,                        "<Branch>" },
-  { "/Edit/<<<<<<",                     NULL,           NULL, 0,                        "<Tearoff>" },
-  { "/Edit/_Undo",                      "<ctrl>Z",      CB (UNDO),                      "<Item>" },
-  { "/Edit/_Redo",                      "<ctrl>R",      CB (REDO),                      "<Item>" },
-  { "/Edit/_Clear Undo",                NULL,           CB (CLEAR_UNDO),                "<Item>" },
-  { "/S_ong",                           NULL,           NULL, 0,                        "<Branch>" },
-  { "/Song/<<<<<<",                     NULL,           NULL, 0,                        "<Tearoff>" },
-  { "/Song/Add _Part",                  NULL,           CB (ADD_PART),                  "<Item>" },
-  { "/Song/Delete _Part",               NULL,           CB (DELETE_PART),               "<Item>" },
-  { "/Song/Add _Track",                 NULL,           CB (ADD_TRACK),                 "<Item>" },
-  { "/Song/Delete _Track",              NULL,           CB (DELETE_TRACK),              "<Item>" },
-  { "/_Waves",                          NULL,           NULL, 0,                        "<Branch>" },
-  { "/Waves/<<<<<<",                    NULL,           NULL, 0,                        "<Tearoff>" },
-  { "/Waves/_Load Wave...",             "",             CB (LOAD_WAVE),                 "<Item>" },
-  { "/Waves/Delete Wave",               NULL,           CB (DELETE_WAVE),               "<Item>" },
-  { "/Waves/_Edit Wave...",             "",             CB (EDIT_WAVE),                 "<Item>" },
-  { "/_Scripts",                        NULL,           NULL, 0,                        "<Branch>" },
-  // { "/S_Net",                        NULL,           NULL, 0,                        "<Branch>" },
-  // { "/SNet/<<<<<<",                  NULL,           NULL, 0,                        "<Tearoff>" },
-  // { "/SNet/_Test",                   "",             CB (NONE),                      "<Item>" },
+  { N_("/_File"),                            NULL,      NULL, 0,                        "<Branch>" },
+  {    "/File/<<<<<<",                       NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/File/_New"),                        "<ctrl>N", CB (NEW_PROJECT),               "<StockItem>", BST_STOCK_NEW },
+  { N_("/File/_Open..."),                    "<ctrl>O", CB (OPEN_PROJECT),              "<StockItem>", BST_STOCK_OPEN },
+  { N_("/File/_Merge..."),                   "<ctrl>M", CB (MERGE_PROJECT),             "<StockItem>", BST_STOCK_MERGE },
+  { N_("/File/_Close"),                      "<ctrl>W", CB (CLOSE_PROJECT),             "<StockItem>", BST_STOCK_CLOSE },
+  {    "/File/-----",                        NULL,      NULL, 0,                        "<Separator>" },
+  { N_("/File/_Save"),                       NULL,      CB (SAVE_PROJECT),              "<StockItem>", BST_STOCK_SAVE },
+  { N_("/File/Save _As..."),                 NULL,      CB (SAVE_PROJECT_AS),           "<StockItem>", BST_STOCK_SAVE_AS },
+  {    "/File/-----",                        NULL,      NULL, 0,                        "<Separator>" },
+  { N_("/File/Preferences..."),              NULL,      CB (SHOW_PREFERENCES),          "<StockItem>", BST_STOCK_PREFERENCES },
+  {    "/File/-----",                        NULL,      NULL, 0,                        "<Separator>" },
+  { N_("/File/_Quit"),                       "<ctrl>Q", CB (EXIT),                      "<StockItem>", BST_STOCK_QUIT },
+  { N_("/_Edit"),                            NULL,      NULL, 0,                        "<Branch>" },
+  {    "/Edit/<<<<<<",                       NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/Edit/_Undo"),                       "<ctrl>Z", CB (UNDO),                      "<StockItem>", BST_STOCK_UNDO },
+  { N_("/Edit/_Redo"),                       "<ctrl>R", CB (REDO),                      "<StockItem>", BST_STOCK_REDO },
+  { N_("/Edit/_Clear Undo"),                 NULL,      CB (CLEAR_UNDO),                "<StockItem>", BST_STOCK_CLEAR_UNDO },
+  {    "/Edit/-----",                        NULL,      NULL, 0,                        "<Separator>" },
+  { N_("/Edit/Preferences..."),              NULL,      CB (SHOW_PREFERENCES),          "<StockItem>", BST_STOCK_PREFERENCES },
+  { N_("/_View"),                            NULL,      NULL, 0,                        "<Branch>" },
+  {    "/View/<<<<<<",                       NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/View/Procedure _Browser"),          NULL,      CB (SHOW_PROC_BROWSER),         "<Item>" },
+  { N_("/View/Rack Editor"),                 NULL,      CB (RACK_EDITOR),               "<Item>" },
+  { N_("/View/Device _Monitor"),             NULL,      CB (SHOW_DEVICE_MONITOR),       "<Item>" },
+  {    "/View/-----",                        NULL,      NULL, 0,                        "<Separator>" },
+  { N_("/View/Preferences"),                 NULL,      CB (SHOW_PREFERENCES),          "<Item>" },
+  {    "/View/-----",                        NULL,      NULL, 0,                        "<Separator>" },
+  { N_("/View/Rebuild"),                     NULL,      CB (REBUILD),                   "<Item>" },
+  { N_("/_Project"),                         NULL,      NULL, 0,                        "<Branch>" },
+  {    "/Project/<<<<<<",                    NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/Project/_Play"),                    "<ctrl>P", CB (START_PLAYBACK),            "<StockItem>", BST_STOCK_PLAY },
+  { N_("/Project/_Stop"),                    "<ctrl>S", CB (STOP_PLAYBACK),             "<StockItem>", BST_STOCK_STOP },
+  {    "/Project/-----",                     NULL,      NULL, 0,                        "<Separator>" },
+  { N_("/Project/New Song"),                 NULL,      CB (NEW_SONG),                  "<StockItem>", BST_STOCK_NEW_SONG },
+  { N_("/Project/New Custom Synthesizer"),   NULL,      CB (NEW_CSYNTH),                "<StockItem>", BST_STOCK_NEW_CSYNTH },
+  { N_("/Project/New MIDI Synthesizer"),     NULL,      CB (NEW_MIDI_SYNTH),            "<StockItem>", BST_STOCK_NEW_MIDI_SYNTH },
+  { N_("/Project/Remove Song or Synthesizer"), NULL,    CB (REMOVE_SYNTH),              "<StockItem>", BST_STOCK_REMOVE_SYNTH },
+#if 0
+  { N_("/_Song"),                            NULL,      NULL, 0,                        "<Branch>" },
+  {    "/Song/<<<<<<",                       NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/Song/Add _Part"),                   NULL,      CB (ADD_PART),                  "<Item>" },
+  { N_("/Song/Delete _Part"),                NULL,      CB (DELETE_PART),               "<Item>" },
+  { N_("/Song/Add _Track"),                  NULL,      CB (ADD_TRACK),                 "<Item>" },
+  { N_("/Song/_Delete Track"),               NULL,      CB (DELETE_TRACK),              "<Item>" },
+  { N_("/_Synth"),                           NULL,      NULL, 0,                        "<Branch>" },
+  {    "/Synth/<<<<<<",                      NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/Synth/_Test"),                      NULL,      CB (NONE),                      "<Item>" },
+  { N_("/Wave_s"),                           NULL,      NULL, 0,                        "<Branch>" },
+  {    "/Waves/<<<<<<",                      NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/Waves/_Load Wave..."),              NULL,      CB (LOAD_WAVE),                 "<Item>" },
+  { N_("/Waves/Delete Wave"),                NULL,      CB (DELETE_WAVE),               "<Item>" },
+  { N_("/Waves/_Edit Wave..."),              NULL,      CB (EDIT_WAVE),                 "<Item>" },
+#endif
+  { N_("/_Synthesizers"),                    NULL,      NULL, 0,                        "<Branch>" },
+  {    "/Synthesizers/<<<<<<",               NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/Synthesizers/Load _Effect"),        NULL,      CB (MERGE_EFFECT),              "<Item>" },
+  { N_("/Synthesizers/Load _Instrument"),    NULL,      CB (MERGE_INSTRUMENT),          "<Item>" },
+  { N_("/Synthesizers/Save As Effect"),      NULL,      CB (SAVE_EFFECT),               "<Item>" },
+  { N_("/Synthesizers/Save As Instrument"),  NULL,      CB (SAVE_INSTRUMENT),           "<Item>" },
+  { N_("/_Tools"),                           NULL,      NULL, 0,                        "<Branch>" },
+  { N_("/Tools/_Song"),                      NULL,      NULL, 0,                        "<Branch>" },
+  { N_("/Tools/_Synth"),                     NULL,      NULL, 0,                        "<Branch>" },
+  { N_("/Tools/Wave_s"),                     NULL,      NULL, 0,                        "<Branch>" },
+  { N_("/_Demo"),                            NULL,      NULL, 0,                        "<Branch>" },
+  {    "/Demo/<<<<<<",                       NULL,      NULL, 0,                        "<Tearoff>" },
 };
 static BstMenuConfigEntry menubar_help_entries[] = {
-  { "/_Help",                           NULL,           NULL, 0,                        "<LastBranch>" },
-  { "/Help/<<<<<<",                     NULL,           NULL, 0,                        "<Tearoff>" },
-  { "/Help/_Release Notes...",          NULL,           CB (HELP_RELEASE_NOTES),        "<Item>" },
-  { "/Help/Quick Start...",             NULL,           CB (HELP_QUICK_START),          "<Item>" },
-  { "/Help/_FAQ...",                    NULL,           CB (HELP_FAQ),                  "<Item>" },
-  { "/Help/Development/GSL Engine...",  NULL,           CB (HELP_GSL_PLAN),             "<Item>" },
-  { "/Help/-----",                      NULL,           NULL, 0,                        "<Separator>" },
-  { "/Help/_About...",                  NULL,           CB (HELP_ABOUT),                "<Item>" },
+  { N_("/_Help"),                            NULL,      NULL, 0,                        "<LastBranch>" },
+  {    "/Help/<<<<<<",                       NULL,      NULL, 0,                        "<Tearoff>" },
+  { N_("/Help/_Release Notes..."),           NULL,      CB (HELP_RELEASE_NOTES),        "<StockItem>", BST_STOCK_DOC_NEWS },
+  { N_("/Help/Quick Start..."),              NULL,      CB (HELP_QUICK_START),          "<StockItem>", BST_STOCK_HELP },
+  { N_("/Help/_FAQ..."),                     NULL,      CB (HELP_FAQ),                  "<StockItem>", BST_STOCK_DOC_FAQ },
+  { N_("/Help/Development/GSL Engine..."), NULL,        CB (HELP_GSL_PLAN),             "<StockItem>", BST_STOCK_DOC_DEVEL },
+  {    "/Help/-----",                        NULL,      NULL, 0,                        "<Separator>" },
+  { N_("/Help/_About..."),                   NULL,      CB (HELP_ABOUT),                "<StockItem>", BST_STOCK_ABOUT },
 #undef  CB
 };
 
@@ -227,7 +245,7 @@ bst_app_init (BstApp *app)
 
   /* setup the menu bar
    */
-  factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, bst_app_factories_path, NULL);
+  factory = bst_item_factory_new (GTK_TYPE_MENU_BAR, bst_app_factories_path);
   gtk_window_add_accel_group (window, factory->accel_group);
   gtk_container_add_with_properties (GTK_CONTAINER (app->main_vbox),
                                      factory->widget,
@@ -241,15 +259,44 @@ bst_app_init (BstApp *app)
                             (GtkDestroyNotify) gtk_object_unref);
   /* standard entries */
   m1 = bst_menu_config_from_entries (G_N_ELEMENTS (menubar_entries), menubar_entries);
-  /* script entries */
-  cseq = bse_categories_match_typed ("/Scripts/*", "BseProcedure");
-  m2 = bst_menu_config_from_cats (cseq, bst_app_run_script_proc, FALSE);
+  /* Project utilities */
+  cseq = bse_categories_match ("/Project/*");
+  m2 = bst_menu_config_from_cats (cseq, bst_app_run_script_proc, 1, "/Tools/", BST_STOCK_EXECUTE);
+  bst_menu_config_sort (m2);
+  m1 = bst_menu_config_merge (m1, m2);
+  /* Song utilities */
+  cseq = bse_categories_match ("/Song/*");
+  m2 = bst_menu_config_from_cats (cseq, bst_app_run_script_proc, 1, "/Tools/Song/", BST_STOCK_EXECUTE);
+  bst_menu_config_sort (m2);
+  m1 = bst_menu_config_merge (m1, m2);
+  /* CSynth utilities */
+  cseq = bse_categories_match ("/CSynth/*");
+  m2 = bst_menu_config_from_cats (cseq, bst_app_run_script_proc, 1, "/Tools/Synth/", BST_STOCK_EXECUTE);
+  bst_menu_config_sort (m2);
+  m1 = bst_menu_config_merge (m1, m2);
+  /* SNet utilities */
+  cseq = bse_categories_match ("/SNet/*");
+  m2 = bst_menu_config_from_cats (cseq, bst_app_run_script_proc, 1, "/Tools/Synth/", BST_STOCK_EXECUTE);
+  bst_menu_config_sort (m2);
+  m1 = bst_menu_config_merge (m1, m2);
+#if 0
+  /* Wave utilities */
+  cseq = bse_categories_match ("/Wave/*");
+  m2 = bst_menu_config_from_cats (cseq, bst_app_run_script_proc, 1, "/Tools/Waves/", BST_STOCK_EXECUTE);
+  bst_menu_config_sort (m2);
+  m1 = bst_menu_config_merge (m1, m2);
+#endif
+  /* WaveRepo utilities */
+  cseq = bse_categories_match ("/WaveRepo/*");
+  m2 = bst_menu_config_from_cats (cseq, bst_app_run_script_proc, 1, "/Tools/Waves/", BST_STOCK_EXECUTE);
   bst_menu_config_sort (m2);
-  /* merge and sort up */
   m1 = bst_menu_config_merge (m1, m2);
   /* add help entries */
   m2 = bst_menu_config_from_entries (G_N_ELEMENTS (menubar_help_entries), menubar_help_entries);
   m1 = bst_menu_config_merge (m1, m2);
+  /* add demo songs */
+  m2 = demo_entries_create ("/Demo");
+  m1 = bst_menu_config_merge (m1, m2);
   /* and create menu items */
   bst_menu_config_create_items (m1, factory, GTK_WIDGET (app));
   bst_menu_config_free (m1);
@@ -539,6 +586,82 @@ rebuild_super_shell (BstSuperShell *super_shell)
   bse_item_unuse (proxy);
 }
 
+typedef struct {
+  gchar *file;
+  gchar *name;
+} DemoEntry;
+static DemoEntry *demo_entries = NULL;
+static guint     n_demo_entries = 0;
+
+static void
+demo_entries_setup (void)
+{
+  if (!demo_entries)
+    {
+      SfiRing *files = sfi_file_crawler_list_files (bse_server_get_demo_path (BSE_SERVER), "*.bse", 0);
+      while (files)
+        {
+          gchar *file = sfi_ring_pop_head (&files);
+          gchar *name = bst_file_scan_song_name (file);
+          if (name && n_demo_entries < 0xffff)
+            {
+              guint i = n_demo_entries++;
+              demo_entries = g_renew (DemoEntry, demo_entries, n_demo_entries);
+              demo_entries[i].file = file;
+              demo_entries[i].name = name;
+            }
+          else
+            {
+              g_free (name);
+              g_free (file);
+            }
+        }
+    }
+}
+
+static void
+demo_play_song (GtkWidget   *owner,
+                gulong       callback_action,
+                gpointer     popup_data)
+{
+  const gchar *file_name = demo_entries[callback_action - BST_ACTION_LOAD_DEMO_0000].file;
+  SfiProxy project = bse_server_use_new_project (BSE_SERVER, file_name);
+  BseErrorType error = bse_project_restore_from_file (project, file_name);
+  if (error)
+    bst_status_eprintf (error, _("Opening project `%s'"), file_name);
+  else
+    {
+      BstApp *app;
+      bse_project_get_wave_repo (project);
+      app = bst_app_new (project);
+      gxk_status_window_push (app);
+      bst_status_eprintf (error, _("Opening project `%s'"), file_name);
+      gxk_status_window_pop ();
+      gxk_idle_show_widget (GTK_WIDGET (app));
+    }
+  bse_item_unuse (project);
+}
+
+static BstMenuConfig*
+demo_entries_create (const gchar *path)
+{
+  BstMenuConfig *m1 = bst_menu_config_from_entries (0, NULL);
+  guint i;
+  demo_entries_setup ();
+  for (i = 0; i < n_demo_entries; i++)
+    {
+      BstMenuConfigEntry entry = { 0, };
+      entry.path = g_strconcat (path, "/", demo_entries[i].name, NULL);
+      entry.callback = demo_play_song;
+      entry.callback_action = BST_ACTION_LOAD_DEMO_0000 + i;
+      entry.item_type = "<StockItem>";
+      entry.extra_data = BST_STOCK_NOTE_ICON;
+      m1 = bst_menu_config_merge (bst_menu_config_from_entries (1, &entry), m1);
+    }
+  bst_menu_config_sort (m1);
+  return m1;
+}
+
 static void
 bst_app_run_script_proc (GtkWidget *widget,
                          gulong     category_id,
@@ -546,9 +669,27 @@ bst_app_run_script_proc (GtkWidget *widget,
 {
   BstApp *self = BST_APP (widget);
   BseCategory *cat = bse_category_from_id (category_id);
+  GtkWidget *shell = bst_app_get_current_shell (self);
+  SfiProxy super = shell ? BST_SUPER_SHELL (shell)->super : 0;
+  const gchar *song = "", *wave_repo = "", *snet = "", *csynth = "";
+
+  if (BST_IS_SONG_SHELL (shell) && super)
+    song = "song";
+  else if (BST_IS_WAVE_REPO_SHELL (shell) && super)
+    wave_repo = "wrepo";
+  else if (BST_IS_SNET_SHELL (shell) && super)
+    {
+      snet = "snet";
+      if (BSE_IS_CSYNTH (super))
+        csynth = "csynth";
+    }
 
   bst_procedure_exec_auto (cat->type,
                            "project", SFI_TYPE_PROXY, self->project,
+                           song, SFI_TYPE_PROXY, super,
+                           wave_repo, SFI_TYPE_PROXY, super,
+                           snet, SFI_TYPE_PROXY, super,
+                           csynth, SFI_TYPE_PROXY, super,
                            NULL);
 }
 
@@ -577,6 +718,19 @@ bst_app_activate (BstActivatable *activatable,
     {
       SfiProxy proxy;
       GtkWidget *any;
+    case BST_ACTION_EXIT:
+      if (bst_app_class)
+        {
+          GSList *slist, *free_slist = g_slist_copy (bst_app_class->apps);
+
+          for (slist = free_slist; slist; slist = slist->next)
+            gxk_toplevel_delete (slist->data);
+          g_slist_free (free_slist);
+        }
+      break;
+    case BST_ACTION_CLOSE_PROJECT:
+      gxk_toplevel_delete (widget);
+      break;
     case BST_ACTION_NEW_PROJECT:
       if (1)
         {
@@ -600,18 +754,17 @@ bst_app_activate (BstActivatable *activatable,
     case BST_ACTION_SAVE_PROJECT_AS:
       bst_file_dialog_popup_save_project (self, self->project);
       break;
-    case BST_ACTION_CLOSE_PROJECT:
-      gxk_toplevel_delete (widget);
+    case BST_ACTION_MERGE_EFFECT:
+      bst_file_dialog_popup_merge_effect (self, self->project);
       break;
-    case BST_ACTION_EXIT:
-      if (bst_app_class)
-        {
-          GSList *slist, *free_slist = g_slist_copy (bst_app_class->apps);
-
-          for (slist = free_slist; slist; slist = slist->next)
-            gxk_toplevel_delete (slist->data);
-          g_slist_free (free_slist);
-        }
+    case BST_ACTION_MERGE_INSTRUMENT:
+      bst_file_dialog_popup_merge_instrument (self, self->project);
+      break;
+    case BST_ACTION_SAVE_EFFECT:
+      bst_file_dialog_popup_save_effect (self, self->project, bst_app_get_current_super (self));
+      break;
+    case BST_ACTION_SAVE_INSTRUMENT:
+      bst_file_dialog_popup_save_instrument (self, self->project, bst_app_get_current_super (self));
       break;
     case BST_ACTION_NEW_SONG:
       proxy = bse_project_create_song (self->project, NULL);
@@ -654,7 +807,7 @@ bst_app_activate (BstActivatable *activatable,
           self->rack_dialog = gxk_dialog_new (&self->rack_dialog,
                                               GTK_OBJECT (self),
                                               0, // FIXME: undo Edit when hide && GXK_DIALOG_HIDE_ON_DELETE
-                                              "Rack editor",
+                                              _("Rack editor"),
                                               self->rack_editor);
         }
       gxk_widget_showraise (self->rack_dialog);
@@ -668,7 +821,7 @@ bst_app_activate (BstActivatable *activatable,
           bst_preferences = gxk_dialog_new (&bst_preferences,
                                             NULL,
                                             GXK_DIALOG_HIDE_ON_DELETE,
-                                            "Preferences",
+                                            _("Preferences"),
                                             widget);
           bst_preferences_create_buttons (BST_PREFERENCES (widget), GXK_DIALOG (bst_preferences));
         }
@@ -676,6 +829,16 @@ bst_app_activate (BstActivatable *activatable,
         bst_preferences_revert (BST_PREFERENCES (gxk_dialog_get_child (GXK_DIALOG (bst_preferences))));
       gxk_widget_showraise (bst_preferences);
       break;
+    case BST_ACTION_SHOW_DEVICE_MONITOR:
+      any = g_object_new (BST_TYPE_SERVER_MONITOR, NULL);
+      gtk_widget_show (any);
+      any = gxk_dialog_new (NULL,
+                            GTK_OBJECT (self),
+                            GXK_DIALOG_DELETE_BUTTON, // FIXME: GXK_DIALOG_HIDE_ON_DELETE && save dialog pointer
+                            _("Device Monitor"),
+                            any);
+      gtk_widget_show (any);
+      break;
     case BST_ACTION_SHOW_PROC_BROWSER:
 #if 0 // FIXME
       if (!bst_proc_browser)
@@ -687,22 +850,12 @@ bst_app_activate (BstActivatable *activatable,
           bst_proc_browser = gxk_dialog_new (&bst_proc_browser,
                                              NULL,
                                              GXK_DIALOG_HIDE_ON_DELETE,
-                                             "Procedure Browser",
+                                             _("Procedure Browser"),
                                              widget);
           bst_proc_browser_create_buttons (BST_PROC_BROWSER (widget), GXK_DIALOG (bst_proc_browser));
         }
       gxk_widget_showraise (bst_proc_browser);
 #endif
-      break;
-    case BST_ACTION_SHOW_DEVICE_MONITOR:
-      any = g_object_new (BST_TYPE_SERVER_MONITOR, NULL);
-      gtk_widget_show (any);
-      any = gxk_dialog_new (NULL,
-                            GTK_OBJECT (self),
-                            GXK_DIALOG_DELETE_BUTTON, // FIXME: GXK_DIALOG_HIDE_ON_DELETE && save dialog pointer
-                            "Device Monitor",
-                            any);
-      gtk_widget_show (any);
       sfi_alloc_report ();
 #if 0 // FIXME
       {
@@ -754,7 +907,7 @@ bst_app_activate (BstActivatable *activatable,
       goto HELP_DIALOG;
     case BST_ACTION_HELP_RELEASE_NOTES:
       help_file = g_strconcat (BST_PATH_DOCS, "/release-notes.markup", NULL);
-      help_title = g_strdup_printf ("BEAST-%s Release Notes", BST_VERSION);
+      help_title = g_strdup_printf (_("BEAST-%s Release Notes"), BST_VERSION);
       goto HELP_DIALOG;
     HELP_DIALOG:
       if (!bst_help_dialogs[action - BST_ACTION_HELP_FIRST])
@@ -836,6 +989,13 @@ bst_app_can_activate (BstActivatable *activatable,
     case BST_ACTION_SHOW_PROC_BROWSER:
     case BST_ACTION_SHOW_DEVICE_MONITOR:
       return TRUE;
+    case BST_ACTION_MERGE_EFFECT:
+    case BST_ACTION_MERGE_INSTRUMENT:
+      return !bse_project_is_active (self->project);
+    case BST_ACTION_SAVE_EFFECT:
+    case BST_ACTION_SAVE_INSTRUMENT:
+      super = bst_app_get_current_super (self);
+      return BSE_IS_CSYNTH (super) && !bse_project_is_active (self->project);
       // case BST_OP_HELP_ABOUT:
     case BST_ACTION_HELP_FAQ:
     case BST_ACTION_HELP_GSL_PLAN:
@@ -884,12 +1044,19 @@ bst_app_update_activatable (BstActivatable *activatable)
     return;
 
   /* update menu bar menu items */
-  widget = gxk_item_factory_get_item (factory, "/Song");
-  if (widget)
-    gtk_widget_set_sensitive (widget, BST_IS_SONG_SHELL (shell));
-  widget = gxk_item_factory_get_item (factory, "/Waves");
-  if (widget)
-    gtk_widget_set_sensitive (widget, BST_IS_WAVE_REPO_SHELL (shell));
+  gxk_item_factory_sensitize (factory, "/Song", BST_IS_SONG_SHELL (shell));
+  gxk_item_factory_sensitize (factory, "/Tools/Song", BST_IS_SONG_SHELL (shell));
+  gxk_item_factory_sensitize (factory, "/Synth", BST_IS_SNET_SHELL (shell));
+  gxk_item_factory_sensitize (factory, "/Tools/Synth", BST_IS_SNET_SHELL (shell));
+  gxk_item_factory_sensitize (factory, "/Waves", BST_IS_WAVE_REPO_SHELL (shell));
+  gxk_item_factory_sensitize (factory, "/Tools/Waves", BST_IS_WAVE_REPO_SHELL (shell));
+
+  /* special adjustments */
+  widget = gxk_item_factory_get_item (factory, "/Edit/Clear Undo");
+  if (widget && BST_DVL_HINTS)
+    gtk_widget_show (widget);
+  else if (widget && !BST_DVL_HINTS)
+    gtk_widget_hide (widget);
 
   /* update app actions */
   for (i = 0; i < G_N_ELEMENTS (menubar_entries); i++)
