@@ -82,6 +82,12 @@ enum {
   BST_ACTION_SAVE_PROJECT,
   BST_ACTION_SAVE_PROJECT_AS,
   BST_ACTION_CLOSE_PROJECT,
+  BST_ACTION_EXIT,
+  /* synthesizer */
+  BST_ACTION_MERGE_EFFECT,
+  BST_ACTION_MERGE_INSTRUMENT,
+  BST_ACTION_SAVE_EFFECT,
+  BST_ACTION_SAVE_INSTRUMENT,
   /* handling supers */
   BST_ACTION_NEW_SONG,
   BST_ACTION_NEW_CSYNTH,
@@ -95,8 +101,9 @@ enum {
   BST_ACTION_CLEAR_UNDO,
   BST_ACTION_UNDO,
   BST_ACTION_REDO,
-  /* and shutdown */
-  BST_ACTION_EXIT,
+  /* loading demo songs */
+  BST_ACTION_LOAD_DEMO_0000,
+  BST_ACTION_LOAD_DEMO_ffff = BST_ACTION_LOAD_DEMO_0000 + 0xffff,
   BST_ACTION_APP_LAST
 };
 
