@@ -174,7 +174,7 @@ clink_view_update (BstCanvasLink *clink,
        */
       iname = clink->icsource ? bse_item_get_name_or_type (clink->icsource->source) : "<???>";
       oname = clink->ocsource ? bse_item_get_name_or_type (clink->ocsource->source) : "<???>";
-      string = g_strconcat ("Module Link: ", iname, " <=> ", oname, NULL);
+      string = g_strconcat (_("Module Link: "), iname, " <=> ", oname, NULL);
       gxk_dialog_set_title (GXK_DIALOG (clink->link_view), string);
       g_free (string);
 
@@ -230,7 +230,7 @@ bst_canvas_link_popup_view (BstCanvasLink *clink)
 				       gtk_widget_new (GTK_TYPE_FRAME,
 						       "visible", TRUE,
 						       "border_width", 5,
-						       "label", "Module link",
+						       "label", _("Module link"),
 						       "child", gxk_scroll_text_create (GXK_SCROLL_TEXT_WIDGET_LOOK, NULL),
 						       NULL));
   clink_view_update (clink, TRUE);
