@@ -19,6 +19,7 @@
 #define __BST_DEFS_H__
 
 #include <gxk/gxk.h>
+#include <libintl.h>
 #include "glewidgets.h"
 #include "bstzoomedwindow.h"
 #include "bstfreeradiobutton.h"
@@ -53,6 +54,25 @@ typedef enum {
   BST_QUANTIZE_TACT		= 65535
 } BstQuantizationType;
 
+typedef enum /*< skip >*/
+{
+  BST_GENERIC_ROLL_TOOL_NONE,
+  /* choose IDs that are unlikely to clash with category IDs */
+  BST_GENERIC_ROLL_TOOL_INSERT            = G_MAXINT - 1000,
+  BST_GENERIC_ROLL_TOOL_RESIZE,
+  BST_GENERIC_ROLL_TOOL_LINK,
+  BST_GENERIC_ROLL_TOOL_RENAME,
+  BST_GENERIC_ROLL_TOOL_ALIGN,
+  BST_GENERIC_ROLL_TOOL_MOVE,
+  BST_GENERIC_ROLL_TOOL_DELETE,
+  BST_GENERIC_ROLL_TOOL_SELECT,
+  BST_GENERIC_ROLL_TOOL_VSELECT,
+  BST_GENERIC_ROLL_TOOL_EDITOR,
+  BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER,
+  BST_GENERIC_ROLL_TOOL_MOVE_TICK_LEFT,
+  BST_GENERIC_ROLL_TOOL_MOVE_TICK_RIGHT,
+} BstGenericRollTool;
+
 
 /* --- constants & defines --- */
 #define	BST_TAG_DIAMETER	  (20)
@@ -79,9 +99,12 @@ typedef enum {
 
 /* --- i18n and gettext helpers --- */
 #define CKEY(x) x
-/* allow gettext-ization */
-#define	_N(x)	x
-#define	_(x)	x
+#define _(str)		dgettext (NULL, str)
+#ifdef gettext_noop
+#  define N_(str)	gettext_noop (str)
+#else
+#  define N_(str)	(str)
+#endif
 
 
 /* --- internal stuff --- */
