@@ -2,6 +2,28 @@
 /* Generated data (by glib-mkenums) */
 
 
+/* --- bstfiledialog.h --- */
+#include	"bstfiledialog.h"
+/* BstFileDialogMode
+ */
+static GEnumValue bst_file_dialog_mode_values[] = {
+  { BST_FILE_DIALOG_OPEN_PROJECT, "BST_FILE_DIALOG_OPEN_PROJECT", "open-project" },
+  { BST_FILE_DIALOG_MERGE_PROJECT, "BST_FILE_DIALOG_MERGE_PROJECT", "merge-project" },
+  { BST_FILE_DIALOG_SAVE_PROJECT, "BST_FILE_DIALOG_SAVE_PROJECT", "save-project" },
+  { BST_FILE_DIALOG_SELECT_DIR, "BST_FILE_DIALOG_SELECT_DIR", "select-dir" },
+  { BST_FILE_DIALOG_LOAD_WAVE, "BST_FILE_DIALOG_LOAD_WAVE", "load-wave" },
+  { BST_FILE_DIALOG_LOAD_WAVE_LIB, "BST_FILE_DIALOG_LOAD_WAVE_LIB", "load-wave-lib" },
+  { BST_FILE_DIALOG_MERGE_EFFECT, "BST_FILE_DIALOG_MERGE_EFFECT", "merge-effect" },
+  { BST_FILE_DIALOG_MERGE_INSTRUMENT, "BST_FILE_DIALOG_MERGE_INSTRUMENT", "merge-instrument" },
+  { BST_FILE_DIALOG_SAVE_EFFECT, "BST_FILE_DIALOG_SAVE_EFFECT", "save-effect" },
+  { BST_FILE_DIALOG_SAVE_INSTRUMENT, "BST_FILE_DIALOG_SAVE_INSTRUMENT", "save-instrument" },
+  { BST_FILE_DIALOG_MODE_MASK, "BST_FILE_DIALOG_MODE_MASK", "mode-mask" },
+  { BST_FILE_DIALOG_ALLOW_DIRS, "BST_FILE_DIALOG_ALLOW_DIRS", "allow-dirs" },
+  { BST_FILE_DIALOG_FLAG_MASK, "BST_FILE_DIALOG_FLAG_MASK", "flag-mask" },
+  { 0, NULL, NULL }
+};
+
+
 /* --- bstmarker.h --- */
 #include	"bstmarker.h"
 /* BstMarkerType
@@ -78,46 +100,26 @@ static GFlagsValue bst_radio_tools_flags_values[] = {
 };
 
 
+/* --- bstsegment.h --- */
+#include	"bstsegment.h"
+/* BstSegmentType
+ */
+static GEnumValue bst_segment_type_values[] = {
+  { BST_SEGMENT_LINE, "BST_SEGMENT_LINE", "line" },
+  { 0, NULL, NULL }
+};
+
+
 /* --- bstdefs.h --- */
 #include	"bstdefs.h"
-/* BstOps
+/* BstActionRegions
  */
-static GEnumValue bst_ops_values[] = {
-  { BST_OP_NONE, "BST_OP_NONE", "none" },
-  { BST_OP_PROJECT_NEW, "BST_OP_PROJECT_NEW", "project-new" },
-  { BST_OP_PROJECT_OPEN, "BST_OP_PROJECT_OPEN", "project-open" },
-  { BST_OP_PROJECT_MERGE, "BST_OP_PROJECT_MERGE", "project-merge" },
-  { BST_OP_PROJECT_SAVE, "BST_OP_PROJECT_SAVE", "project-save" },
-  { BST_OP_PROJECT_SAVE_AS, "BST_OP_PROJECT_SAVE_AS", "project-save-as" },
-  { BST_OP_PROJECT_NEW_SONG, "BST_OP_PROJECT_NEW_SONG", "project-new-song" },
-  { BST_OP_PROJECT_NEW_SNET, "BST_OP_PROJECT_NEW_SNET", "project-new-snet" },
-  { BST_OP_PROJECT_NEW_MIDI_SYNTH, "BST_OP_PROJECT_NEW_MIDI_SYNTH", "project-new-midi-synth" },
-  { BST_OP_PROJECT_CLOSE, "BST_OP_PROJECT_CLOSE", "project-close" },
-  { BST_OP_PROJECT_PLAY, "BST_OP_PROJECT_PLAY", "project-play" },
-  { BST_OP_PROJECT_STOP, "BST_OP_PROJECT_STOP", "project-stop" },
-  { BST_OP_PROJECT_RACK_EDITOR, "BST_OP_PROJECT_RACK_EDITOR", "project-rack-editor" },
-  { BST_OP_DIALOG_PREFERENCES, "BST_OP_DIALOG_PREFERENCES", "dialog-preferences" },
-  { BST_OP_DIALOG_PROC_BROWSER, "BST_OP_DIALOG_PROC_BROWSER", "dialog-proc-browser" },
-  { BST_OP_DIALOG_DEVICE_MONITOR, "BST_OP_DIALOG_DEVICE_MONITOR", "dialog-device-monitor" },
-  { BST_OP_REBUILD, "BST_OP_REBUILD", "rebuild" },
-  { BST_OP_PART_ADD, "BST_OP_PART_ADD", "part-add" },
-  { BST_OP_PART_DELETE, "BST_OP_PART_DELETE", "part-delete" },
-  { BST_OP_PART_EDITOR, "BST_OP_PART_EDITOR", "part-editor" },
-  { BST_OP_WAVE_LOAD, "BST_OP_WAVE_LOAD", "wave-load" },
-  { BST_OP_WAVE_DELETE, "BST_OP_WAVE_DELETE", "wave-delete" },
-  { BST_OP_WAVE_EDITOR, "BST_OP_WAVE_EDITOR", "wave-editor" },
-  { BST_OP_TRACK_ADD, "BST_OP_TRACK_ADD", "track-add" },
-  { BST_OP_TRACK_DELETE, "BST_OP_TRACK_DELETE", "track-delete" },
-  { BST_OP_UNDO_LAST, "BST_OP_UNDO_LAST", "undo-last" },
-  { BST_OP_REDO_LAST, "BST_OP_REDO_LAST", "redo-last" },
-  { BST_OP_EXIT, "BST_OP_EXIT", "exit" },
-  { BST_OP_HELP_FAQ, "BST_OP_HELP_FAQ", "help-faq" },
-  { BST_OP_HELP_KEYTABLE, "BST_OP_HELP_KEYTABLE", "help-keytable" },
-  { BST_OP_HELP_RELEASE_NOTES, "BST_OP_HELP_RELEASE_NOTES", "help-release-notes" },
-  { BST_OP_HELP_GSL_PLAN, "BST_OP_HELP_GSL_PLAN", "help-gsl-plan" },
-  { BST_OP_HELP_QUICK_START, "BST_OP_HELP_QUICK_START", "help-quick-start" },
-  { BST_OP_HELP_ABOUT, "BST_OP_HELP_ABOUT", "help-about" },
-  { BST_OP_LAST, "BST_OP_LAST", "last" },
+static GFlagsValue bst_action_regions_values[] = {
+  { BST_ACTION_NONE, "BST_ACTION_NONE", "none" },
+  { BST_ACTION_APP_FIRST, "BST_ACTION_APP_FIRST", "app-first" },
+  { BST_ACTION_WAVE_FIRST, "BST_ACTION_WAVE_FIRST", "wave-first" },
+  { BST_ACTION_PART_FIRST, "BST_ACTION_PART_FIRST", "part-first" },
+  { BST_ACTION_TRACK_FIRST, "BST_ACTION_TRACK_FIRST", "track-first" },
   { 0, NULL, NULL }
 };
 
