@@ -72,15 +72,15 @@ tree_viewable_changed (BstFileDialog *self)
   gboolean viewable = gxk_widget_viewable (GTK_WIDGET (self->tview));
   gboolean tvisible = GTK_WIDGET_VISIBLE (gtk_widget_get_toplevel (GTK_WIDGET (self->tview)));
   
-  if (viewable && !self->using_sample_list)
+  if (viewable && !self->using_file_store)
     {
-      self->using_sample_list = TRUE;
-      bst_file_store_use_sample_list ();
+      self->using_file_store = TRUE;
+      bst_file_store_update_list (self->file_store, self->search_path, self->search_filter);
     }
-  else if (!tvisible && self->using_sample_list)
+  else if (!tvisible && self->using_file_store)
     {
-      self->using_sample_list = FALSE;
-      bst_file_store_unuse_sample_list ();
+      self->using_file_store = FALSE;
+      bst_file_store_forget_list (self->file_store);
     }
 }
 
@@ -89,7 +89,7 @@ bst_file_dialog_init (BstFileDialog *self)
 {
   GtkTreeSelection *tsel;
   GtkTreeModel *smodel;
-  GtkWidget *bbox, *vbox, *any;
+  GtkWidget *bbox, *vbox;
   GtkWidget *main_box = GXK_DIALOG (self)->vbox;
   
   self->ignore_activate = TRUE;
@@ -144,7 +144,8 @@ bst_file_dialog_init (BstFileDialog *self)
 			      "shadow_type", GTK_SHADOW_IN,
 			      NULL);
   gxk_notebook_add_page (GTK_NOTEBOOK (self->notebook), self->spage, "Sample Selection", TRUE);
-  smodel = gtk_tree_model_sort_new_with_model (bst_file_store_get_sample_list ());
+  self->file_store = bst_file_store_create ();
+  smodel = gtk_tree_model_sort_new_with_model (self->file_store);
   self->tview = g_object_new (GTK_TYPE_TREE_VIEW,
 			      "visible", TRUE,
 			      "can_focus", TRUE,
@@ -193,7 +194,7 @@ bst_file_dialog_init (BstFileDialog *self)
   
   /* setup save options */
   self->osave = g_object_new (GTK_TYPE_FRAME,
-			      "label", "Contents",
+			      "label", _("Contents"),
 			      "parent", self->fs->action_area,
 			      NULL);
   vbox = g_object_new (GTK_TYPE_VBOX,
@@ -201,20 +202,20 @@ bst_file_dialog_init (BstFileDialog *self)
 		       "parent", self->osave,
 		       NULL);
   self->radio1 = g_object_new (GTK_TYPE_RADIO_BUTTON,
-			       "label", "Store references to wave files",
+			       "label", "radio-1",
 			       "visible", TRUE,
 			       "parent", vbox,
 			       "can_focus", FALSE,
 			       NULL);
   gtk_misc_set_alignment (GTK_MISC (GTK_BIN (self->radio1)->child), 0, .5);
-  any = g_object_new (GTK_TYPE_RADIO_BUTTON,
-		      "label", "Include wave files",
-		      "visible", TRUE,
-		      "parent", vbox,
-		      "group", self->radio1,
-		      "can_focus", FALSE,
-		      NULL);
-  gtk_misc_set_alignment (GTK_MISC (GTK_BIN (any)->child), 0, .5);
+  self->radio2 = g_object_new (GTK_TYPE_RADIO_BUTTON,
+                               "label", "radio-2",
+                               "visible", TRUE,
+                               "parent", vbox,
+                               "group", self->radio1,
+                               "can_focus", FALSE,
+                               NULL);
+  gtk_misc_set_alignment (GTK_MISC (GTK_BIN (self->radio2)->child), 0, .5);
   
   /* setup actions */
   g_object_connect (self->fs->ok_button, "swapped_signal::clicked", bst_file_dialog_activate, self, NULL);
@@ -225,7 +226,7 @@ bst_file_dialog_init (BstFileDialog *self)
   gxk_dialog_set_focus (GXK_DIALOG (self), self->fs->selection_entry);
   
   /* setup remaining bits */
-  bst_file_dialog_set_mode (self, NULL, 0, "File Selection", 0);
+  bst_file_dialog_set_mode (self, NULL, 0, _("File Selection"), 0);
   gtk_window_set_type_hint (GTK_WINDOW (self), GDK_WINDOW_TYPE_HINT_DIALOG);
 }
 
@@ -235,16 +236,66 @@ bst_file_dialog_finalize (GObject *object)
   BstFileDialog *self = BST_FILE_DIALOG (object);
   
   bst_file_dialog_set_mode (self, NULL, 0, NULL, 0);
-  if (self->using_sample_list)
-    {
-      self->using_sample_list = FALSE;
-      bst_file_store_unuse_sample_list ();
-    }
+  g_free (self->search_path);
+  self->search_filter = NULL;
+  bst_file_store_destroy (self->file_store);
   
   /* chain parent class' handler */
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+static BstFileDialog*
+bst_file_dialog_global_project (void)
+{
+  static BstFileDialog *singleton = NULL;
+  if (!singleton)
+    singleton = g_object_new (BST_TYPE_FILE_DIALOG, NULL);
+  return singleton;
+}
+
+static BstFileDialog*
+bst_file_dialog_global_wave (void)
+{
+  static BstFileDialog *singleton = NULL;
+  if (!singleton)
+    singleton = g_object_new (BST_TYPE_FILE_DIALOG, NULL);
+  return singleton;
+}
+
+static BstFileDialog*
+bst_file_dialog_global_effect (void)
+{
+  static BstFileDialog *singleton = NULL;
+  if (!singleton)
+    {
+      const gchar *dir = bse_server_get_custom_effect_dir (BSE_SERVER);
+      singleton = g_object_new (BST_TYPE_FILE_DIALOG, NULL);
+      if (dir)
+        {
+          sfi_make_dirpath (dir);
+          gtk_file_selection_complete (singleton->fs, dir);
+        }
+    }
+  return singleton;
+}
+
+static BstFileDialog*
+bst_file_dialog_global_instrument (void)
+{
+  static BstFileDialog *singleton = NULL;
+  if (!singleton)
+    {
+      const gchar *dir = bse_server_get_custom_instrument_dir (BSE_SERVER);
+      singleton = g_object_new (BST_TYPE_FILE_DIALOG, NULL);
+      if (dir)
+        {
+          sfi_make_dirpath (dir);
+          gtk_file_selection_complete (singleton->fs, dir);
+        }
+    }
+  return singleton;
+}
+
 static void
 parent_window_destroyed (BstFileDialog *self)
 {
@@ -263,14 +314,17 @@ bst_file_dialog_set_mode (BstFileDialog    *self,
   GtkWindow *window = GTK_WINDOW (self);
   
   g_return_if_fail (BST_IS_FILE_DIALOG (self));
-  
+
   gtk_widget_hide (GTK_WIDGET (self));
   gtk_widget_hide (self->osave);
   self->mode = mode;
-  
+  g_free (self->selected);
+  self->selected = NULL;
+
   /* reset proxy handling */
   bst_window_sync_title_to_proxy (self, proxy, fs_title);
   self->proxy = proxy;
+  self->super = 0;
   
   /* cleanup connections to old parent_window */
   if (self->parent_window)
@@ -299,46 +353,75 @@ bst_file_dialog_set_mode (BstFileDialog    *self,
   switch (mode & BST_FILE_DIALOG_MODE_MASK)
     {
     case BST_FILE_DIALOG_LOAD_WAVE:
+      g_free (self->search_path);
+      self->search_path = g_strdup (bse_server_get_sample_path (BSE_SERVER));
+      self->search_filter = NULL;
       gtk_widget_show (self->spage);
       gxk_notebook_set_current_page_widget (GTK_NOTEBOOK (self->notebook), self->fpage);
       g_object_set (self->notebook, "show_border", TRUE, "show_tabs", TRUE, NULL);
       break;
     case BST_FILE_DIALOG_LOAD_WAVE_LIB:
+      g_free (self->search_path);
+      self->search_path = g_strdup (bse_server_get_sample_path (BSE_SERVER));
+      self->search_filter = NULL;
+      gtk_widget_show (self->spage);
+      gxk_notebook_set_current_page_widget (GTK_NOTEBOOK (self->notebook), self->spage);
+      g_object_set (self->notebook, "show_border", TRUE, "show_tabs", TRUE, NULL);
+      break;
+    case BST_FILE_DIALOG_MERGE_EFFECT:
+      g_free (self->search_path);
+      self->search_path = g_strdup (bse_server_get_effect_path (BSE_SERVER));
+      self->search_filter = "*";
+      gtk_widget_show (self->spage);
+      gxk_notebook_set_current_page_widget (GTK_NOTEBOOK (self->notebook), self->spage);
+      g_object_set (self->notebook, "show_border", TRUE, "show_tabs", TRUE, NULL);
+      break;
+    case BST_FILE_DIALOG_MERGE_INSTRUMENT:
+      g_free (self->search_path);
+      self->search_path = g_strdup (bse_server_get_instrument_path (BSE_SERVER));
+      self->search_filter = "*";
       gtk_widget_show (self->spage);
       gxk_notebook_set_current_page_widget (GTK_NOTEBOOK (self->notebook), self->spage);
       g_object_set (self->notebook, "show_border", TRUE, "show_tabs", TRUE, NULL);
       break;
     default:
-      if (self->using_sample_list)
-	{
-	  self->using_sample_list = FALSE;
-	  bst_file_store_unuse_sample_list ();
-	}
+      g_free (self->search_path);
+      self->search_path = NULL;
+      self->search_filter = NULL;
+      if (self->using_file_store)
+        {
+          self->using_file_store = FALSE;
+          bst_file_store_forget_list (self->file_store);
+        }
       gtk_widget_hide (self->spage);
       g_object_set (self->notebook, "show_border", FALSE, "show_tabs", FALSE, NULL);
       break;
     }
 }
 
-static BstFileDialog*
-bst_file_dialog_singleton (void)
-{
-  static BstFileDialog *fd_singleton = NULL;
-  if (!fd_singleton)
-    fd_singleton = g_object_new (BST_TYPE_FILE_DIALOG,
-				 NULL);
-  return fd_singleton;
-}
-
 GtkWidget*
 bst_file_dialog_popup_open_project (gpointer parent_widget)
 {
-  BstFileDialog *self = bst_file_dialog_singleton ();
+  BstFileDialog *self = bst_file_dialog_global_project ();
   GtkWidget *widget = GTK_WIDGET (self);
 
   bst_file_dialog_set_mode (self, parent_widget,
 			    BST_FILE_DIALOG_OPEN_PROJECT,
-			    "Open Project", 0);
+			    _("Open Project"), 0);
+  gxk_widget_showraise (widget);
+
+  return widget;
+}
+
+GtkWidget*
+bst_file_dialog_popup_select_dir (gpointer parent_widget)
+{
+  BstFileDialog *self = bst_file_dialog_global_project ();
+  GtkWidget *widget = GTK_WIDGET (self);
+
+  bst_file_dialog_set_mode (self, parent_widget,
+			    BST_FILE_DIALOG_SELECT_DIR | BST_FILE_DIALOG_ALLOW_DIRS,
+			    _("Select Directory"), 0);
   gxk_widget_showraise (widget);
 
   return widget;
@@ -352,14 +435,14 @@ bst_file_dialog_open_project (BstFileDialog *self,
   BseErrorType error = bse_project_restore_from_file (project, file_name);
 
   if (error)
-    bst_status_eprintf (error, "Opening project `%s'", file_name);
+    bst_status_eprintf (error, _("Opening project `%s'"), file_name);
   else
     {
       BstApp *app;
       bse_project_get_wave_repo (project);
       app = bst_app_new (project);
       gxk_status_window_push (app);
-      bst_status_eprintf (error, "Opening project `%s'", file_name);
+      bst_status_eprintf (error, _("Opening project `%s'"), file_name);
       gxk_status_window_pop ();
       gxk_idle_show_widget (GTK_WIDGET (app));
     }
@@ -372,12 +455,12 @@ GtkWidget*
 bst_file_dialog_popup_merge_project (gpointer   parent_widget,
 				     SfiProxy   project)
 {
-  BstFileDialog *self = bst_file_dialog_singleton ();
+  BstFileDialog *self = bst_file_dialog_global_project ();
   GtkWidget *widget = GTK_WIDGET (self);
 
   bst_file_dialog_set_mode (self, parent_widget,
 			    BST_FILE_DIALOG_MERGE_PROJECT,
-			    "Merge: %s", project);
+			    _("Merge: %s"), project);
   gxk_widget_showraise (widget);
 
   return widget;
@@ -390,25 +473,64 @@ bst_file_dialog_merge_project (BstFileDialog *self,
   SfiProxy project = bse_item_use (self->proxy);
   BseErrorType error = bse_project_restore_from_file (project, file_name);
 
-  bst_status_eprintf (error, "Merging project `%s'", file_name);
+  bst_status_eprintf (error, _("Merging project `%s'"), file_name);
 
   bse_item_unuse (project);
 
   return TRUE;
 }
 
+static gboolean
+retry_after_file_unlink (gchar       *title,
+                         gchar       *message,
+                         const gchar *file_name)
+{
+  GtkWidget *choice = bst_choice_dialog_createv (BST_CHOICE_TITLE (title),
+                                                 BST_CHOICE_TEXT (message),
+                                                 BST_CHOICE_D (1, BST_STOCK_OVERWRITE, NONE),
+                                                 BST_CHOICE (0, BST_STOCK_CANCEL, NONE),
+                                                 BST_CHOICE_END);
+  gboolean need_retry = FALSE;
+  if (bst_choice_modal (choice, 0, 0) == 1)
+    {
+      bst_choice_destroy (choice);
+      if (unlink (file_name) < 0)
+        {
+          gchar *text = g_strdup_printf (_("Failed to delete file\n`%s'\ndue to:\n%s"),
+                                         file_name, g_strerror (errno));
+          choice = bst_choice_dialog_createv (BST_CHOICE_TITLE (title),
+                                              BST_CHOICE_TEXT (text),
+                                              BST_CHOICE_D (0, BST_STOCK_CLOSE, NONE),
+                                              BST_CHOICE_END);
+          g_free (text);
+          bst_choice_modal (choice, 0, 0);
+          bst_choice_destroy (choice);
+        }
+      else
+        need_retry = TRUE;
+    }
+  else
+    bst_choice_destroy (choice);
+  g_free (message);
+  g_free (title);
+  return need_retry;
+}
+
 GtkWidget*
 bst_file_dialog_popup_save_project (gpointer   parent_widget,
 				    SfiProxy   project)
 {
-  BstFileDialog *self = bst_file_dialog_singleton ();
+  BstFileDialog *self = bst_file_dialog_global_project ();
   GtkWidget *widget = GTK_WIDGET (self);
 
   bst_file_dialog_set_mode (self, parent_widget,
 			    BST_FILE_DIALOG_SAVE_PROJECT,
-			    "Save: %s", project);
-  /* resetting: gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->radio1), TRUE); */
+			    _("Save: %s"), project);
+  /* setup radio buttons */
+  g_object_set (GTK_BIN (self->radio1)->child, "label", _("Fully include wave files"), NULL);
+  g_object_set (GTK_BIN (self->radio2)->child, "label", _("Store references to wave files"), NULL);
   gtk_widget_show (self->osave);
+  /* show dialog */
   gxk_widget_showraise (widget);
 
   return widget;
@@ -419,50 +541,177 @@ bst_file_dialog_save_project (BstFileDialog *self,
 			      const gchar   *file_name)
 {
   SfiProxy project = bse_item_use (self->proxy);
-  gboolean handled = TRUE, self_contained = !GTK_TOGGLE_BUTTON (self->radio1)->active;
+  gboolean handled = TRUE, self_contained = GTK_TOGGLE_BUTTON (self->radio1)->active;
   BseErrorType error;
 
  retry_saving:
-  error = bse_project_store_bse (project, file_name, self_contained);
+  error = bse_project_store_bse (project, 0, file_name, self_contained);
   /* offer retry if file exists */
   if (error == BSE_ERROR_FILE_EXISTS)
     {
-      gchar *title = g_strdup_printf ("Saving project `%s'", bse_item_get_name (project));
-      gchar *text = g_strdup_printf ("Failed to save\n`%s'\nto\n`%s':\n%s",
-				     bse_item_get_name (project),
-				     file_name,
-				     bse_error_blurb (error));
-      GtkWidget *choice = bst_choice_dialog_createv (BST_CHOICE_TITLE (title),
-						     BST_CHOICE_TEXT (text),
-						     BST_CHOICE_D (1, BST_STOCK_OVERWRITE, NONE),
-						     BST_CHOICE (0, BST_STOCK_CANCEL, NONE),
-						     BST_CHOICE_END);
-      g_free (title);
-      g_free (text);
-      if (bst_choice_modal (choice, 0, 0) == 1)
-	{
-	  bst_choice_destroy (choice);
-	  if (unlink (file_name) < 0)
-	    {
-	      title = g_strdup_printf ("Deleting file `%s'", bse_item_get_name (project));
-	      text = g_strdup_printf ("Failed to delete file\n`%s'\ndue to:\n%s",
-				      file_name, bse_error_blurb (error));
-	      choice = bst_choice_dialog_createv (BST_CHOICE_TITLE (title),
-						  BST_CHOICE_TEXT (text),
-						  BST_CHOICE_D (0, BST_STOCK_CLOSE, NONE),
-						  BST_CHOICE_END);
-	      bst_choice_modal (choice, 0, 0);
-	      bst_choice_destroy (choice);
-	    }
-	  else
-	    goto retry_saving;
-	}
-      else
-	bst_choice_destroy (choice);
+      if (retry_after_file_unlink (g_strdup_printf (_("Saving project `%s'"), bse_item_get_name (project)),
+                                   g_strdup_printf (_("Failed to save\n`%s'\nto\n`%s':\n%s"),
+                                                    bse_item_get_name (project),
+                                                    file_name,
+                                                    bse_error_blurb (error)),
+                                   file_name))
+        goto retry_saving;
       handled = FALSE;
     }
   else
-    bst_status_eprintf (error, "Saving project `%s'", file_name);
+    bst_status_eprintf (error, _("Saving project `%s'"), bse_item_get_name (self->proxy));
+  bse_item_unuse (project);
+
+  return handled;
+}
+
+GtkWidget*
+bst_file_dialog_popup_merge_effect (gpointer   parent_widget,
+                                    SfiProxy   project)
+{
+  BstFileDialog *self = bst_file_dialog_global_effect ();
+  GtkWidget *widget = GTK_WIDGET (self);
+
+  bst_file_dialog_set_mode (self, parent_widget,
+                            BST_FILE_DIALOG_MERGE_EFFECT,
+                            _("Load Effect"), project);
+  gxk_widget_showraise (widget);
+
+  return widget;
+}
+
+static gboolean
+bst_file_dialog_merge_effect (BstFileDialog *self,
+                              const gchar   *file_name)
+{
+  SfiProxy project = bse_item_use (self->proxy);
+  BseErrorType error = bse_project_restore_from_file (project, file_name);
+
+  bst_status_eprintf (error, _("Merging effect `%s'"), file_name);
+
+  bse_item_unuse (project);
+
+  return TRUE;
+}
+
+GtkWidget*
+bst_file_dialog_popup_save_effect (gpointer parent_widget,
+                                   SfiProxy project,
+                                   SfiProxy super)
+{
+  BstFileDialog *self = bst_file_dialog_global_effect ();
+  GtkWidget *widget = GTK_WIDGET (self);
+
+  bst_file_dialog_set_mode (self, parent_widget,
+			    BST_FILE_DIALOG_SAVE_EFFECT,
+			    _("Save Effect"), project);
+  self->super = super;
+  /* show dialog */
+  gxk_widget_showraise (widget);
+
+  return widget;
+}
+
+static gboolean
+bst_file_dialog_save_effect (BstFileDialog *self,
+                             const gchar   *file_name)
+{
+  SfiProxy project = bse_item_use (self->proxy);
+  gboolean handled = TRUE;
+  BseErrorType error;
+
+ retry_saving:
+  error = bse_project_store_bse (project, self->super, file_name, TRUE);
+  /* offer retry if file exists */
+  if (error == BSE_ERROR_FILE_EXISTS)
+    {
+      if (retry_after_file_unlink (g_strdup_printf (_("Saving effect `%s'"), bse_item_get_name (self->super)),
+                                   g_strdup_printf (_("Failed to save\n`%s'\nto\n`%s':\n%s"),
+                                                    bse_item_get_name (self->super),
+                                                    file_name,
+                                                    bse_error_blurb (error)),
+                                   file_name))
+        goto retry_saving;
+      handled = FALSE;
+    }
+  else
+    bst_status_eprintf (error, _("Saving effect `%s'"), bse_item_get_name (self->super));
+  bse_item_unuse (project);
+
+  return handled;
+}
+
+GtkWidget*
+bst_file_dialog_popup_merge_instrument (gpointer   parent_widget,
+                                        SfiProxy   project)
+{
+  BstFileDialog *self = bst_file_dialog_global_instrument ();
+  GtkWidget *widget = GTK_WIDGET (self);
+
+  bst_file_dialog_set_mode (self, parent_widget,
+                            BST_FILE_DIALOG_MERGE_INSTRUMENT,
+                            _("Load Instrument"), project);
+  gxk_widget_showraise (widget);
+
+  return widget;
+}
+
+static gboolean
+bst_file_dialog_merge_instrument (BstFileDialog *self,
+                                  const gchar   *file_name)
+{
+  SfiProxy project = bse_item_use (self->proxy);
+  BseErrorType error = bse_project_restore_from_file (project, file_name);
+
+  bst_status_eprintf (error, _("Merging instrument `%s'"), file_name);
+
+  bse_item_unuse (project);
+
+  return TRUE;
+}
+
+GtkWidget*
+bst_file_dialog_popup_save_instrument (gpointer parent_widget,
+                                       SfiProxy project,
+                                       SfiProxy super)
+{
+  BstFileDialog *self = bst_file_dialog_global_instrument ();
+  GtkWidget *widget = GTK_WIDGET (self);
+  
+  bst_file_dialog_set_mode (self, parent_widget,
+			    BST_FILE_DIALOG_SAVE_INSTRUMENT,
+			    _("Save Instrument"), project);
+  self->super = super;
+  /* show dialog */
+  gxk_widget_showraise (widget);
+  
+  return widget;
+}
+
+static gboolean
+bst_file_dialog_save_instrument (BstFileDialog *self,
+                                 const gchar   *file_name)
+{
+  SfiProxy project = bse_item_use (self->proxy);
+  gboolean handled = TRUE;
+  BseErrorType error;
+
+ retry_saving:
+  error = bse_project_store_bse (project, self->super, file_name, TRUE);
+  /* offer retry if file exists */
+  if (error == BSE_ERROR_FILE_EXISTS)
+    {
+      if (retry_after_file_unlink (g_strdup_printf (_("Saving instrument `%s'"), bse_item_get_name (self->super)),
+                                   g_strdup_printf (_("Failed to save\n`%s'\nto\n`%s':\n%s"),
+                                                    bse_item_get_name (self->super),
+                                                    file_name,
+                                                    bse_error_blurb (error)),
+                                   file_name))
+        goto retry_saving;
+      handled = FALSE;
+    }
+  else
+    bst_status_eprintf (error, _("Saving instrument `%s'"), bse_item_get_name (self->super));
   bse_item_unuse (project);
 
   return handled;
@@ -473,12 +722,12 @@ bst_file_dialog_popup_load_wave (gpointer parent_widget,
 				 SfiProxy wave_repo,
 				 gboolean show_lib)
 {
-  BstFileDialog *self = bst_file_dialog_singleton ();
+  BstFileDialog *self = bst_file_dialog_global_wave ();
   GtkWidget *widget = GTK_WIDGET (self);
 
   bst_file_dialog_set_mode (self, parent_widget,
 			    show_lib ? BST_FILE_DIALOG_LOAD_WAVE_LIB : BST_FILE_DIALOG_LOAD_WAVE,
-			    "Load Wave", wave_repo);
+			    _("Load Wave"), wave_repo);
   gxk_widget_showraise (widget);
 
   return widget;
@@ -490,13 +739,47 @@ bst_file_dialog_load_wave (BstFileDialog *self,
 {
   BseErrorType error;
 
-  gxk_status_printf (0, NULL, "Loading wave `%s'", file_name);
+  gxk_status_printf (0, NULL, _("Loading wave `%s'"), file_name);
   error = bse_wave_repo_load_file (self->proxy, file_name);
-  bst_status_eprintf (error, "Loading wave `%s'", file_name);
+  bst_status_eprintf (error, _("Loading wave `%s'"), file_name);
 
   return TRUE;
 }
 
+typedef struct {
+  BstFileDialogHandler handler;
+  gpointer             data;
+  GDestroyNotify       destroy;
+} BstFileDialogData;
+
+static void
+bst_file_dialog_handler (BstFileDialog     *self,
+                         BstFileDialogData *data)
+{
+  if (data->handler && self->selected)
+    data->handler (GTK_WIDGET (self), self->selected, data->data);
+  if (data->destroy)
+    data->destroy (data->data);
+  g_object_disconnect (self, "any_signal", bst_file_dialog_handler, data, NULL);
+  g_free (data);
+}
+
+void
+bst_file_dialog_set_handler (BstFileDialog    *self,
+                             BstFileDialogHandler handler,
+                             gpointer          handler_data,
+                             GDestroyNotify    destroy)
+{
+  BstFileDialogData *data = g_new0 (BstFileDialogData, 1);
+
+  g_return_if_fail (GTK_WIDGET_VISIBLE (self));
+
+  data->handler = handler;
+  data->data = handler_data;
+  data->destroy = destroy;
+  g_object_connect (self, "signal_after::hide", bst_file_dialog_handler, data, NULL);
+}
+
 static void
 bst_file_dialog_activate (BstFileDialog *self)
 {
@@ -534,6 +817,7 @@ bst_file_dialog_activate (BstFileDialog *self)
       g_free (file_name);
       return;
     }
+
   if (swin)
     gxk_status_window_push (swin);
   switch (self->mode & BST_FILE_DIALOG_MODE_MASK)
@@ -544,9 +828,24 @@ bst_file_dialog_activate (BstFileDialog *self)
     case BST_FILE_DIALOG_MERGE_PROJECT:
       popdown = bst_file_dialog_merge_project (self, file_name);
       break;
+    case BST_FILE_DIALOG_MERGE_EFFECT:
+      popdown = bst_file_dialog_merge_effect (self, file_name);
+      break;
+    case BST_FILE_DIALOG_MERGE_INSTRUMENT:
+      popdown = bst_file_dialog_merge_instrument (self, file_name);
+      break;
     case BST_FILE_DIALOG_SAVE_PROJECT:
       popdown = bst_file_dialog_save_project (self, file_name);
       break;
+    case BST_FILE_DIALOG_SAVE_EFFECT:
+      popdown = bst_file_dialog_save_effect (self, file_name);
+      break;
+    case BST_FILE_DIALOG_SAVE_INSTRUMENT:
+      popdown = bst_file_dialog_save_instrument (self, file_name);
+      break;
+    case BST_FILE_DIALOG_SELECT_DIR:
+      popdown = TRUE;   /* handled via BstFileDialogHandler and ->selected */
+      break;
     case BST_FILE_DIALOG_LOAD_WAVE:
     case BST_FILE_DIALOG_LOAD_WAVE_LIB:
       popdown = bst_file_dialog_load_wave (self, file_name);
@@ -558,6 +857,10 @@ bst_file_dialog_activate (BstFileDialog *self)
     {
       /* ignore_activate guards against multiple clicks from long loads */
       self->ignore_activate = TRUE;
+      g_free (self->selected);
+      self->selected = file_name;
       gxk_toplevel_delete (GTK_WIDGET (self));
     }
+  else
+    g_free (file_name);
 }
