@@ -99,27 +99,71 @@ menu_config_copy_icon (BstMenuConfig *config,
   return ic;
 }
 
+static void
+menu_config_append_cat (BstMenuConfig  *mconfig,
+                        BseCategory    *cat,
+                        BstMenuCatFunc  callback,
+                        guint           skip_levels,
+                        const gchar    *new_prefix,
+                        const gchar    *stock_fallback)
+{
+  BstMenuConfigEntry e = { 0, };
+  const gchar *p = cat->category[0] == '/' ? cat->category + 1 : cat->category;
+  gboolean have_icon;           // FIXME: optimize once we support NULL icons
+  while (skip_levels--)
+    {
+      const gchar *d = strchr (p, '/');
+      p = d ? d + 1 : p;
+    }
+  e.path = g_strconcat (new_prefix ? new_prefix : "/", p, NULL);
+  e.accelerator = NULL;
+  e.callback = (BstMenuUserFunc) callback;
+  e.callback_action = cat->category_id;
+  have_icon = cat->icon && (cat->icon->width + cat->icon->height) > 0;
+  if (!have_icon)
+    {
+      e.item_type = stock_fallback ? "<StockItem>" : "<Item>";
+      e.extra_data = stock_fallback;
+    }
+  else
+    {
+      e.item_type = bstmenu_category_item;
+      e.extra_data = menu_config_copy_icon (mconfig, cat->icon);
+    }
+  menu_config_append (mconfig, &e);
+  g_free (e.path);
+}
+
+BstMenuConfig*
+bst_menu_config_append_cat (BstMenuConfig          *mconfig,
+                            BseCategory            *cat,
+                            BstMenuCatFunc          callback,
+                            guint                   skip_levels,
+                            const gchar            *new_prefix,
+                            const gchar            *stock_fallback)
+{
+  g_return_val_if_fail (mconfig != NULL, mconfig);
+  g_return_val_if_fail (cat != NULL, mconfig);
+
+  menu_config_append_cat (mconfig, cat, callback, skip_levels, new_prefix, stock_fallback);
+  return mconfig;
+}
+
 BstMenuConfig*
 bst_menu_config_from_cats (BseCategorySeq *cseq,
 			   BstMenuCatFunc  callback,
-			   guint           skip_levels)
+			   guint           skip_levels,
+                           const gchar    *new_prefix,
+                           const gchar    *stock_fallback)
 {
-  BstMenuConfig *config = g_new0 (BstMenuConfig, 1);
+  BstMenuConfig *mconfig = g_new0 (BstMenuConfig, 1);
   guint i;
 
-  for (i = 0; i < cseq->n_cats; i++)
-    {
-      BstMenuConfigEntry e = { 0, };
-      e.path = cseq->cats[i]->category + (skip_levels ? cseq->cats[i]->mindex : 0);
-      e.accelerator = NULL;
-      e.callback = (BstMenuUserFunc) callback;
-      e.callback_action = cseq->cats[i]->category_id;
-      e.item_type = bstmenu_category_item;
-      e.extra_data = menu_config_copy_icon (config, cseq->cats[i]->icon);
-      menu_config_append (config, &e);
-    }
+  g_return_val_if_fail (cseq != NULL, mconfig);
 
-  return config;
+  for (i = 0; i < cseq->n_cats; i++)
+    menu_config_append_cat (mconfig, cseq->cats[i], callback, skip_levels, new_prefix, stock_fallback);
+  return mconfig;
 }
 
 BstMenuConfig*
@@ -238,7 +282,7 @@ bst_menu_config_create_items (BstMenuConfig  *config,
       ife.path = e->path;
       ife.accelerator = e->accelerator;
       ife.callback = NULL;
-      ife.callback_action = 0;
+      ife.callback_action = e->callback_action; /* gtk_item_factory_get_widget_by_action() */
       if (e->item_type && strcmp (e->item_type, bstmenu_category_item) == 0)
 	{
 	  ife.item_type = "<ImageItem>";
@@ -248,6 +292,12 @@ bst_menu_config_create_items (BstMenuConfig  *config,
 	   */
 	  ife.extra_data = BST_PIXDATA_EMPTY1x1;
 	}
+      else if (e->item_type && strcmp (e->item_type, "<StockItem>") == 0)
+        {
+          /* create just an image item, we want the stock IDs to affect only the image (not accels etc.) */
+          ife.item_type = "<ImageItem>";
+          ife.extra_data = BST_PIXDATA_EMPTY1x1;
+        }
       else
 	{
 	  ife.item_type = e->item_type;
@@ -268,12 +318,18 @@ bst_menu_config_create_items (BstMenuConfig  *config,
 			      e->callback);
 	}
 
-      /* create image from BseIcon */
-      if (e->item_type == bstmenu_category_item)
+      /* create image */
+      if (e->item_type && strcmp (e->item_type, bstmenu_category_item) == 0)
 	{
 	  GtkWidget *image = bst_image_from_icon ((BseIcon*) e->extra_data, BST_SIZE_MENU);
 	  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 	}
+      else if (e->item_type && strcmp (e->item_type, "<StockItem>") == 0)
+        {
+          GtkWidget *image = e->extra_data ? gtk_image_new_from_stock ((gchar*) e->extra_data, GTK_ICON_SIZE_MENU) : NULL;
+          gtk_widget_show (image);
+          gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+        }
 
       /* fixup Title items */
       if (ife.item_type && strcmp (ife.item_type, "<Title>") == 0)
@@ -295,7 +351,7 @@ void
 bst_menu_popup (GtkItemFactory  *ifactory,
 		GtkWidget	*owner,
 		gpointer         popup_data,
-		GtkDestroyNotify popup_data_destroy,
+		GtkDestroyNotify data_destroy,
 		guint            x,
 		guint            y,
 		guint            mouse_button,
@@ -309,7 +365,7 @@ bst_menu_popup (GtkItemFactory  *ifactory,
   pdata = g_new (PopupData, 1);
   pdata->owner = owner;
   pdata->popup_data = popup_data;
-  pdata->destroy = popup_data_destroy;
+  pdata->destroy = data_destroy;
 
   gtk_item_factory_popup_with_data (ifactory,
 				    pdata, popup_data_destroy,
