@@ -149,7 +149,7 @@ bst_param_alloc (BstParamImpl *impl,
   bparam->column = 0;
   bparam->readonly = (!(bparam->impl->flags & BST_PARAM_EDITABLE) ||
 		      !(pspec->flags & G_PARAM_WRITABLE) ||
-		      sfi_pspec_test_hint (pspec, SFI_PARAM_HINT_RDONLY));
+		      sfi_pspec_check_option (pspec, "ro"));       /* read-only check */
   if (!bparam->readonly)
     bparam->readonly = !g_type_is_a (itype, vtype);
   bparam->writable = FALSE;
@@ -180,10 +180,7 @@ bst_param_update (BstParam *bparam)
   if (action)
     bparam->impl->update (bparam, action);
   
-  bparam->writable = (!bparam->readonly &&
-		      bparam->editable &&
-		      (!bparam->binding->check_writable ||
-		       bparam->binding->check_writable (bparam)));
+  bparam->writable = FALSE;
   bst_param_update_sensitivity (bparam);
   
   bparam->updating = updating;
@@ -203,6 +200,21 @@ bst_param_apply_value (BstParam *bparam)
   bparam->binding->set_value (bparam, &bparam->value);
 }
 
+void
+bst_param_apply_default (BstParam *bparam)
+{
+  g_return_if_fail (bparam != NULL);
+
+  if (!bparam->updating && bparam->writable)
+    {
+      GValue value = { 0, };
+      g_value_init (&value, G_VALUE_TYPE (&bparam->value));
+      g_param_value_set_default (bparam->pspec, &value);
+      bparam->binding->set_value (bparam, &value);
+      g_value_unset (&value);
+    }
+}
+
 void
 bst_param_set_editable (BstParam *bparam,
 			gboolean  editable)
@@ -316,7 +328,7 @@ bst_param_rack_widget (BstParam *bparam)
   g_object_ref (bparam->gdata.widget);
   bparam->updating = FALSE;
   bst_param_update_sensitivity (bparam); /* bst_param_update (bparam); */
-  return bparam->gdata.widget;
+  return gtk_widget_get_toplevel (bparam->gdata.widget);
 }
 
 void
@@ -546,6 +558,63 @@ bst_param_rec_create (GParamSpec  *pspec,
 }
 
 
+/* --- value binding --- */
+static void
+value_binding_set_value (BstParam     *bparam,
+                         const GValue *value)
+{
+  BstParamValueNotify notify = bparam->mdata[0].v_pointer;
+  sfi_value_copy_shallow (value, &bparam->value);
+  if (notify)
+    notify (bparam->mdata[1].v_pointer, bparam);
+}
+
+static void
+value_binding_get_value (BstParam *bparam,
+                         GValue   *value)
+{
+  sfi_value_copy_shallow (&bparam->value, value);
+}
+
+static void
+value_binding_destroy (BstParam *bparam)
+{
+  bparam->mdata[0].v_pointer = NULL;
+  bparam->mdata[1].v_pointer = NULL;
+}
+
+static BstParamBinding bst_value_binding = {
+  value_binding_set_value,
+  value_binding_get_value,
+  value_binding_destroy,
+  /* check_writable */
+};
+
+BstParamBinding*
+bst_param_binding_value (void)
+{
+  return &bst_value_binding;
+}
+
+BstParam*
+bst_param_value_create (GParamSpec         *pspec,
+                        gboolean            rack_widget,
+                        const gchar        *view_name,
+                        BstParamValueNotify notify,
+                        gpointer            notify_data)
+{
+  BstParamImpl *impl;
+  BstParam *bparam;
+
+  impl = bst_param_lookup_impl (pspec, rack_widget, view_name, &bst_value_binding);
+  bparam = bst_param_alloc (impl, pspec);
+  bparam->binding = &bst_value_binding;
+  bparam->mdata[0].v_pointer = notify;
+  bparam->mdata[1].v_pointer = notify_data;
+  return bparam;
+}
+
+
 /* --- param and rack widget implementations --- */
 #include "bstparam-label.c"
 #include "bstparam-toggle.c"
@@ -690,7 +759,7 @@ bst_param_rate_impl (BstParamImpl    *impl,
   if (impl->flags & BST_PARAM_PROXY_LIST)
     type_mismatch |= !binding || !binding->list_proxies;
 
-  does_match = !type_mismatch && (!impl->hints || sfi_pspec_test_all_hints (pspec, impl->hints));
+  does_match = !type_mismatch && (!impl->hints || sfi_pspec_require_options (pspec, impl->hints));
   if (!does_match)
     return 0;		/* mismatch */
 
