@@ -19,7 +19,9 @@
 #define __BST_PART_DIALOG_H__
 
 #include	"bstpianoroll.h"
+#include	"bsteventroll.h"
 #include	"bstpianorollctrl.h"
+#include	"bsteventrollctrl.h"
 #include	"bstradiotools.h"
 
 G_BEGIN_DECLS
@@ -40,12 +42,11 @@ struct _BstPartDialog
 {
   GxkDialog	parent_object;
 
-  GtkWidget	*main_vbox;
-  GtkWidget	*scrolled_window;
   BstPianoRoll  *proll;
-  BstPianoRollController *proll_ctrl;
+  BstPianoRollController *pctrl;
+  BstEventRoll  *eroll;
+  BstEventRollController *ectrl;
   GxkToolbar	*toolbar;
-  BstRadioTools	*rtools;
   SfiProxy       project;
 };
 struct _BstPartDialogClass
