@@ -252,24 +252,14 @@ bst_radio_tools_add_catalog_tool (BstRadioTools     *self,
 				  const gchar       *cat_key,
 				  BstRadioToolsFlags flags)
 {
-  const BstCatalogTool *tool;
-  BstCatalogTool dummy = { 0, };
   guint i;
 
-  tool = bst_catalog_get_tool (cat_key);
-  if (tool)
-    flags &= ~BST_RADIO_TOOLS_FREE_FLAG;
-  else
-    {
-      dummy.name = g_strdup (cat_key);
-      tool = &dummy;
-      flags |= ~BST_RADIO_TOOLS_FREE_FLAG;
-    }
+  flags &= ~BST_RADIO_TOOLS_FREE_FLAG;
 
   i = self->n_tools++;
   self->tools = g_renew (BstRadioToolEntry, self->tools, self->n_tools);
   self->tools[i].tool_id = tool_id;
-  self->tools[i].tool = *tool;
+  self->tools[i].tool = bst_catalog_get_tool (cat_key);
   self->tools[i].tool.cat_key = NULL;
   self->tools[i].icon = NULL;
   self->tools[i].flags = flags;
@@ -346,7 +336,7 @@ bst_radio_tools_clear_tools (BstRadioTools *self)
 }
 
 void
-bst_radio_tools_destroy (BstRadioTools *self)
+bst_radio_tools_dispose (BstRadioTools *self)
 {
   g_return_if_fail (BST_IS_RADIO_TOOLS (self));
   
@@ -370,6 +360,7 @@ rtools_toggle_toggled (BstRadioTools   *self,
     {
       GdkEvent *event = gtk_get_current_event ();
       tool_id = GPOINTER_TO_UINT (gtk_object_get_user_data (GTK_OBJECT (toggle)));
+#if 0
       /* ignore untoggeling through the GUI (button release on depressed toggle) */
       if (toggle->active ||
           (gtk_get_event_widget (event) == GTK_WIDGET (toggle) &&
@@ -377,6 +368,10 @@ rtools_toggle_toggled (BstRadioTools   *self,
         bst_radio_tools_set_tool (self, tool_id);
       else
         bst_radio_tools_set_tool (self, 0);
+#endif
+      /* react to activating toggle changes only */
+      if (toggle->active)
+        bst_radio_tools_set_tool (self, tool_id);
       /* enforce depressed state in case tool_id didn't change */
       if (self->tool_id == tool_id && !toggle->active)
         {
@@ -627,7 +622,7 @@ bst_radio_tools_build_palette (BstRadioTools *self,
       gtk_box_pack_start (GTK_BOX (hbox), text, TRUE, TRUE, 5);
       gtk_widget_new (GTK_TYPE_FRAME,
                       "visible", TRUE,
-                      "label", "Description",
+                      "label", _("Description"),
                       "label_xalign", 0.5,
                       "border_width", 5,
                       "parent", vbox,
