@@ -1,5 +1,5 @@
 /* BEAST - Bedevilled Audio System
- * Copyright (C) 1998-2002 Tim Janik
+ * Copyright (C) 1998-2003 Tim Janik
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "bstcanvaslink.h"
 #include "bstmenus.h"
 #include "bstgconfig.h"
+#include "bstprocedure.h"
 #include <gdk/gdkkeysyms.h>
 
 
@@ -54,22 +55,27 @@ static void	  bst_router_tool_set		(BstSNetRouter		*router);
 static void	  bst_router_popup_select       (GtkWidget		*widget,
 						 gulong                  category_id,
 						 gpointer                popup_data);
+static void	  bst_router_run_method         (GtkWidget		*widget,
+						 gulong                  category_id,
+						 gpointer                popup_data);
 
 
 /* --- menus --- */
 static BstMenuConfigEntry popup_entries[] =
 {
-  { "/Modules",		NULL,		NULL,	0,	"<Title>",	0 },
+  { "/Tools",		NULL,		NULL,	0,	"<Title>",	0 },
+  { "/_Utils",		NULL,		NULL,	0,	"<Branch>",	0 },
   { "/-----",		NULL,		NULL,	0,	"<Separator>",	0 },
+  { "/Modules",		NULL,		NULL,	0,	"<Title>",	0 },
   { "/Audio _Sources",	NULL,		NULL,	0,	"<Branch>",	0 },
   { "/_Other Sources",	NULL,		NULL,	0,	"<Branch>",	0 },
   { "/_Routing",	NULL,		NULL,	0,	"<Branch>",	0 },
+  { "/_Spatial",	NULL,		NULL,	0,	"<Branch>",	0 },
   { "/_Filters",	NULL,		NULL,	0,	"<Branch>",	0 },
-  // { "/_Enhance",	NULL,		NULL,	0,	"<Branch>",	0 },
+  { "/_Enhance",	NULL,		NULL,	0,	"<Branch>",	0 },
   { "/_Distortion",	NULL,		NULL,	0,	"<Branch>",	0 },
-  { "/_Input & Output",	NULL,		NULL,	0,	"<Branch>",	0 },
-  { "/_MIDI",		NULL,		NULL,	0,	"<Branch>",	0 },
   { "/_Virtualization",	NULL,		NULL,	0,	"<Branch>",	0 },
+  { "/_Input & Output",	NULL,		NULL,	0,	"<Branch>",	0 },
 };
 
 
@@ -79,29 +85,26 @@ static BstSNetRouterClass *bst_snet_router_class = NULL;
 
 
 /* --- functions --- */
-GtkType
+GType
 bst_snet_router_get_type (void)
 {
-  static GtkType snet_router_type = 0;
-  
-  if (!snet_router_type)
+  static GType type = 0;
+  if (!type)
     {
-      GtkTypeInfo snet_router_info =
-      {
-	"BstSNetRouter",
-	sizeof (BstSNetRouter),
-	sizeof (BstSNetRouterClass),
-	(GtkClassInitFunc) bst_snet_router_class_init,
-	(GtkObjectInitFunc) bst_snet_router_init,
-        /* reserved_1 */ NULL,
-	/* reserved_2 */ NULL,
-	(GtkClassInitFunc) NULL,
+      static const GTypeInfo type_info = {
+        sizeof (BstSNetRouterClass),
+        (GBaseInitFunc) NULL,
+        (GBaseFinalizeFunc) NULL,
+        (GClassInitFunc) bst_snet_router_class_init,
+        NULL,   /* class_finalize */
+        NULL,   /* class_data */
+        sizeof (BstSNetRouter),
+        0,      /* n_preallocs */
+        (GInstanceInitFunc) bst_snet_router_init,
       };
-      
-      snet_router_type = gtk_type_unique (GNOME_TYPE_CANVAS, &snet_router_info);
+      type = g_type_register_static (GNOME_TYPE_CANVAS, "BstSNetRouter", &type_info, 0);
     }
-  
-  return snet_router_type;
+  return type;
 }
 
 static void
@@ -111,7 +114,8 @@ bst_snet_router_class_init (BstSNetRouterClass *class)
   GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
   BseCategorySeq *cseq;
-  BstMenuConfig *m1, *m2;
+  BstMenuConfig *m1, *m2, *m3, *m4;
+  guint i;
 
   parent_class = g_type_class_peek_parent (class);
   bst_snet_router_class = class;
@@ -127,12 +131,29 @@ bst_snet_router_class_init (BstSNetRouterClass *class)
 
   /* standard entries */
   m1 = bst_menu_config_from_entries (G_N_ELEMENTS (popup_entries), popup_entries);
-  /* script entries */
-  cseq = bse_categories_match_typed ("/Modules/*", "BseSource");
-  m2 = bst_menu_config_from_cats (cseq, bst_router_popup_select, 1);
+  /* module entries */
+  cseq = bse_categories_match ("/Modules/*");
+  m2 = bst_menu_config_from_entries (0, NULL);
+  for (i = 0; i < cseq->n_cats; i++)
+    {
+      const gchar *stock_fallback = NULL;
+      if (strncmp (cseq->cats[i]->type, "BseLadspaModule_", 16) == 0)
+        stock_fallback = BST_STOCK_LADSPA;
+      bst_menu_config_append_cat (m2, cseq->cats[i], bst_router_popup_select, 1, NULL, stock_fallback);
+    }
   bst_menu_config_sort (m2);
+  /* SNet utilities */
+  cseq = bse_categories_match ("/SNet/*");
+  m3 = bst_menu_config_from_cats (cseq, bst_router_run_method, 1, NULL, BST_STOCK_EXECUTE);
+  bst_menu_config_sort (m3);
+  /* CSynth utilities */
+  cseq = bse_categories_match ("/CSynth/*");
+  m4 = bst_menu_config_from_cats (cseq, bst_router_run_method, 1, NULL, BST_STOCK_EXECUTE);
+  bst_menu_config_sort (m4);
   /* merge them */
   m1 = bst_menu_config_merge (m1, m2);
+  m1 = bst_menu_config_merge (m1, m3);
+  m1 = bst_menu_config_merge (m1, m4);
   /* create menu items */
   bst_menu_config_create_items (m1, class->popup_factory, NULL);
   /* cleanup */
@@ -238,7 +259,7 @@ bst_snet_router_viewable_changed (GtkWidget *widget)
 
   if (router->palette)
     {
-      gboolean show_palette = widget->window && gtk_widget_viewable (widget);
+      gboolean show_palette = widget->window && gxk_widget_viewable (widget);
 
       if (show_palette && router->reshow_palette)
 	{
@@ -279,18 +300,16 @@ bst_snet_router_set_snet (BstSNetRouter *router,
   if (router->snet)
     {
       bst_snet_router_destroy_contents (router);
-      
       bse_proxy_disconnect (router->snet,
 			    "any_signal", bst_snet_router_item_added, router,
 			    NULL);
-      bse_item_use (router->snet);	// FIXME: should we hold a use-count on the snet?
+      bse_item_unuse (router->snet);
       router->snet = 0;
     }
-  if (snet)
+  router->snet = snet;
+  if (router->snet)
     {
-      router->snet = snet;
-      bse_item_unuse (router->snet);
-      
+      bse_item_use (router->snet);	// FIXME: should we hold a use-count on the snet?
       bse_proxy_connect (router->snet,
 			 "swapped_signal::item_added", bst_snet_router_item_added, router,
 			 NULL);
@@ -319,10 +338,24 @@ bst_router_popup_select (GtkWidget *widget,
 			 gulong     category_id,
 			 gpointer   popup_data)
 {
-  BstSNetRouter *router = BST_SNET_ROUTER (widget);
+  BstSNetRouter *self = BST_SNET_ROUTER (widget);
 
-  if (router->rtools)
-    bst_radio_tools_set_tool (router->rtools, category_id);
+  if (self->rtools)
+    bst_radio_tools_set_tool (self->rtools, category_id);
+}
+
+static void
+bst_router_run_method (GtkWidget *widget,
+                       gulong     category_id,
+                       gpointer   popup_data)
+{
+  BstSNetRouter *self = BST_SNET_ROUTER (widget);
+  BseCategory *cat = bse_category_from_id (category_id);
+
+  bst_procedure_exec_auto (cat->type,
+                           "snet", SFI_TYPE_PROXY, self->snet,
+                           BSE_IS_CSYNTH (self->snet) ? "csynth" : "", SFI_TYPE_PROXY, self->snet,
+                           NULL);
 }
 
 static void
@@ -339,7 +372,7 @@ palette_ebox_button (BstSNetRouter  *self,
   GtkItemFactory *popup_factory = BST_SNET_ROUTER_GET_CLASS (self)->popup_factory;
 
   bst_menu_popup (popup_factory,
-		  self,
+		  GTK_WIDGET (self),
 		  NULL, NULL,
 		  event->x_root, event->y_root,
 		  event->button, event->time);
@@ -371,7 +404,7 @@ bst_snet_router_toggle_palette (BstSNetRouter *self)
 	  self->palette = g_object_connect (gxk_dialog_new (&self->palette,
 							    GTK_OBJECT (self),
 							    GXK_DIALOG_HIDE_ON_DELETE,
-							    "Palette",
+							    _("Palette"),
 							    bst_radio_tools_build_palette (self->rtools, ebox,
 											   TRUE, GTK_RELIEF_NORMAL)),
 					    "swapped_signal::hide", palette_reset, self,
@@ -539,26 +572,16 @@ bst_snet_router_build_tools (BstSNetRouter *self)
   for (i = 0; i < cseq->n_cats; i++)
     {
       static struct { gchar *type, *name, *tip; } toolbar_types[] = {
-	{ "BsePcmOutput", "Output", "PCM Output" },
-	{ "BseAmplifier", "DCA", "Amplifier" },
-	{ "BseSnooper", "Snoop", "Signal Debugging Tool" },
-	{ "BsePcmInput", "Input", "PCM Input" },
-      };
-      static const gchar *palette_cats[] = {
-	"/Modules/Audio Sources/", "/Modules/Filters/",
-	"/Modules/Input & Output/", "/Modules/MIDI/",
-	"/Modules/Other Sources/", "/Modules/Routing/",
-	"/Modules/Virtualization/", "/Modules/Distortion/",
+	{ "BsePcmOutput",       "Output", "PCM Output" },
+	{ "BseAmplifier",       "DCA", "Amplifier" },
+	{ "BseSnooper",         "Snoop", "Signal Debugging Tool" },
+	{ "BsePcmInput",        "Input", "PCM Input" },
       };
       guint n, is_palette = 0;
 
       /* decide whether this tool is displayed in the palette */
-      for (n = 0; n < G_N_ELEMENTS (palette_cats); n++)
-	if (strncmp (palette_cats[n], cseq->cats[i]->category, strlen (palette_cats[n])) == 0)
-	  {
-	    is_palette = TRUE;
-	    break;
-	  }
+      is_palette = cseq->cats[i]->icon && (cseq->cats[i]->icon->width + cseq->cats[i]->icon->height) > 0;
+
       /* add (all) tools */
       bst_radio_tools_add_category (self->rtools,
 				    cseq->cats[i]->category_id,
@@ -900,7 +923,7 @@ bst_snet_router_root_event (BstSNetRouter   *router,
 	  router->drag_is_input = ichannel != ~0;
 	  if (csource && at_channel && router->drag_is_input &&  /* ichannel in use */
 	      !bst_canvas_source_ichannel_free (csource, ichannel))
-	    gxk_status_set (GXK_STATUS_ERROR, "Input channel in use", NULL);
+	    gxk_status_set (GXK_STATUS_ERROR, _("Input channel in use"), NULL);
 	  else if (csource && at_channel) /* i/o link */
 	    {
 	      GnomeCanvasPoints *gpoints = gnome_canvas_points_new (2);
@@ -927,9 +950,9 @@ bst_snet_router_root_event (BstSNetRouter   *router,
 	      router->world_y = event->button.y;	/* event coords are world already */
 	      bst_radio_tools_set_tool (router->rtools, ROUTER_TOOL_CREATE_LINK);
 	      if (router->drag_is_input)
-		gxk_status_set (GXK_STATUS_WAIT, "Create Link", "Select output module");
+		gxk_status_set (GXK_STATUS_WAIT, _("Create Link"), _("Select output module"));
 	      else
-		gxk_status_set (GXK_STATUS_WAIT, "Create Link", "Select input module");
+		gxk_status_set (GXK_STATUS_WAIT, _("Create Link"), _("Select input module"));
 	      handled = TRUE;
 	    }
 	  else if (csource && csource->source != router->snet)
@@ -937,7 +960,7 @@ bst_snet_router_root_event (BstSNetRouter   *router,
 	      if (event->button.state & GDK_SHIFT_MASK)
 		bst_canvas_source_toggle_info (csource);
 	      else
-		bst_canvas_source_toggle_view (csource);
+		bst_canvas_source_toggle_params (csource);
 	    }
 	  else if (clink && !csource)
 	    bst_canvas_link_toggle_view (clink);
@@ -965,7 +988,7 @@ bst_snet_router_root_event (BstSNetRouter   *router,
 	      router->drag_csource = NULL;
 	      router->drag_channel = ~0;
 	      bst_snet_router_reset_tool (router);
-	      bst_status_eprintf (error, "Create Link");
+	      bst_status_eprintf (error, _("Create Link"));
 	    }
 	  handled = TRUE;
 	}
@@ -985,24 +1008,24 @@ bst_snet_router_root_event (BstSNetRouter   *router,
 	      choice = bst_choice_menu_createv ("<BEAST-SNetRouter>/ModulePopup",
 						BST_CHOICE_TITLE (source_name),
 						BST_CHOICE_SEPERATOR,
-						BST_CHOICE_S (2, "Properties", PROPERTIES, csource->source != router->snet),
-						BST_CHOICE_S (3, "Delete Inputs", NO_ILINK, has_inputs),
-						BST_CHOICE_S (4, "Delete Outputs", NO_OLINK, bse_source_has_outputs (csource->source)),
-						BST_CHOICE (5, "Show Info", INFO),
+						BST_CHOICE (2, _("Properties"), PROPERTIES),
+						BST_CHOICE (6, _("Reset Properties"), PROPERTIES_RESET),
+						BST_CHOICE_S (3, _("Delete Inputs"), NO_ILINK, has_inputs),
+						BST_CHOICE_S (4, _("Delete Outputs"), NO_OLINK, bse_source_has_outputs (csource->source)),
+						BST_CHOICE (5, _("Show Info"), INFO),
 						BST_CHOICE_SEPERATOR,
-						BST_CHOICE_S (1, "Delete", DELETE, csource->source != router->snet),
+						BST_CHOICE_S (1, _("Delete"), DELETE, csource->source != router->snet),
 						BST_CHOICE_END);
 	      g_free (source_name);
 	      i = bst_choice_modal (choice, event->button.button, event->button.time);
 	      switch (i)
 		{
 		  BseErrorType error;
-		case 1:
-		  error = bse_snet_remove_source (router->snet, csource->source);
-		  bst_status_eprintf (error, "Remove Module");
-		  break;
 		case 2:
-		  bst_canvas_source_popup_view (csource);
+		  bst_canvas_source_popup_params (csource);
+		  break;
+		case 6:
+		  bst_canvas_source_reset_params (csource);
 		  break;
 		case 3:
 		  bse_source_clear_inputs (csource->source);
@@ -1013,6 +1036,10 @@ bst_snet_router_root_event (BstSNetRouter   *router,
 		case 5:
 		  bst_canvas_source_popup_info (csource);
 		  break;
+		case 1:
+		  error = bse_snet_remove_source (router->snet, csource->source);
+		  bst_status_eprintf (error, _("Remove Module"));
+		  break;
 		}
 	      bst_choice_destroy (choice);
 	      /* FIXME: get rid of artifacts left behind removal (mostly rect-ellipse) */
@@ -1025,11 +1052,11 @@ bst_snet_router_root_event (BstSNetRouter   *router,
 	      guint i;
 
 	      choice = bst_choice_menu_createv ("<BEAST-SNetRouter>/LinkPopup",
-						BST_CHOICE_TITLE ("Module link"),
+						BST_CHOICE_TITLE (_("Module link")),
 						BST_CHOICE_SEPERATOR,
-                                                BST_CHOICE (2, "Show Info", INFO),
+                                                BST_CHOICE (2, _("Show Info"), INFO),
 						BST_CHOICE_SEPERATOR,
-						BST_CHOICE (1, "Delete", DELETE),
+						BST_CHOICE (1, _("Delete"), DELETE),
 						BST_CHOICE_END);
 	      i = bst_choice_modal (choice, event->button.button, event->button.time);
 	      switch (i)
@@ -1038,7 +1065,7 @@ bst_snet_router_root_event (BstSNetRouter   *router,
 		case 1:
 		  error = bse_source_unset_input_by_id (clink->icsource->source, clink->ichannel,
 							clink->ocsource->source, clink->ochannel);
-		  bst_status_eprintf (error, "Delete Link");
+		  bst_status_eprintf (error, _("Delete Link"));
 		  break;
 		case 2:
 		  bst_canvas_link_popup_view (clink);
@@ -1080,17 +1107,19 @@ bst_snet_router_event (GtkWidget *widget,
 	  error = bse_snet_can_create_source (router->snet, cat->type);
 	  if (!error)
 	    {
-	      SfiProxy module = bse_snet_create_source (router->snet, cat->type);
-	      bse_proxy_set (module,
-			     "pos_x", router->world_x / BST_CANVAS_SOURCE_PIXEL_SCALE,
-			     "pos_y", -router->world_y / BST_CANVAS_SOURCE_PIXEL_SCALE,
-			     NULL);
+	      SfiProxy module;
+              bse_item_group_undo (router->snet, "Create Module");
+              module = bse_snet_create_source (router->snet, cat->type);
+              bse_source_set_pos (module,
+                                  router->world_x / BST_CANVAS_SOURCE_PIXEL_SCALE,
+                                  router->world_y / -BST_CANVAS_SOURCE_PIXEL_SCALE);
+              bse_item_ungroup_undo (router->snet);
 	    }
 	  if (BST_SNET_EDIT_FALLBACK)
 	    bst_radio_tools_set_tool (router->rtools, 0);
 	  router->world_x = 0;
 	  router->world_y = 0;
-	  bst_status_eprintf (error, "Insert Module");
+	  bst_status_eprintf (error, _("Insert Module"));
 	}
       else if (event->button.button != 1 && router->rtools->tool_id == ROUTER_TOOL_CREATE_LINK)
 	{
