@@ -18,7 +18,7 @@
 #include "bstsplash.h"
 
 
-#include "PKG_config.h"
+#include "topconfig.h"
 #include <string.h>
 
 
@@ -124,7 +124,7 @@ bst_splash_init (BstSplash *self)
   gtk_box_pack_end (GTK_BOX (self->vbox), any, FALSE, TRUE, 5);
   self->item = g_object_new (GTK_TYPE_LABEL,
 			     "visible", TRUE,
-			     "label", "Item",
+			     "label", "Item",           /* untranslated template name */
 			     "width_request", 1,
 			     "parent", any,
 			     NULL);
@@ -138,7 +138,7 @@ bst_splash_init (BstSplash *self)
   gtk_box_pack_end (GTK_BOX (self->vbox), any, FALSE, TRUE, 10);
   self->entity = g_object_new (GTK_TYPE_LABEL,
 			       "visible", TRUE,
-			       "label", "Entity",
+			       "label", "Entity",       /* untranslated template name */
 			       "width_request", 1,
 			       "parent", any,
 			       NULL);
@@ -184,8 +184,8 @@ bst_splash_unrealize (GtkWidget *widget)
 {
   BstSplash *self = BST_SPLASH (widget);
 
-  if (!BST_VERSION_STABLE && self->item_count > self->max_items)
-    g_message ("BstSplash: seen %u/%u items (+%u)",
+  if (BST_DBG_EXT) /* && self->item_count > self->max_items */
+    g_message ("BstSplash: seen %u/%u items (%+d)",
 	       self->item_count, self->max_items,
 	       self->item_count - self->max_items);
 
