@@ -65,13 +65,13 @@ bst_track_roll_controller_new (BstTrackRoll *troll)
 		    NULL);
   {
     BstTool radio_tools[] = {
-      { CKEY ("TrackRoll/Insert"),	BST_TRACK_ROLL_TOOL_INSERT,	BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("TrackRoll/Link"),	BST_TRACK_ROLL_TOOL_LINK,	BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("TrackRoll/Delete"),	BST_TRACK_ROLL_TOOL_DELETE,	BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("TrackRoll/Editor"),	BST_TRACK_ROLL_TOOL_EDITOR_ONCE, BST_RADIO_TOOLS_EVERYWHERE },
+      { CKEY ("TrackRoll/Insert"),	BST_GENERIC_ROLL_TOOL_INSERT,	BST_RADIO_TOOLS_EVERYWHERE },
+      { CKEY ("TrackRoll/Link"),	BST_GENERIC_ROLL_TOOL_LINK,	BST_RADIO_TOOLS_EVERYWHERE },
+      { CKEY ("TrackRoll/Rename"),	BST_GENERIC_ROLL_TOOL_RENAME,	BST_RADIO_TOOLS_EVERYWHERE },
+      { CKEY ("TrackRoll/Delete"),	BST_GENERIC_ROLL_TOOL_DELETE,   BST_RADIO_TOOLS_EVERYWHERE },
     };
     bst_radio_tools_add_tools (self->canvas_rtools, G_N_ELEMENTS (radio_tools), radio_tools);
-    bst_radio_tools_set_tool (self->canvas_rtools, BST_TRACK_ROLL_TOOL_INSERT);
+    bst_radio_tools_set_tool (self->canvas_rtools, BST_GENERIC_ROLL_TOOL_INSERT);
   }
   /* register hpanel tools */
   self->hpanel_rtools = bst_radio_tools_new ();
@@ -80,12 +80,12 @@ bst_track_roll_controller_new (BstTrackRoll *troll)
 		    NULL);
   {
     BstTool radio_tools[] = {
-      { CKEY ("TrackRoll/TickLeft"),	BST_TRACK_ROLL_TOOL_MOVE_TICK_LEFT,	BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("TrackRoll/TickPos"),	BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER,	BST_RADIO_TOOLS_EVERYWHERE },
-      { CKEY ("TrackRoll/TickRight"),	BST_TRACK_ROLL_TOOL_MOVE_TICK_RIGHT,	BST_RADIO_TOOLS_EVERYWHERE },
+      { CKEY ("TrackRoll/TickLeft"),	BST_GENERIC_ROLL_TOOL_MOVE_TICK_LEFT,	  BST_RADIO_TOOLS_EVERYWHERE },
+      { CKEY ("TrackRoll/TickPos"),	BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER,  BST_RADIO_TOOLS_EVERYWHERE },
+      { CKEY ("TrackRoll/TickRight"),	BST_GENERIC_ROLL_TOOL_MOVE_TICK_RIGHT,	  BST_RADIO_TOOLS_EVERYWHERE },
     };
     bst_radio_tools_add_tools (self->hpanel_rtools, G_N_ELEMENTS (radio_tools), radio_tools);
-    bst_radio_tools_set_tool (self->hpanel_rtools, BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER);
+    bst_radio_tools_set_tool (self->hpanel_rtools, BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER);
   }
   /* register quantization tools */
   self->quant_rtools = bst_radio_tools_new ();
@@ -106,38 +106,38 @@ bst_track_roll_controller_new (BstTrackRoll *troll)
   return self;
 }
 
-static BstTrackRollTool
+static BstGenericRollTool
 hpanel_button_tool (BstTrackRollController *self,
 		    guint                   button)
 {
   switch (self->hpanel_rtools->tool_id)	/* user selected tool */
     {
-    case BST_TRACK_ROLL_TOOL_MOVE_TICK_LEFT:
+    case BST_GENERIC_ROLL_TOOL_MOVE_TICK_LEFT:
       switch (button)
 	{
-	case 1:	 return BST_TRACK_ROLL_TOOL_MOVE_TICK_LEFT;
-	case 2:	 return BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER;
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:	 return BST_GENERIC_ROLL_TOOL_MOVE_TICK_LEFT;
+	case 2:	 return BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER;
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER:
+    case BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER:
       switch (button)
 	{
-	case 1:	 return BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER;
-	case 2:	 return BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER;
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:	 return BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER;
+	case 2:	 return BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER;
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_MOVE_TICK_RIGHT:
+    case BST_GENERIC_ROLL_TOOL_MOVE_TICK_RIGHT:
       switch (button)
 	{
-	case 1:	 return BST_TRACK_ROLL_TOOL_MOVE_TICK_RIGHT;
-	case 2:	 return BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER;
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:	 return BST_GENERIC_ROLL_TOOL_MOVE_TICK_RIGHT;
+	case 2:	 return BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER;
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
     }
-  return BST_TRACK_ROLL_TOOL_NONE;
+  return BST_GENERIC_ROLL_TOOL_NONE;
 }
 
-static BstTrackRollTool
+static BstGenericRollTool
 canvas_button_tool (BstTrackRollController *self,
 		    guint                   button,
 		    guint                   have_object)
@@ -145,79 +145,79 @@ canvas_button_tool (BstTrackRollController *self,
   switch (self->canvas_rtools->tool_id | /* user selected tool */
 	  (have_object ? HAVE_OBJECT : 0))
     {
-    case BST_TRACK_ROLL_TOOL_INSERT | HAVE_OBJECT:
+    case BST_GENERIC_ROLL_TOOL_INSERT | HAVE_OBJECT:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_EDIT_NAME;
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_EDITOR;
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_INSERT:
+    case BST_GENERIC_ROLL_TOOL_INSERT:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_INSERT;
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;	/* error */
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_INSERT;
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;	/* error */
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_LINK | HAVE_OBJECT:
+    case BST_GENERIC_ROLL_TOOL_LINK | HAVE_OBJECT:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_LINK;
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_LINK;
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_LINK:
+    case BST_GENERIC_ROLL_TOOL_LINK:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_LINK;
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;	/* error */
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_LINK;
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;	/* error */
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_EDIT_NAME | HAVE_OBJECT:
+    case BST_GENERIC_ROLL_TOOL_RENAME | HAVE_OBJECT:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_EDIT_NAME;
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_RENAME;
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_EDIT_NAME:
+    case BST_GENERIC_ROLL_TOOL_RENAME:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_EDIT_NAME;	/* error */
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;	/* error */
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_RENAME;	/* error */
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;	/* error */
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_DELETE | HAVE_OBJECT:
+    case BST_GENERIC_ROLL_TOOL_DELETE | HAVE_OBJECT:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_DELETE;
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_DELETE;
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_DELETE:
+    case BST_GENERIC_ROLL_TOOL_DELETE:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_DELETE;	/* error */
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;	/* error */
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_DELETE;	/* error */
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;	/* error */
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_EDITOR_ONCE | HAVE_OBJECT:
+    case BST_GENERIC_ROLL_TOOL_EDITOR | HAVE_OBJECT:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_EDITOR_ONCE;
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_EDITOR;
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
-    case BST_TRACK_ROLL_TOOL_EDITOR_ONCE:
+    case BST_GENERIC_ROLL_TOOL_EDITOR:
       switch (button)
 	{
-	case 1:  return BST_TRACK_ROLL_TOOL_EDITOR_ONCE;	/* error */
-	case 2:  return BST_TRACK_ROLL_TOOL_MOVE;		/* error */
-	default: return BST_TRACK_ROLL_TOOL_NONE;
+	case 1:  return BST_GENERIC_ROLL_TOOL_EDITOR;     	/* error */
+	case 2:  return BST_GENERIC_ROLL_TOOL_MOVE;		/* error */
+	default: return BST_GENERIC_ROLL_TOOL_NONE;
 	}
       break;
     }
-  return BST_TRACK_ROLL_TOOL_NONE;
+  return BST_GENERIC_ROLL_TOOL_NONE;
 }
 
 BstTrackRollController*
@@ -240,11 +240,11 @@ bst_track_roll_controller_unref (BstTrackRollController *self)
   self->ref_count--;
   if (!self->ref_count)
     {
-      bst_radio_tools_destroy (self->canvas_rtools);
+      bst_radio_tools_dispose (self->canvas_rtools);
       g_object_unref (self->canvas_rtools);
-      bst_radio_tools_destroy (self->hpanel_rtools);
+      bst_radio_tools_dispose (self->hpanel_rtools);
       g_object_unref (self->hpanel_rtools);
-      bst_radio_tools_destroy (self->quant_rtools);
+      bst_radio_tools_dispose (self->quant_rtools);
       g_object_unref (self->quant_rtools);
       g_free (self);
     }
@@ -319,13 +319,13 @@ controller_update_hpanel_cursor (BstTrackRollController *self,
 {
   switch (tool_id)
     {
-    case BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER:
+    case BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER:
       bst_track_roll_set_hpanel_cursor (self->troll, GDK_SB_DOWN_ARROW);
       break;
-    case BST_TRACK_ROLL_TOOL_MOVE_TICK_LEFT:
+    case BST_GENERIC_ROLL_TOOL_MOVE_TICK_LEFT:
       bst_track_roll_set_hpanel_cursor (self->troll, GDK_LEFT_SIDE);
       break;
-    case BST_TRACK_ROLL_TOOL_MOVE_TICK_RIGHT:
+    case BST_GENERIC_ROLL_TOOL_MOVE_TICK_RIGHT:
       bst_track_roll_set_hpanel_cursor (self->troll, GDK_RIGHT_SIDE);
       break;
     default:
@@ -340,22 +340,22 @@ controller_update_canvas_cursor (BstTrackRollController *self,
 {
   switch (tool_id)
     {
-    case BST_TRACK_ROLL_TOOL_INSERT:
+    case BST_GENERIC_ROLL_TOOL_INSERT:
       bst_track_roll_set_canvas_cursor (self->troll, GDK_PENCIL);
       break;
-    case BST_TRACK_ROLL_TOOL_LINK:
+    case BST_GENERIC_ROLL_TOOL_LINK:
       bst_track_roll_set_canvas_cursor (self->troll, GDK_DIAMOND_CROSS);
       break;
-    case BST_TRACK_ROLL_TOOL_EDIT_NAME:
+    case BST_GENERIC_ROLL_TOOL_RENAME:
       bst_track_roll_set_canvas_cursor (self->troll, GXK_DEFAULT_CURSOR);
       break;
-    case BST_TRACK_ROLL_TOOL_MOVE:
+    case BST_GENERIC_ROLL_TOOL_MOVE:
       bst_track_roll_set_canvas_cursor (self->troll, GDK_FLEUR);
       break;
-    case BST_TRACK_ROLL_TOOL_DELETE:
+    case BST_GENERIC_ROLL_TOOL_DELETE:
       bst_track_roll_set_canvas_cursor (self->troll, GDK_TARGET);
       break;
-    case BST_TRACK_ROLL_TOOL_EDITOR_ONCE:
+    case BST_GENERIC_ROLL_TOOL_EDITOR:
       bst_track_roll_set_canvas_cursor (self->troll, GDK_HAND2);
       break;
     default:
@@ -382,10 +382,10 @@ edit_name_start (BstTrackRollController *self,
 				 GTK_CELL_EDITABLE (entry));
       g_signal_connect_data (entry, "editing_done", G_CALLBACK (bst_track_roll_stop_edit),
 			     self->troll, NULL, G_CONNECT_SWAPPED);
-      controller_update_canvas_cursor (self, BST_TRACK_ROLL_TOOL_EDIT_NAME);
+      controller_update_canvas_cursor (self, BST_GENERIC_ROLL_TOOL_RENAME);
     }
   else
-    gxk_status_set (GXK_STATUS_ERROR, "Edit Part", "No Part");
+    gxk_status_set (GXK_STATUS_ERROR, _("Edit Part"), _("No Part"));
   drag->state = BST_DRAG_HANDLED;
 }
 
@@ -397,7 +397,7 @@ controller_stop_edit (BstTrackRollController *self,
   if (!canceled)
     {
       bse_item_set_name (self->obj_part, gtk_entry_get_text (GTK_ENTRY (ecell)));
-      gxk_status_set (GXK_STATUS_DONE, "Edit Part", NULL);
+      gxk_status_set (GXK_STATUS_DONE, _("Edit Part"), NULL);
     }
   controller_update_canvas_cursor (self, self->canvas_rtools->tool_id);
 }
@@ -416,21 +416,21 @@ insert_start (BstTrackRollController *self,
           bse_item_group_undo (song, "Insert part");
 	  item = bse_song_create_part (song);
 	  if (item && bse_track_insert_part (drag->current_track, tick, item) > 0)
-	    gxk_status_set (GXK_STATUS_DONE, "Insert Part", NULL);
+	    gxk_status_set (GXK_STATUS_DONE, _("Insert Part"), NULL);
 	  else
-	    gxk_status_set (GXK_STATUS_ERROR, "Insert Part", "Lost Part");
+	    gxk_status_set (GXK_STATUS_ERROR, _("Insert Part"), _("Lost Part"));
           bse_item_ungroup_undo (song);
 	  drag->state = BST_DRAG_HANDLED;
 	}
       else
-	gxk_status_set (GXK_STATUS_ERROR, "Insert Part", "Position taken");
+	gxk_status_set (GXK_STATUS_ERROR, _("Insert Part"), _("Position taken"));
     }
   else
     {
       if (self->obj_part)
-	gxk_status_set (GXK_STATUS_ERROR, "Insert Part", "Position taken");
+	gxk_status_set (GXK_STATUS_ERROR, _("Insert Part"), _("Position taken"));
       else
-	gxk_status_set (GXK_STATUS_ERROR, "Insert part", "No Track");
+	gxk_status_set (GXK_STATUS_ERROR, _("Insert part"), _("No Track"));
       drag->state = BST_DRAG_HANDLED;
     }
 }
@@ -442,10 +442,10 @@ delete_start (BstTrackRollController *self,
   if (self->obj_part)	/* got part to delete */
     {
       bse_track_remove_tick (self->obj_track, self->obj_tick);
-      gxk_status_set (GXK_STATUS_DONE, "Delete Part", NULL);
+      gxk_status_set (GXK_STATUS_DONE, _("Delete Part"), NULL);
     }
   else
-    gxk_status_set (GXK_STATUS_ERROR, "Delete Part", "No target");
+    gxk_status_set (GXK_STATUS_ERROR, _("Delete Part"), _("No target"));
   drag->state = BST_DRAG_HANDLED;
 }
 
@@ -454,18 +454,18 @@ move_link_start (BstTrackRollController *self,
 		 BstTrackRollDrag       *drag,
 		 gboolean		 link_pending)
 {
-  const gchar *action = link_pending ? "Link Part" : "Move Part";
+  const gchar *action = link_pending ? _("Link Part") : _("Move Part");
   if (self->obj_part)	/* got part to move */
     {
       self->xoffset = drag->start_tick - self->obj_tick;	/* drag offset */
-      controller_update_canvas_cursor (self, link_pending ? BST_TRACK_ROLL_TOOL_LINK : BST_TRACK_ROLL_TOOL_MOVE);
+      controller_update_canvas_cursor (self, link_pending ? BST_GENERIC_ROLL_TOOL_LINK : BST_GENERIC_ROLL_TOOL_MOVE);
       gxk_status_set (GXK_STATUS_PROGRESS, action, NULL);
       drag->state = BST_DRAG_CONTINUE;
       self->skip_deletion = link_pending;
     }
   else
     {
-      gxk_status_set (GXK_STATUS_ERROR, action, "No target");
+      gxk_status_set (GXK_STATUS_ERROR, action, _("No target"));
       drag->state = BST_DRAG_HANDLED;
     }
 }
@@ -488,7 +488,7 @@ static void
 move_motion (BstTrackRollController *self,
 	     BstTrackRollDrag       *drag)
 {
-  const gchar *action = self->skip_deletion ? "Link Part" : "Move Part";
+  const gchar *action = self->skip_deletion ? _("Link Part") : _("Move Part");
   gint new_tick;
   gboolean track_changed;
 
@@ -505,7 +505,7 @@ move_motion (BstTrackRollController *self,
 	  else
 	    {
 	      self->skip_deletion = FALSE;
-	      controller_update_canvas_cursor (self, BST_TRACK_ROLL_TOOL_MOVE);
+	      controller_update_canvas_cursor (self, BST_GENERIC_ROLL_TOOL_MOVE);
 	    }
 	  self->obj_track = drag->current_track;
 	  self->obj_tick = new_tick;
@@ -520,24 +520,24 @@ static void
 move_abort (BstTrackRollController *self,
 	    BstTrackRollDrag       *drag)
 {
-  gxk_status_set (GXK_STATUS_ERROR, "Move Part", "Lost Part");
+  gxk_status_set (GXK_STATUS_ERROR, _("Move Part"), _("Lost Part"));
 }
 
 static void
-editor_once (BstTrackRollController *self,
-	     BstTrackRollDrag       *drag)
+editor_create (BstTrackRollController *self,
+               BstTrackRollDrag       *drag)
 {
   if (self->obj_part)	/* got part */
     {
       GtkWidget *pdialog = g_object_new (BST_TYPE_PART_DIALOG, NULL);
       bst_part_dialog_set_proxy (BST_PART_DIALOG (pdialog), self->obj_part);
       g_signal_connect_object (self->troll, "destroy", G_CALLBACK (gtk_widget_destroy), pdialog, G_CONNECT_SWAPPED);
-      gxk_status_set (GXK_STATUS_DONE, "Start Editor", NULL);
+      gxk_status_set (GXK_STATUS_DONE, _("Start Editor"), NULL);
       gtk_widget_show (pdialog);
-      bst_radio_tools_set_tool (self->canvas_rtools, BST_TRACK_ROLL_TOOL_INSERT);
+      bst_radio_tools_set_tool (self->canvas_rtools, BST_GENERIC_ROLL_TOOL_INSERT);
     }
   else
-    gxk_status_set (GXK_STATUS_ERROR, "Start Editor", "No target");
+    gxk_status_set (GXK_STATUS_ERROR, _("Start Editor"), _("No target"));
   drag->state = BST_DRAG_HANDLED;
 }
 
@@ -582,7 +582,7 @@ typedef void (*DragFunc) (BstTrackRollController *,
 			  BstTrackRollDrag       *);
 struct _BstTrackRollUtil
 {
-  BstTrackRollTool tool;
+  BstGenericRollTool tool;
   DragFunc start, motion, abort;
 };
 
@@ -591,23 +591,23 @@ controller_drag (BstTrackRollController *self,
 		 BstTrackRollDrag       *drag)
 {
   static const BstTrackRollUtil canvas_tool_table[] = {
-    { BST_TRACK_ROLL_TOOL_INSERT,	insert_start,		NULL,		NULL,		},
-    { BST_TRACK_ROLL_TOOL_MOVE,		move_start,		move_motion,	move_abort,	},
-    { BST_TRACK_ROLL_TOOL_LINK,		link_start,		move_motion,	move_abort,	},
-    { BST_TRACK_ROLL_TOOL_DELETE,	delete_start,		NULL,		NULL,		},
-    { BST_TRACK_ROLL_TOOL_EDIT_NAME,	edit_name_start,	NULL,		NULL,		},
-    { BST_TRACK_ROLL_TOOL_EDITOR_ONCE,	editor_once,		NULL,		NULL,		},
+    { BST_GENERIC_ROLL_TOOL_INSERT,	insert_start,		NULL,		NULL,		},
+    { BST_GENERIC_ROLL_TOOL_MOVE,	move_start,		move_motion,	move_abort,	},
+    { BST_GENERIC_ROLL_TOOL_LINK,	link_start,		move_motion,	move_abort,	},
+    { BST_GENERIC_ROLL_TOOL_DELETE,	delete_start,		NULL,		NULL,		},
+    { BST_GENERIC_ROLL_TOOL_RENAME,	edit_name_start,	NULL,		NULL,		},
+    { BST_GENERIC_ROLL_TOOL_EDITOR,	editor_create,		NULL,		NULL,		},
   };
   static const BstTrackRollUtil hpanel_tool_table[] = {
-    { BST_TRACK_ROLL_TOOL_MOVE_TICK_POINTER,	pointer_move,	 pointer_move,	  NULL,		},
-    { BST_TRACK_ROLL_TOOL_MOVE_TICK_LEFT,	tick_left_move,	 tick_left_move,  NULL,		},
-    { BST_TRACK_ROLL_TOOL_MOVE_TICK_RIGHT,	tick_right_move, tick_right_move, NULL,		},
+    { BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER,	pointer_move,	 pointer_move,	  NULL,		},
+    { BST_GENERIC_ROLL_TOOL_MOVE_TICK_LEFT,	tick_left_move,	 tick_left_move,  NULL,		},
+    { BST_GENERIC_ROLL_TOOL_MOVE_TICK_RIGHT,	tick_right_move, tick_right_move, NULL,		},
   };
 
   /* initial drag handling */
   if (drag->type == BST_DRAG_START)
     {
-      BstTrackRollTool obj_tool, tool;
+      BstGenericRollTool obj_tool, tool;
       BseTrackPart *tpart = NULL;
       const BstTrackRollUtil *tool_table;
       guint i, n_tools;
