@@ -91,6 +91,34 @@ _bst_init_utils (void)
   }
 }
 
+GtkWidget*
+bst_stock_button (const gchar *stock_id)
+{
+  GtkWidget *w = gtk_button_new_from_stock (stock_id);
+  gtk_widget_show_all (w);
+  return w;
+}
+
+GtkWidget*
+bst_stock_dbutton (const gchar *stock_id)
+{
+  GtkWidget *w = bst_stock_button (stock_id);
+  g_object_set (w, "can-default", TRUE, NULL);
+  return w;
+}
+
+GtkWidget*
+bst_stock_icon_button (const gchar *stock_id)
+{
+  GtkWidget *w = g_object_new (GTK_TYPE_BUTTON,
+                               "visible", TRUE,
+                               "child", gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON),
+                               "can-focus", FALSE,
+                               NULL);
+  gtk_widget_show_all (w);
+  return w;
+}
+
 GtkWidget*
 bst_image_from_icon (BseIcon    *icon,
 		     GtkIconSize icon_size)
@@ -220,6 +248,137 @@ bst_window_sync_title_to_proxy (gpointer     window,
 }
 
 
+/* --- packing utilities --- */
+#define SPACING 3
+static void
+bst_util_pack (GtkWidget   *widget,
+               const gchar *location,
+               guint        spacing,
+               va_list      args)
+{
+  GtkBox *box = GTK_BOX (widget);
+  while (location)
+    {
+      gchar *t, **toks = g_strsplit (location, ":", -1);
+      guint border = 0, padding = 0, i = 0;
+      gboolean fill = FALSE, expand = FALSE, start = TRUE;
+      GtkWidget *child;
+      t = toks[i++];
+      if (t && t[0] >= '0' && t[0] <= '9')
+        {
+          border = g_ascii_strtoull (t, NULL, 10);
+          t = toks[i++];
+        }
+      if (t && t[0] == '+')
+        {
+          expand = TRUE;
+          t = toks[i++];
+        }
+      if (t && t[0] == '*')
+        {
+          expand = fill = TRUE;
+          t = toks[i++];
+        }
+      if (t && t[0] == 'H')
+        {
+          gtk_box_set_homogeneous (box, TRUE);
+          expand = fill = TRUE;
+          t = toks[i++];
+        }
+      if (t && t[0] == 's')
+        {
+          start = TRUE;
+          t = toks[i++];
+        }
+      if (t && t[0] == 'e')
+        {
+          start = FALSE;
+          t = toks[i++];
+        }
+      if (t && t[0] == 'p')
+        {
+          padding = g_ascii_strtoull (t + 1, NULL, 10);
+          t = toks[i++];
+        }
+      g_strfreev (toks);
+      child = va_arg (args, GtkWidget*);
+      if (child)
+        {
+          if (border)
+            child = g_object_new (GTK_TYPE_ALIGNMENT,
+                                  "child", child,
+                                  "border_width", border * spacing,
+                                  NULL);
+          if (start)
+            gtk_box_pack_start (box, child, expand, fill, padding);
+          else
+            gtk_box_pack_end (box, child, expand, fill, padding);
+        }
+      location = va_arg (args, gchar*);
+    }
+}
+
+GtkWidget*
+bst_vpack (const gchar *first_location,
+           ...)
+{
+  va_list args;
+  GtkWidget *box = g_object_new (GTK_TYPE_VBOX,
+                                 "spacing", SPACING,
+                                 NULL);
+  va_start (args, first_location);
+  bst_util_pack (box, first_location, SPACING, args);
+  va_end (args);
+  gtk_widget_show_all (box);
+  return box;
+}
+
+GtkWidget*
+bst_hpack (const gchar *first_location,
+           ...)
+{
+  va_list args;
+  GtkWidget *box = g_object_new (GTK_TYPE_HBOX,
+                                 "spacing", SPACING,
+                                 NULL);
+  va_start (args, first_location);
+  bst_util_pack (box, first_location, SPACING, args);
+  va_end (args);
+  gtk_widget_show_all (box);
+  return box;
+}
+
+GtkWidget*
+bst_vpack0 (const gchar *first_location,
+            ...)
+{
+  va_list args;
+  GtkWidget *box = g_object_new (GTK_TYPE_VBOX,
+                                 "spacing", 0,
+                                 NULL);
+  va_start (args, first_location);
+  bst_util_pack (box, first_location, SPACING, args);
+  va_end (args);
+  gtk_widget_show_all (box);
+  return box;
+}
+
+GtkWidget*
+bst_hpack0 (const gchar *first_location,
+            ...)
+{
+  va_list args;
+  GtkWidget *box = g_object_new (GTK_TYPE_HBOX,
+                                 "spacing", 0,
+                                 NULL);
+  va_start (args, first_location);
+  bst_util_pack (box, first_location, SPACING, args);
+  va_end (args);
+  gtk_widget_show_all (box);
+  return box;
+}
+
+
 /* --- field mask --- */
 static GQuark gmask_quark = 0;
 typedef struct {
@@ -1056,6 +1215,62 @@ bst_xpm_view_create (const gchar **xpm,
   return pix;
 }
 
+static gchar*
+item_factory_translate (const gchar *path,
+                        gpointer     func_data)
+{
+  return gettext (path);
+}
+
+GtkItemFactory*
+bst_item_factory_new (GType          container_type,
+                      const gchar   *path)
+{
+  GtkItemFactory *ifac = gtk_item_factory_new (container_type, path, NULL);
+  gtk_item_factory_set_translate_func (ifac, item_factory_translate, NULL, NULL);
+  return ifac;
+}
+
+
+/* --- file utils --- */
+#include <sfi/sfistore.h>
+
+static gboolean
+song_name_scanner (SfiRStore      *rstore,
+                   gpointer        data)
+{
+  if (g_scanner_peek_next_token (rstore->scanner) == G_TOKEN_STRING)
+    {
+      g_scanner_get_next_token (rstore->scanner);
+      if (strncmp (rstore->scanner->value.v_string, "BseSong::", 9) == 0)
+        {
+          gchar **rval = data;
+          *rval = g_strdup (rstore->scanner->value.v_string + 9);
+          return FALSE;
+        }
+    }
+  return TRUE;
+}
+
+gchar*
+bst_file_scan_song_name (const gchar *file)
+{
+  SfiRStore *rstore;
+
+  g_return_val_if_fail (file != NULL, NULL);
+
+  rstore = sfi_rstore_new_open (file);
+  if (rstore)
+    {
+      gchar *name = NULL;
+      sfi_rstore_quick_scan (rstore, "container-child", song_name_scanner, &name);
+      sfi_rstore_destroy (rstore);
+      return name;
+    }
+  else
+    return NULL;
+}
+
 
 /* --- source file key scans --- */
 #include "bstdebugkeys.defs"
