@@ -48,6 +48,29 @@ typedef struct {
 #define	BST_STOCK_WARNING		GTK_STOCK_DIALOG_WARNING
 #define	BST_STOCK_ERROR			GTK_STOCK_DIALOG_ERROR
 
+#define BST_STOCK_NEW	                GTK_STOCK_NEW
+#define BST_STOCK_OPEN	                GTK_STOCK_OPEN
+#define BST_STOCK_MERGE	                GTK_STOCK_OPEN // FIXME
+#define BST_STOCK_SAVE	                GTK_STOCK_SAVE
+#define BST_STOCK_SAVE_AS	        GTK_STOCK_SAVE_AS
+#define BST_STOCK_PREFERENCES	        GTK_STOCK_PREFERENCES
+#define BST_STOCK_QUIT	                GTK_STOCK_QUIT
+#define BST_STOCK_CLEAR_UNDO	        GTK_STOCK_DELETE // FIXME
+#define BST_STOCK_PREFERENCES	        GTK_STOCK_PREFERENCES
+#define BST_STOCK_PLAY	                GTK_STOCK_GO_FORWARD // FIXME
+#define BST_STOCK_STOP	                GTK_STOCK_STOP
+#define BST_STOCK_NEW_SONG	        GTK_STOCK_NEW // FIXME
+#define BST_STOCK_NEW_CSYNTH	        GTK_STOCK_NEW // FIXME
+#define BST_STOCK_NEW_MIDI_SYNTH	GTK_STOCK_NEW // FIXME
+#define BST_STOCK_REMOVE_SYNTH	        GTK_STOCK_REMOVE // REMOVE
+#define BST_STOCK_DOC_NEWS	        GTK_STOCK_NEW // FIXME
+#define BST_STOCK_HELP	                GTK_STOCK_HELP
+#define BST_STOCK_DOC_FAQ	        GTK_STOCK_NEW // FIXME
+#define BST_STOCK_DOC_DEVEL	        GTK_STOCK_NEW // FIXME
+#define BST_STOCK_ABOUT	                GTK_STOCK_YES // FIXME
+#define BST_STOCK_ADD                   GTK_STOCK_ADD
+#define BST_STOCK_REMOVE                GTK_STOCK_REMOVE
+
 
 /* --- stock actions and aliases --- */
 #define	BST_STOCK_NONE			(NULL)
@@ -61,7 +84,6 @@ typedef struct {
 #define BST_STOCK_EXECUTE		GTK_STOCK_EXECUTE
 #define BST_STOCK_OK			GTK_STOCK_OK
 #define BST_STOCK_OVERWRITE		("bst-stock-overwrite")
-#define	BST_STOCK_PROPERTIES		GTK_STOCK_PROPERTIES
 #define BST_STOCK_REDO			GTK_STOCK_REDO
 #define BST_STOCK_REVERT		("bst-stock-revert")
 #define BST_STOCK_UNDO			GTK_STOCK_UNDO
@@ -81,8 +103,15 @@ typedef struct {
 #define	BST_SIZE_PALETTE		GXK_SIZE_PALETTE
 
 
+/* --- stock utilities --- */
+GtkWidget*      bst_stock_button        (const gchar    *stock_id);
+GtkWidget*      bst_stock_dbutton       (const gchar    *stock_id);
+GtkWidget*      bst_stock_icon_button   (const gchar    *stock_id);
+
+
 /* --- pixbuf shortcuts --- */
 #define bst_pixbuf_no_icon()	gxk_stock_fallback_pixbuf (BST_STOCK_NO_ICON)
+#define bst_pixbuf_ladspa()	gxk_stock_fallback_pixbuf (BST_STOCK_LADSPA)
 #define	bst_pixbuf_knob()	gxk_stock_fallback_pixbuf (BST_STOCK_KNOB)
 #define	BST_PIXDATA_EMPTY1x1	"GdkP\0\0\0\34\1\1\0\2\0\0\0\4\0\0\0\1\0\0\0\1\0\0\0\0"
 
@@ -101,9 +130,15 @@ void		bst_window_sync_title_to_proxy	(gpointer	 window,
 const gchar**	bst_log_scan_keys		(void);
 
 
-/* --- Gtk+ utilities & workarounds --- */
-gboolean   gtk_widget_viewable		 (GtkWidget		*widget);
-void	   gtk_widget_viewable_changed	 (GtkWidget		*widget);
+/* --- packing utilities --- */
+GtkWidget*      bst_vpack               (const gchar    *first_location,
+                                         ...);
+GtkWidget*      bst_hpack               (const gchar    *first_location,
+                                         ...);
+GtkWidget*      bst_vpack0              (const gchar    *first_location,
+                                         ...);
+GtkWidget*      bst_hpack0              (const gchar    *first_location,
+                                         ...);
 
 
 /* --- GUI field mask --- */
@@ -115,7 +150,8 @@ typedef enum /*< skip >*/
   BST_GMASK_FIT,
   BST_GMASK_FILL,
   BST_GMASK_INTERLEAVE, /* stretch */
-  BST_GMASK_BIG
+  BST_GMASK_BIG,
+  BST_GMASK_CENTER
 } BstGMaskPack;
 BstGMask*	bst_gmask_form		(GtkWidget     *gmask_container,
 					 GtkWidget     *action,
@@ -171,6 +207,12 @@ GtkWidget*	bst_container_get_named_child	(GtkWidget	*container,
 						 GQuark		 qname);
 GtkWidget*	bst_xpm_view_create		(const gchar   **xpm,
 						 GtkWidget	*colormap_widget);
+GtkItemFactory* bst_item_factory_new            (GType          container_type,
+                                                 const gchar   *path);
+
+
+/* --- file utils --- */
+gchar*          bst_file_scan_song_name         (const gchar    *file);
 
 
 /* --- internal --- */
