@@ -18,6 +18,7 @@
  */
 #include "gxkutils.h"
 #include "gxkcellrendererpopup.h"
+#include <string.h>
 
 
 /* --- generated marshallers --- */
@@ -28,11 +29,30 @@
 #include "gxkgentypes.c"
 
 
+/* --- prototypes --- */
+static void     gxk_traverse_viewable_changed	(GtkWidget      *widget,
+						 gpointer        data);
+
+
+/* --- variables --- */
+static gulong viewable_changed_id = 0;
+
+
 /* --- functions --- */
 void
 _gxk_init_utils (void)
 {
+  /* type registrations */
   gxk_type_register_generated (G_N_ELEMENTS (generated_type_entries), generated_type_entries);
+
+  /* Gtk+ patchups */
+  viewable_changed_id = g_signal_newv ("viewable-changed",
+				       G_TYPE_FROM_CLASS (gtk_type_class (GTK_TYPE_WIDGET)),
+				       G_SIGNAL_RUN_LAST,
+				       g_cclosure_new (G_CALLBACK (gxk_traverse_viewable_changed), NULL, NULL),
+				       NULL, NULL,
+				       gtk_marshal_VOID__VOID,
+				       G_TYPE_NONE, 0, NULL);
 }
 
 /**
@@ -92,7 +112,7 @@ g_object_set_double (gpointer     object,
 
   g_return_if_fail (G_IS_OBJECT (object));
 
-  if (*(guint64*)&v_double == *(guint64*)&zero)
+  if (memcmp (&v_double, &zero, sizeof (zero)) == 0)
     g_object_set_data (object, name, NULL);
   else
     {
@@ -160,6 +180,93 @@ g_object_get_long (gpointer     object,
   return (glong) g_object_get_data (object, name);
 }
 
+gchar*
+gxk_convert_latin1_to_utf8 (const gchar *string)
+{
+  if (string)
+    {
+      const guchar *s = string;
+      guint l = strlen (s);
+      guchar *dest = g_new (guchar, l * 2 + 1), *d = dest;
+      while (*s)
+	if (*s >= 0xC0)
+	  *d++ = 0xC3, *d++ = *s++ - 0x40;
+	else if (*s >= 0x80)
+	  *d++ = 0xC2, *d++ = *s++;
+	else
+	  *d++ = *s++;
+      *d++ = 0;
+      return dest;
+    }
+  return NULL;
+}
+
+gchar*
+gxk_filename_to_utf8 (const gchar *filename)
+{
+  if (filename)
+    {
+      gchar *s = g_locale_to_utf8 (filename, -1, NULL, NULL, NULL);
+      if (!s)
+	s = gxk_convert_latin1_to_utf8 (filename);
+      return s;
+    }
+  return NULL;
+}
+
+/* --- Gtk+ Utilities --- */
+/**
+ * gxk_widget_viewable_changed
+ * @widget: valid #GtkWidget
+ *
+ * A widget should call this function if it changed
+ * the mapped state of one of its children (or if it
+ * is a toplevel and gets show or hidden) to emit the
+ * ::viewable-changed signal on the related sub-tree.
+ * #GxkDialog properly emits this signal if show or
+ * hidden, containers like #GtkNotebook need this
+ * function be explicitely connected to their ::switch-page
+ * signal, in order for their children to get properly
+ * notified.
+ */
+void
+gxk_widget_viewable_changed (GtkWidget *widget)
+{
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  g_signal_emit (widget, viewable_changed_id, 0);
+}
+
+static void
+gxk_traverse_viewable_changed (GtkWidget *widget,
+			       gpointer   data)
+{
+  if (GTK_IS_CONTAINER (widget))
+    gtk_container_forall (GTK_CONTAINER (widget), (GtkCallback) gxk_widget_viewable_changed, NULL);
+}
+
+/**
+ * gxk_widget_viewable
+ * @widget: valid #GtkWidget
+ * RETURNS: %TRUE if the widget is viewable, %FALSE otherwise
+ *
+ * Check whether a widget is viewable by verifying the mapped
+ * state of the widget and all its parent widgets.
+ */
+gboolean
+gxk_widget_viewable (GtkWidget *widget)
+{
+  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+
+  while (widget)
+    {
+      if (!GTK_WIDGET_MAPPED (widget))
+	return FALSE;
+      widget = widget->parent;
+    }
+  return TRUE;
+}
+
 /**
  * gxk_window_set_cursor_type
  * @window: valid #GdkWindow*
@@ -291,7 +398,6 @@ idle_shower (GtkWidget **widget_p)
 				     widget_p);
       gtk_widget_show (*widget_p);
     }
-
   g_free (widget_p);
 
   GDK_THREADS_LEAVE ();
@@ -301,7 +407,7 @@ idle_shower (GtkWidget **widget_p)
 
 /**
  * gxk_idle_show_widget
- * @widget: a valid widget
+ * @widget: a valid #GtkWidget
  *
  * Defer showing this widget until the next idle handler
  * is run. This is usefull if other things are pending
@@ -325,6 +431,65 @@ gxk_idle_show_widget (GtkWidget *widget)
   gtk_idle_add_priority (GTK_PRIORITY_RESIZE - 1, (GtkFunction) idle_shower, widget_p);
 }
 
+static gint
+idle_unrealizer (GtkWidget **widget_p)
+{
+  GDK_THREADS_ENTER ();
+
+  if (GTK_IS_WINDOW (*widget_p))
+    {
+      gtk_signal_disconnect_by_func (GTK_OBJECT (*widget_p),
+				     GTK_SIGNAL_FUNC (gtk_widget_destroyed),
+				     widget_p);
+      if (!GTK_WIDGET_VISIBLE (*widget_p) &&
+          GTK_WIDGET_REALIZED (*widget_p))
+        gtk_widget_unrealize (*widget_p);
+    }
+  g_free (widget_p);
+
+  GDK_THREADS_LEAVE ();
+
+  return FALSE;
+}
+
+/**
+ * gxk_idle_unrealize_widget
+ * @widget: a valid #GtkWindow
+ *
+ * Defer unrealizing this widget until the next idle handler
+ * is run. This is usefull if other things are pending
+ * which need to be processed first, e.g. completing a running
+ * signal emission.
+ */
+void
+gxk_idle_unrealize_widget (GtkWidget *widget)
+{
+  GtkWidget **widget_p;
+
+  g_return_if_fail (GTK_IS_WINDOW (widget));
+
+  widget_p = g_new (GtkWidget*, 1);
+
+  *widget_p = widget;
+  gtk_signal_connect (GTK_OBJECT (widget),
+		      "destroy",
+		      GTK_SIGNAL_FUNC (gtk_widget_destroyed),
+		      widget_p);
+  gtk_idle_add_priority (GTK_PRIORITY_RESIZE - 1, (GtkFunction) idle_unrealizer, widget_p);
+}
+
+void
+gxk_notebook_add_page (GtkNotebook *notebook,
+		       GtkWidget   *child,
+		       const gchar *tab_text,
+		       gboolean     expand_fill)
+{
+  gtk_container_add (GTK_CONTAINER (notebook), child);
+  gtk_notebook_set_tab_label_text (notebook, child, tab_text);
+  gtk_notebook_set_menu_label_text (notebook, child, tab_text);
+  gtk_notebook_set_tab_label_packing (notebook, child, expand_fill, expand_fill, GTK_PACK_START);
+}
+
 /**
  * gxk_notebook_set_current_page_widget
  * @notebook: valid #GtkNotebook
@@ -439,6 +604,7 @@ style_modify_fg_as_sensitive (GtkWidget *widget)
   rc_style->fg[GTK_STATE_INSENSITIVE].green = widget->style->fg[GTK_STATE_NORMAL].green;
   rc_style->fg[GTK_STATE_INSENSITIVE].blue = widget->style->fg[GTK_STATE_NORMAL].blue;
   gtk_widget_modify_style (widget, rc_style);
+  gtk_rc_style_unref (rc_style);
 }
 
 /**
@@ -739,11 +905,30 @@ gxk_tree_view_add_column (GtkTreeView       *tree_view,
  * @...:       column arguments
  *
  * Add @n_cols new columns with text cells to
- * @tree_view. Per column, the caller needs to
- * supply a #guint, a #gdouble and a string, to
- * be used as model column number (for the text
- * to be displayed), the horizontal cell alignment
+ * @tree_view (a short hand version for multiple
+ * calls to gxk_tree_view_add_text_column()).
+ * Per column, the caller needs to
+ * supply a #guint, a string, a #gdouble and another
+ * string. The Arguments are used as model column
+ * number (for the text to be displayed), the column
+ * specific flags, the horizontal cell alignment
  * (between 0 and 1) and the column title respectively.
+ *
+ * The @column_flags argument is a combination of letters that
+ * are able to switch certain characteristics on or of,
+ * currently supported are:
+ * @* %F - column is fixed in sizing;
+ * @* %A - column resizes automatically;
+ * @* %G - columns sizing behaviour is grow only;
+ * @* %S - column is sortable;
+ * @* %s - column is unsortable;
+ * @* %O - column is reorderable;
+ * @* %o - column is not reorderable;
+ * @* %R - column is user-resizable;
+ * @* %r - column is not user-resizable;
+ * @* %P - add extra padding between multiple cells of the same column;
+ * @* %p - cancel a previous %P flag;
+ * @* %# - automatically popup dialogs for popup cell renderers.
  */
 void
 gxk_tree_view_append_text_columns (GtkTreeView *tree_view,
@@ -758,29 +943,143 @@ gxk_tree_view_append_text_columns (GtkTreeView *tree_view,
   while (n_cols--)
     {
       guint col = va_arg (var_args, guint);
+      gchar *column_flags = va_arg (var_args, gchar*);
       gfloat xalign = va_arg (var_args, gdouble);
       gchar *title = va_arg (var_args, gchar*);
 
-      gxk_tree_view_add_column (tree_view, -1,
-				g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
-					      "title", title,
-					      "sizing", GTK_TREE_VIEW_COLUMN_GROW_ONLY,
-					      "resizable", TRUE,
-					      "reorderable", TRUE,
-					      NULL),
-				g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
-					      "xalign", xalign,
-					      NULL),
-				"text", col,
-				NULL);
+      gxk_tree_view_add_text_column (tree_view, col, column_flags,
+				     xalign, title, NULL,
+				     NULL, NULL, 0);
     }
   va_end (var_args);
 }
 
+static void
+tree_view_add_column (GtkTreeView  *tree_view,
+		      guint	     model_column,
+		      gdouble       xalign,
+		      const gchar  *title,
+		      const gchar  *tooltip,
+		      gpointer      callback1,
+		      gpointer      callback2,
+		      gpointer      data,
+		      GConnectFlags cflags,
+		      guint         column_type,
+		      const gchar  *dcolumn_flags,
+		      const gchar  *ucolumn_flags)
+{
+  GtkCellRenderer *cell = NULL;
+  const gchar *prop = NULL;
+  GtkTreeViewColumn *tcol;
+  GtkTreeViewColumnSizing sizing = GTK_TREE_VIEW_COLUMN_GROW_ONLY;
+  gboolean reorderable = FALSE, resizable = TRUE, sortable = FALSE, auto_popup = FALSE;
+  gchar *p, *column_flags = g_strconcat (" ", dcolumn_flags, ucolumn_flags, NULL);
+  guint fixed_width = 0, padding = 0;
+
+  for (p = column_flags; *p; p++)
+    switch (*p)
+      {
+      case 'F':	/* column is fixed in sizing */
+	sizing = GTK_TREE_VIEW_COLUMN_FIXED;
+	fixed_width = 120;
+	break;
+      case 'A':	/* autosizing columns */
+	sizing = GTK_TREE_VIEW_COLUMN_AUTOSIZE;
+	break;
+      case 'G':	/* grow-only columns */
+	sizing = GTK_TREE_VIEW_COLUMN_GROW_ONLY;
+	break;
+      case 'S':	/* sortable columns */
+	sortable = TRUE;
+	break;
+      case 's':	/* unsortable columns */
+	sortable = FALSE;
+	break;
+      case 'O':	/* reorderable columns */
+	reorderable = TRUE;
+	break;
+      case 'o':	/* non-reorderable columns */
+	reorderable = TRUE;
+	break;
+      case 'R':	/* resizable columns */
+	resizable = TRUE;
+	break;
+      case 'r':	/* non-resizable columns */
+	resizable = FALSE;
+	break;
+      case 'P':	/* add cell padding */
+	padding += 3;
+	break;
+      case 'p':	/* add cell padding */
+	padding = MAX (padding, 3) - 3;
+	break;
+      case '#':	/* auto popup popup cell renderers */
+	auto_popup = TRUE;
+	break;
+      }
+
+  switch (column_type)
+    {
+    case 1:	/* text */
+      /* GTKFIX: we use a popup cell renderer for text cells to work around focus problems in gtk */
+      cell = g_object_new (GXK_TYPE_CELL_RENDERER_POPUP,
+			   "show_button", FALSE,
+			   "xalign", xalign,
+			   "editable", callback1 != NULL,
+			   NULL);
+      prop = "text";
+      if (callback1)
+	g_signal_connect_data (cell, "edited", G_CALLBACK (callback1), data, NULL, cflags);
+      break;
+    case 2:	/* popup */
+      cell = g_object_new (GXK_TYPE_CELL_RENDERER_POPUP,
+			   "xalign", xalign,
+			   "editable", callback1 != NULL,
+                           "auto_popup", auto_popup,
+			   NULL);
+      prop = "text";
+      if (callback1)
+	g_signal_connect_data (cell, "edited", G_CALLBACK (callback1), data, NULL, cflags);
+      if (callback2)
+	g_signal_connect_data (cell, "popup", G_CALLBACK (callback2), data, NULL, cflags);
+      break;
+    case 3:
+      cell = g_object_new (GTK_TYPE_CELL_RENDERER_TOGGLE,
+			   /* "radio", radio_indicator, */
+			   "activatable", callback1 != NULL,
+			   NULL);
+      prop = "active";
+      if (callback1)
+	g_signal_connect_data (cell, "toggled", G_CALLBACK (callback1), data, NULL, cflags);
+      break;
+    }
+  gxk_tree_view_add_column (tree_view, -1,
+			    tcol = g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
+						 "title", title,
+						 "sizing", sizing,
+						 "resizable", resizable,
+						 "reorderable", reorderable,
+						 NULL),
+			    cell,
+			    prop, model_column,
+			    NULL);
+  if (fixed_width)
+    gtk_tree_view_column_set_fixed_width (tcol, fixed_width);
+  if (padding)
+    gtk_tree_view_column_set_spacing (tcol, padding);
+  if (sortable && GTK_IS_TREE_SORTABLE (gtk_tree_view_get_model (tree_view)))
+    gtk_tree_view_column_set_sort_column_id (tcol, model_column);
+  if (tooltip)
+    gxk_tree_view_column_set_tip_title (tcol, title, tooltip);
+  gtk_tree_view_column_set_alignment (tcol, xalign);
+  g_free (column_flags);
+}
+
 /**
  * gxk_tree_view_add_text_column
  * @tree_view:        valid #GtkTreeView
  * @model_column:     model column
+ * @column_flags:     column flags
  * @xalign:	      horizontal text alignment
  * @title:            column title
  * @tooltip:          column tooltip
@@ -788,48 +1087,35 @@ gxk_tree_view_append_text_columns (GtkTreeView *tree_view,
  * @data:             data passed in to toggled_callback
  * @cflags:           connection flags
  *
- * Add a text column, similar to
- * gxk_tree_view_append_text_columns().
- * @edited_callback(@data) is connected with
- * @cflags (see g_signal_connect_data()) to
- * the "edited" signal of the text cell,
- * or passed as %NULL which makes the column
- * non-editable.
+ * Add a new column with text cell to a @tree_view.
+ * The @model_column indicates the column number
+ * of the tree model containing the text to be
+ * displayed, the @column_flags toggle specific
+ * column characteristics (see
+ * gxk_tree_view_append_text_columns() for details)
+ * and @xalign controls the horizontal cell alignment
+ * (between 0 and 1).
+ * If non-%NULL, @edited_callback(@data) is connected
+ * with @cflags (see g_signal_connect_data()) to the
+ * "::edited" signal of the text cell and the cell is
+ * made editable.
  */
 void
 gxk_tree_view_add_text_column (GtkTreeView  *tree_view,
-			       guint	     model_column,
-			       gdouble       xalign,
-			       const gchar  *title,
-			       const gchar  *tooltip,
-			       gpointer      edited_callback,
-			       gpointer      data,
-			       GConnectFlags cflags)
+                               guint         model_column,
+			       const gchar  *column_flags,
+                               gdouble       xalign,
+                               const gchar  *title,
+                               const gchar  *tooltip,
+                               gpointer      edited_callback,
+                               gpointer      data,
+                               GConnectFlags cflags)
 {
-  GtkCellRenderer *cell;
-  GtkTreeViewColumn *tcol;
-
   g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
 
-  cell = g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
-		       "xalign", xalign,
-		       "editable", edited_callback != NULL,
-		       NULL);
-  if (edited_callback)
-    g_signal_connect_data (cell, "edited", G_CALLBACK (edited_callback), data, NULL, cflags);
-  gxk_tree_view_add_column (tree_view, -1,
-			    tcol = g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
-						 "title", title,
-						 "sizing", GTK_TREE_VIEW_COLUMN_GROW_ONLY,
-						 "resizable", TRUE,
-						 "reorderable", TRUE,
-						 NULL),
-			    cell,
-			    "text", model_column,
-			    NULL);
-  if (tooltip)
-    gxk_tree_view_column_set_tip_title (tcol, title, tooltip);
-  gtk_tree_view_column_set_alignment (tcol, xalign);
+  return tree_view_add_column (tree_view, model_column, xalign, title, tooltip,
+                               edited_callback, NULL, data, cflags,
+			       1, "", column_flags);
 }
 
 /**
@@ -839,47 +1125,34 @@ gxk_tree_view_add_text_column (GtkTreeView  *tree_view,
  * @xalign:	      horizontal text alignment
  * @title:            column title
  * @tooltip:          column tooltip
- * @edited_callback:  notification callback 
+ * @edited_callback:  edit notification callback 
+ * @popup_callback:   popup notification callback 
  * @data:             data passed in to toggled_callback
  * @cflags:           connection flags
  *
  * Add a text column with popup facility, similar to
- * gxk_tree_view_add_text_column().
+ * gxk_tree_view_add_text_column(). This function takes
+ * an additional argument @popup_callback() which is
+ * called when the user clicks on the cells "popup"
+ * button.
  */
 void
 gxk_tree_view_add_popup_column (GtkTreeView  *tree_view,
 				guint	      model_column,
+				const gchar  *column_flags,
 				gdouble       xalign,
 				const gchar  *title,
 				const gchar  *tooltip,
 				gpointer      edited_callback,
+				gpointer      popup_callback,
 				gpointer      data,
 				GConnectFlags cflags)
 {
-  GtkCellRenderer *cell;
-  GtkTreeViewColumn *tcol;
-
   g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
 
-  cell = g_object_new (GXK_TYPE_CELL_RENDERER_POPUP,
-		       "xalign", xalign,
-		       "editable", edited_callback != NULL,
-		       NULL);
-  if (edited_callback)
-    g_signal_connect_data (cell, "edited", G_CALLBACK (edited_callback), data, NULL, cflags);
-  gxk_tree_view_add_column (tree_view, -1,
-			    tcol = g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
-						 "title", title,
-						 "sizing", GTK_TREE_VIEW_COLUMN_GROW_ONLY,
-						 "resizable", TRUE,
-						 "reorderable", TRUE,
-						 NULL),
-			    cell,
-			    "text", model_column,
-			    NULL);
-  if (tooltip)
-    gxk_tree_view_column_set_tip_title (tcol, title, tooltip);
-  gtk_tree_view_column_set_alignment (tcol, xalign);
+  return tree_view_add_column (tree_view, model_column, xalign, title, tooltip,
+			       edited_callback, popup_callback, data, cflags,
+			       2, "", column_flags);
 }
 
 /**
@@ -894,16 +1167,17 @@ gxk_tree_view_add_popup_column (GtkTreeView  *tree_view,
  * @cflags:           connection flags
  *
  * Add a toggle button column, similar
- * to gxk_tree_view_add_text_column().
- * @edited_callback(@data) is connected with
- * @cflags (see g_signal_connect_data()) to
- * the "toggled" signal of the toggle cell,
- * or passed as %NULL which makes the column
- * non-editable.
+ * to gxk_tree_view_add_text_column(), however
+ * the model column is expected to be of type
+ * %G_TYPE_BOOLEAN, and instead of an @edited_callback(),
+ * this function has a @toggled_callback(@data) callback
+ * which is connected to the "toggled" signal of
+ * the new cell.
  */
 void
 gxk_tree_view_add_toggle_column (GtkTreeView  *tree_view,
 				 guint         model_column,
+				 const gchar  *column_flags,
 				 gdouble       xalign,
 				 const gchar  *title,
 				 const gchar  *tooltip,
@@ -911,30 +1185,44 @@ gxk_tree_view_add_toggle_column (GtkTreeView  *tree_view,
 				 gpointer      data,
 				 GConnectFlags cflags)
 {
-  GtkCellRenderer *cell;
-  GtkTreeViewColumn *tcol;
-
   g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
 
-  cell = g_object_new (GTK_TYPE_CELL_RENDERER_TOGGLE,
-		       /* "radio", radio_indicator, */
-		       "activatable", toggled_callback != NULL,
-		       NULL);
-  if (toggled_callback)
-    g_signal_connect_data (cell, "toggled", G_CALLBACK (toggled_callback), data, NULL, cflags);
-  gxk_tree_view_add_column (tree_view, -1,
-			    tcol = g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
-						 "title", title,
-						 "sizing", GTK_TREE_VIEW_COLUMN_AUTOSIZE,
-						 "resizable", TRUE,
-						 "reorderable", TRUE,
-						 NULL),
-			    cell,
-			    "active", model_column,
-			    NULL);
-  if (tooltip)
-    gxk_tree_view_column_set_tip_title (tcol, title, tooltip);
-  gtk_tree_view_column_set_alignment (tcol, xalign);
+  return tree_view_add_column (tree_view, model_column, xalign, title, tooltip,
+			       toggled_callback, NULL, data, cflags,
+			       3, "A", column_flags);
+}
+
+void
+gxk_tree_view_set_editable (GtkTreeView *tview,
+                            gboolean     maybe_editable)
+{
+  GList *clist = gtk_tree_view_get_columns (tview);
+  GtkTreeViewColumn *tcol = g_list_pop_head (&clist);
+  while (tcol)
+    {
+      GList *rlist = gtk_tree_view_column_get_cell_renderers (tcol);
+      GtkCellRenderer *cell = g_list_pop_head (&rlist);
+      while (cell)
+        {
+          GParamSpec *pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (cell), "editable");
+          if (pspec && g_type_is_a (G_PARAM_SPEC_VALUE_TYPE (pspec), G_TYPE_BOOLEAN))
+            {
+              gboolean is_editable, was_editable = g_object_get_long (cell, "editable");
+              g_object_get (cell, "editable", &is_editable, NULL);
+              if (maybe_editable && was_editable && !is_editable)
+                g_object_set (cell, "editable", TRUE, NULL);
+              else if (is_editable)
+                {
+                  if (!was_editable)
+                    g_object_set_long (cell, "editable", TRUE);
+                  if (!maybe_editable)
+                    g_object_set (cell, "editable", FALSE, NULL);
+                }
+            }
+          cell = g_list_pop_head (&rlist);
+        }
+      tcol = g_list_pop_head (&clist);
+    }
 }
 
 static void
@@ -1135,12 +1423,15 @@ browse_selection_handler (gpointer data)
 	    }
 	  if (needs_sel)
 	    {
-	      gxk_tree_selection_select_ipath (selection, 0, -1);
 	      path = gtk_tree_path_new ();
 	      gtk_tree_path_append_index (path, 0);
 	      gtk_tree_selection_select_path (selection, path);
-	      gtk_tree_view_set_cursor (gtk_tree_selection_get_tree_view (selection),
-					path, NULL, FALSE);
+	      if (gtk_tree_selection_path_is_selected (selection, path))
+		{
+		  /* GTKFIX: this triggeres an assertion on empty sort models */
+		  gtk_tree_view_set_cursor (gtk_tree_selection_get_tree_view (selection),
+					    path, NULL, FALSE);
+		}
 	      gtk_tree_path_free (path);
 	    }
 	  else
@@ -1191,6 +1482,7 @@ gxk_tree_selection_force_browse (GtkTreeSelection *selection,
   g_return_if_fail (GTK_IS_TREE_SELECTION (selection));
   if (model)
     g_return_if_fail (GTK_IS_TREE_MODEL (model));
+  return; // FIXME: hack disabled
 
   if (!gxk_signal_handler_pending (selection, "changed", G_CALLBACK (browse_selection_changed), selection))
     g_signal_connect_data (selection, "changed", G_CALLBACK (browse_selection_changed), selection, NULL, 0);
@@ -1254,16 +1546,11 @@ gxk_tree_view_get_row_area (GtkTreeView *tree,
                             gint        *y_p,
                             gint        *height_p)
 {
-  GdkRectangle rect;
+  GdkRectangle rect = { 0, 0, 0, 0 };
 
   g_return_val_if_fail (GTK_IS_TREE_VIEW (tree), FALSE);
 
-  if (row < 0)
-    {
-      rect.y = 0;
-      rect.width = 0;
-    }
-  else
+  if (row >= 0)
     {
       GtkTreePath *path = gtk_tree_path_new ();
       gtk_tree_path_append_index (path, row);
@@ -1616,22 +1903,24 @@ gxk_cell_editable_canceled (GtkCellEditable *ecell)
 }
 
 /**
- * gxk_cell_editable_focus_out_handler
+ * gxk_cell_editable_is_focus_handler
  * @ecell:   valid #GtkCellEditable
  * @RETURNS: returns %FALSE
  *
  * Call gtk_cell_editable_editing_done() if necessary and return %FALSE.
- * This function is meant to be used to handle focus out events on
- * #GtkCellEditable widgets.
+ * This function is meant to be used to handle "notify::is-focus" signals
+ * on #GtkCellEditable widgets.
  */
-gboolean
-gxk_cell_editable_focus_out_handler (GtkCellEditable *ecell)
+void
+gxk_cell_editable_is_focus_handler (GtkCellEditable *ecell)
 {
-  g_return_val_if_fail (GTK_IS_CELL_EDITABLE (ecell), FALSE);
+  g_return_if_fail (GTK_IS_CELL_EDITABLE (ecell));
 
-  // gtk_cell_editable_editing_done (ecell);
-
-  return FALSE;
+  if (!gtk_widget_is_focus (GTK_WIDGET (ecell)))
+    {
+      gtk_cell_editable_editing_done (ecell);
+      gtk_cell_editable_remove_widget (ecell);
+    }
 }
 
 static gchar*
@@ -1659,6 +1948,44 @@ path_fix_uline (const gchar *str)
   return path;
 }
 
+/**
+ * gxk_item_factory_sensitize
+ * @ifactory:  valid #GtkItemFactory
+ * @path:      item factory path
+ * @sensitive: whether menu item should be sensitive
+ * @RETURNS:   menu item according to @path
+ *
+ * This function turns the menu item found via
+ * gxk_item_factory_get_item() (in-)sensitive
+ * according to @sensitive. Additional checks
+ * are performed before making a menu item sensitive
+ * to avoid showing e.g. empty submenus.
+ */
+GtkWidget*
+gxk_item_factory_sensitize (GtkItemFactory  *ifactory,
+                            const gchar     *path,
+                            gboolean         sensitive)
+{
+  GtkWidget *item = gxk_item_factory_get_item (ifactory, path);
+  if (item)
+    {
+      if (GTK_IS_MENU_ITEM (item) && sensitive)
+        {
+          GtkWidget *menu = gtk_menu_item_get_submenu ((GtkMenuItem*) item);
+          if (menu && GTK_IS_MENU (menu))
+            {
+              GList *list = gtk_container_get_children (GTK_CONTAINER (menu));
+              if (list)
+                g_list_free (list);
+              else
+                sensitive = FALSE;
+            }
+        }
+      gtk_widget_set_sensitive (item, sensitive);
+    }
+  return item;
+}
+
 /**
  * gxk_item_factory_get_item
  * @ifactory: valid #GtkItemFactory
@@ -1730,32 +2057,27 @@ gxk_widget_proxy_requisition (GtkWidget *widget)
   g_signal_connect_after (widget, "size_request", G_CALLBACK (requisition_to_aux_info), NULL);
 }
 
-/**
- * gxk_file_selection_heal
- * @fs: valid #GtkFileSelection
- *
- * Fixup various oddities that happened to the Gtk+
- * file selection widget over time. This function
- * corrects container border widths, spacing, button
- * placement and the default and focus widgets.
- */
-void
-gxk_file_selection_heal (GtkFileSelection *fs)
+GtkWidget*
+gxk_file_selection_split (GtkFileSelection *fs,
+			  GtkWidget       **bbox_p)
 {
   GtkWidget *main_vbox;
   GtkWidget *hbox;
-  GtkWidget *any;
 
-  g_return_if_fail (GTK_IS_FILE_SELECTION (fs));
+  g_return_val_if_fail (GTK_IS_FILE_SELECTION (fs), NULL);
 
-  /* button placement
-   */
-  gtk_container_set_border_width (GTK_CONTAINER (fs), 0);
+  /* nuke GUI junk */
   gtk_file_selection_hide_fileop_buttons (fs);
+
+  /* fix spacing and borders */
+  gtk_container_set_border_width (GTK_CONTAINER (fs), 0);
   gtk_widget_ref (fs->main_vbox);
   gtk_container_remove (GTK_CONTAINER (fs), fs->main_vbox);
-  gtk_box_set_spacing (GTK_BOX (fs->main_vbox), 0);
-  gtk_container_set_border_width (GTK_CONTAINER (fs->main_vbox), 5);
+  g_object_set (fs->main_vbox,
+		"spacing", 0,
+		"border_width", 5,
+		NULL);
+  /* repack into new parent box */
   main_vbox = gtk_widget_new (GTK_TYPE_VBOX,
 			      "homogeneous", FALSE,
 			      "spacing", 0,
@@ -1765,30 +2087,64 @@ gxk_file_selection_heal (GtkFileSelection *fs)
 			      NULL);
   gtk_box_pack_start (GTK_BOX (main_vbox), fs->main_vbox, TRUE, TRUE, 0);
   gtk_widget_unref (fs->main_vbox);
+
+  /* fixup focus and default widgets */
+  gtk_widget_grab_default (fs->ok_button);
+  gtk_widget_grab_focus (fs->selection_entry);
+
+  /* use an ordinary HBox as button container */
   gtk_widget_hide (fs->ok_button->parent);
   hbox = gtk_widget_new (GTK_TYPE_HBOX,
 			 "homogeneous", TRUE,
-			 "spacing", 0,
+			 "spacing", 3,
 			 "border_width", 5,
 			 "visible", TRUE,
 			 NULL);
-  gtk_box_pack_end (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
+  if (bbox_p)
+    *bbox_p = hbox;
+  else
+    gtk_box_pack_end (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_reparent (fs->ok_button, hbox);
   gtk_widget_reparent (fs->cancel_button, hbox);
-  gtk_widget_grab_default (fs->ok_button);
-  // gtk_label_set_text (GTK_LABEL (GTK_BIN (fs->ok_button)->child), "Ok");
-  // gtk_label_set_text (GTK_LABEL (GTK_BIN (fs->cancel_button)->child), "Cancel");
 
-  /* heal the action_area packing so we can customize children
-   */
+  /* fix the action_area packing so we can customize children */
   gtk_box_set_child_packing (GTK_BOX (fs->action_area->parent),
 			     fs->action_area,
 			     FALSE, TRUE,
 			     5, GTK_PACK_START);
 
-  any = gtk_widget_new (GTK_TYPE_HSEPARATOR,
-			"visible", TRUE,
-			NULL);
-  gtk_box_pack_end (GTK_BOX (main_vbox), any, FALSE, TRUE, 0);
-  gtk_widget_grab_focus (fs->selection_entry);
+  /* fs life cycle */
+  g_signal_connect_object (main_vbox, "destroy", G_CALLBACK (gtk_widget_destroy), fs, G_CONNECT_SWAPPED);
+
+  return main_vbox;
+}
+
+/**
+ * gxk_file_selection_heal
+ * @fs:      valid #GtkFileSelection
+ * @RETURNS: new toplevel VBox of the file selection
+ *
+ * Fixup various oddities that happened to the Gtk+
+ * file selection widget over time. This function
+ * corrects container border widths, spacing, button
+ * placement and the default and focus widgets.
+ * Also, the lifetime of the file selection window
+ * is tied to the returned #GtkVBox, enabling removal
+ * of the #GtkVBox from it's parent and thus using the
+ * file selection widgets in a custom #GtkWindow.
+ */
+GtkWidget*
+gxk_file_selection_heal (GtkFileSelection *fs)
+{
+  GtkWidget *any, *main_box;
+
+  main_box = gxk_file_selection_split (fs, NULL);
+
+  /* add obligatory button seperator */
+  any = g_object_new (GTK_TYPE_HSEPARATOR,
+		      "visible", TRUE,
+		      NULL);
+  gtk_box_pack_end (GTK_BOX (main_box), any, FALSE, TRUE, 0);
+
+  return main_box;
 }
