@@ -13,7 +13,6 @@
 
 
 /* --- bse-categories-match-typed --- */
-static GType type_id_bse_categories_match_typed = 0;
 static void
 bse_categories_match_typed_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 27 "bsecategories.proc"
@@ -30,7 +29,7 @@ bse_categories_match_typed_setup (BseProcedureClass *proc, GParamSpec **in_pspec
 #line 23 "bsecategories.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsecategories.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 35 "bsecategories.proc"
  }
 static BseErrorType
@@ -65,7 +64,6 @@ bse_categories_match_typed_exec (BseProcedureClass *proc,
 }
 
 /* --- bse-categories-match --- */
-static GType type_id_bse_categories_match = 0;
 static void
 bse_categories_match_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 60 "bsecategories.proc"
@@ -80,7 +78,7 @@ bse_categories_match_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
 #line 23 "bsecategories.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsecategories.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 66 "bsecategories.proc"
  }
 static BseErrorType
@@ -112,7 +110,6 @@ bse_categories_match_exec (BseProcedureClass *proc,
 }
 
 /* --- bse-category-from-id --- */
-static GType type_id_bse_category_from_id = 0;
 static void
 bse_category_from_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 88 "bsecategories.proc"
@@ -127,7 +124,7 @@ bse_category_from_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
 #line 23 "bsecategories.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsecategories.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 94 "bsecategories.proc"
  }
 static BseErrorType
@@ -170,7 +167,6 @@ categories_check_method (BseCategory *cat,
 }
 
 /* --- bse-categories-match-method --- */
-static GType type_id_bse_categories_match_method = 0;
 static void
 bse_categories_match_method_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 128 "bsecategories.proc"
@@ -187,7 +183,7 @@ bse_categories_match_method_setup (BseProcedureClass *proc, GParamSpec **in_pspe
 #line 23 "bsecategories.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsecategories.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 136 "bsecategories.proc"
  }
 static BseErrorType
@@ -221,15 +217,31 @@ bse_categories_match_method_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { &type_id_bse_categories_match_typed, "bse-categories-match-typed", NULL, 0, bse_categories_match_typed_setup, bse_categories_match_typed_exec, NULL, "/Proc/Utils/Categories/Match Typed", { 0, }, },
-  { &type_id_bse_categories_match, "bse-categories-match", NULL, 0, bse_categories_match_setup, bse_categories_match_exec, NULL, "/Proc/Utils/Categories/Match", { 0, }, },
-  { &type_id_bse_category_from_id, "bse-category-from-id", NULL, 0, bse_category_from_id_setup, bse_category_from_id_exec, NULL, "/Proc/Utils/Categories/From ID", { 0, }, },
-  { &type_id_bse_categories_match_method, "bse-categories-match-method", NULL, 0, bse_categories_match_method_setup, bse_categories_match_method_exec, NULL, "/Proc/Utils/Categories/Match Method", { 0, }, },
-  { NULL, },
+static BseExportNodeProc __enode_bse_categories_match_typed = {
+  { NULL, BSE_EXPORT_NODE_PROC,
+    "bse-categories-match-typed", "/Proc/Categories/Match Typed", NULL },
+  0, bse_categories_match_typed_setup, bse_categories_match_typed_exec, 
 };
-BSE_EXPORTS_END;
+static BseExportNodeProc __enode_bse_categories_match = {
+  { (BseExportNode*) &__enode_bse_categories_match_typed, BSE_EXPORT_NODE_PROC,
+    "bse-categories-match", "/Proc/Categories/Match", NULL },
+  0, bse_categories_match_setup, bse_categories_match_exec, 
+};
+static BseExportNodeProc __enode_bse_category_from_id = {
+  { (BseExportNode*) &__enode_bse_categories_match, BSE_EXPORT_NODE_PROC,
+    "bse-category-from-id", "/Proc/Categories/From ID", NULL },
+  0, bse_category_from_id_setup, bse_category_from_id_exec, 
+};
+static BseExportNodeProc __enode_bse_categories_match_method = {
+  { (BseExportNode*) &__enode_bse_category_from_id, BSE_EXPORT_NODE_PROC,
+    "bse-categories-match-method", "/Proc/Categories/Match Method", NULL },
+  0, bse_categories_match_method_setup, bse_categories_match_method_exec, 
+};
+BseExportNode* bse__builtin_init_bsecategories_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bsecategories_gen_proc_c (void)
+{
+  return (BseExportNode*) &__enode_bse_categories_match_method;
+}
 
 /**
  ** Generated data ends here
