@@ -13,7 +13,6 @@
 
 
 /* --- create-entry --- */
-static GType type_id_create_entry = 0;
 static void
 create_entry_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 27 "bsedatapocket.proc"
@@ -29,7 +28,7 @@ create_entry_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 34 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -61,7 +60,6 @@ create_entry_exec (BseProcedureClass *proc,
 }
 
 /* --- delete-entry --- */
-static GType type_id_delete_entry = 0;
 static void
 delete_entry_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 55 "bsedatapocket.proc"
@@ -79,7 +77,7 @@ delete_entry_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 64 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -113,7 +111,6 @@ delete_entry_exec (BseProcedureClass *proc,
 }
 
 /* --- get-n-entries --- */
-static GType type_id_get_n_entries = 0;
 static void
 get_n_entries_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 87 "bsedatapocket.proc"
@@ -128,7 +125,7 @@ get_n_entries_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 93 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -155,7 +152,6 @@ get_n_entries_exec (BseProcedureClass *proc,
 }
 
 /* --- get-nth-entry-id --- */
-static GType type_id_get_nth_entry_id = 0;
 static void
 get_nth_entry_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 110 "bsedatapocket.proc"
@@ -172,7 +168,7 @@ get_nth_entry_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 118 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -200,7 +196,6 @@ get_nth_entry_id_exec (BseProcedureClass *proc,
 }
 
 /* --- set-float --- */
-static GType type_id_set_float = 0;
 static void
 set_float_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 136 "bsedatapocket.proc"
@@ -224,7 +219,7 @@ set_float_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 151 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -262,7 +257,6 @@ set_float_exec (BseProcedureClass *proc,
 }
 
 /* --- set-int --- */
-static GType type_id_set_int = 0;
 static void
 set_int_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 178 "bsedatapocket.proc"
@@ -286,7 +280,7 @@ set_int_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 193 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -324,7 +318,6 @@ set_int_exec (BseProcedureClass *proc,
 }
 
 /* --- set-object --- */
-static GType type_id_set_object = 0;
 static void
 set_object_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 220 "bsedatapocket.proc"
@@ -348,7 +341,7 @@ set_object_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 235 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -387,7 +380,6 @@ set_object_exec (BseProcedureClass *proc,
 }
 
 /* --- set-string --- */
-static GType type_id_set_string = 0;
 static void
 set_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 263 "bsedatapocket.proc"
@@ -409,7 +401,7 @@ set_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 276 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -447,7 +439,6 @@ set_string_exec (BseProcedureClass *proc,
 }
 
 /* --- get-float --- */
-static GType type_id_get_float = 0;
 static void
 get_float_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 303 "bsedatapocket.proc"
@@ -466,7 +457,7 @@ get_float_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 313 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -501,7 +492,6 @@ get_float_exec (BseProcedureClass *proc,
 }
 
 /* --- get-int --- */
-static GType type_id_get_int = 0;
 static void
 get_int_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 337 "bsedatapocket.proc"
@@ -520,7 +510,7 @@ get_int_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 347 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -555,7 +545,6 @@ get_int_exec (BseProcedureClass *proc,
 }
 
 /* --- get-object --- */
-static GType type_id_get_object = 0;
 static void
 get_object_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 371 "bsedatapocket.proc"
@@ -574,7 +563,7 @@ get_object_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 381 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -609,7 +598,6 @@ get_object_exec (BseProcedureClass *proc,
 }
 
 /* --- get-string --- */
-static GType type_id_get_string = 0;
 static void
 get_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 405 "bsedatapocket.proc"
@@ -628,7 +616,7 @@ get_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 23 "bsedatapocket.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsedatapocket.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 415 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -663,23 +651,71 @@ get_string_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { &type_id_create_entry, "BseDataPocket+create-entry", NULL, 0, create_entry_setup, create_entry_exec, NULL, "/Method/BseDataPocket/General/Create Entry", { 0, }, },
-  { &type_id_delete_entry, "BseDataPocket+delete-entry", NULL, 0, delete_entry_setup, delete_entry_exec, NULL, "/Method/BseDataPocket/General/Delete Entry", { 0, }, },
-  { &type_id_get_n_entries, "BseDataPocket+get-n-entries", NULL, 0, get_n_entries_setup, get_n_entries_exec, NULL, "/Method/BseDataPocket/General/Get N Entries", { 0, }, },
-  { &type_id_get_nth_entry_id, "BseDataPocket+get-nth-entry-id", NULL, 0, get_nth_entry_id_setup, get_nth_entry_id_exec, NULL, "/Method/BseDataPocket/General/Get Nth Entry Id", { 0, }, },
-  { &type_id_set_float, "BseDataPocket+set-float", NULL, 0, set_float_setup, set_float_exec, NULL, "/Method/BseDataPocket/General/Set Float", { 0, }, },
-  { &type_id_set_int, "BseDataPocket+set-int", NULL, 0, set_int_setup, set_int_exec, NULL, "/Method/BseDataPocket/General/Set Int", { 0, }, },
-  { &type_id_set_object, "BseDataPocket+set-object", NULL, 0, set_object_setup, set_object_exec, NULL, "/Method/BseDataPocket/General/Set Object", { 0, }, },
-  { &type_id_set_string, "BseDataPocket+set-string", NULL, 0, set_string_setup, set_string_exec, NULL, "/Method/BseDataPocket/General/Set String", { 0, }, },
-  { &type_id_get_float, "BseDataPocket+get-float", NULL, 0, get_float_setup, get_float_exec, NULL, "/Method/BseDataPocket/General/Get Float", { 0, }, },
-  { &type_id_get_int, "BseDataPocket+get-int", NULL, 0, get_int_setup, get_int_exec, NULL, "/Method/BseDataPocket/General/Get Int", { 0, }, },
-  { &type_id_get_object, "BseDataPocket+get-object", NULL, 0, get_object_setup, get_object_exec, NULL, "/Method/BseDataPocket/General/Get Object", { 0, }, },
-  { &type_id_get_string, "BseDataPocket+get-string", NULL, 0, get_string_setup, get_string_exec, NULL, "/Method/BseDataPocket/General/Get String", { 0, }, },
-  { NULL, },
+static BseExportNodeProc __enode_create_entry = {
+  { NULL, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+create-entry", "/Methods/BseDataPocket/General/Create Entry", NULL },
+  0, create_entry_setup, create_entry_exec, 
 };
-BSE_EXPORTS_END;
+static BseExportNodeProc __enode_delete_entry = {
+  { (BseExportNode*) &__enode_create_entry, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+delete-entry", "/Methods/BseDataPocket/General/Delete Entry", NULL },
+  0, delete_entry_setup, delete_entry_exec, 
+};
+static BseExportNodeProc __enode_get_n_entries = {
+  { (BseExportNode*) &__enode_delete_entry, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+get-n-entries", "/Methods/BseDataPocket/General/Get N Entries", NULL },
+  0, get_n_entries_setup, get_n_entries_exec, 
+};
+static BseExportNodeProc __enode_get_nth_entry_id = {
+  { (BseExportNode*) &__enode_get_n_entries, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+get-nth-entry-id", "/Methods/BseDataPocket/General/Get Nth Entry Id", NULL },
+  0, get_nth_entry_id_setup, get_nth_entry_id_exec, 
+};
+static BseExportNodeProc __enode_set_float = {
+  { (BseExportNode*) &__enode_get_nth_entry_id, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+set-float", "/Methods/BseDataPocket/General/Set Float", NULL },
+  0, set_float_setup, set_float_exec, 
+};
+static BseExportNodeProc __enode_set_int = {
+  { (BseExportNode*) &__enode_set_float, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+set-int", "/Methods/BseDataPocket/General/Set Int", NULL },
+  0, set_int_setup, set_int_exec, 
+};
+static BseExportNodeProc __enode_set_object = {
+  { (BseExportNode*) &__enode_set_int, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+set-object", "/Methods/BseDataPocket/General/Set Object", NULL },
+  0, set_object_setup, set_object_exec, 
+};
+static BseExportNodeProc __enode_set_string = {
+  { (BseExportNode*) &__enode_set_object, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+set-string", "/Methods/BseDataPocket/General/Set String", NULL },
+  0, set_string_setup, set_string_exec, 
+};
+static BseExportNodeProc __enode_get_float = {
+  { (BseExportNode*) &__enode_set_string, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+get-float", "/Methods/BseDataPocket/General/Get Float", NULL },
+  0, get_float_setup, get_float_exec, 
+};
+static BseExportNodeProc __enode_get_int = {
+  { (BseExportNode*) &__enode_get_float, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+get-int", "/Methods/BseDataPocket/General/Get Int", NULL },
+  0, get_int_setup, get_int_exec, 
+};
+static BseExportNodeProc __enode_get_object = {
+  { (BseExportNode*) &__enode_get_int, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+get-object", "/Methods/BseDataPocket/General/Get Object", NULL },
+  0, get_object_setup, get_object_exec, 
+};
+static BseExportNodeProc __enode_get_string = {
+  { (BseExportNode*) &__enode_get_object, BSE_EXPORT_NODE_PROC,
+    "BseDataPocket+get-string", "/Methods/BseDataPocket/General/Get String", NULL },
+  0, get_string_setup, get_string_exec, 
+};
+BseExportNode* bse__builtin_init_bsedatapocket_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bsedatapocket_gen_proc_c (void)
+{
+  return (BseExportNode*) &__enode_get_string;
+}
 
 /**
  ** Generated data ends here
