@@ -20,12 +20,14 @@
 #ifndef __BSE_DEFS_H__
 #define __BSE_DEFS_H__
 
-#undef          G_DISABLE_ASSERT
-#undef          G_DISABLE_CHECKS
-#include        <sfi/sfi.h>
-#include        <sfi/sfistore.h>	// FIXME
-#include	<sfi/sficomwire.h>	// FIXME
-#include	<math.h>
+#undef   G_DISABLE_ASSERT
+#undef   G_DISABLE_CHECKS
+#include <libintl.h>
+#include <sfi/sfi.h>
+#include <sfi/sfistore.h>	// FIXME
+#include <sfi/sficomwire.h>	// FIXME
+#include <math.h>
+#include <bse/bseconfig.h>
 
 
 #ifdef __cplusplus
@@ -34,8 +36,6 @@ extern "C" {
 
 
 /* --- some globally used macros --- */
-#define	_(x)	(x)
-#define	N_(x)	(x)
 #define BSE_VERSION_CMP(v1_major, v1_minor, v1_micro, v2_major, v2_minor, v2_micro) ( \
                                     (v1_major != v2_major) ? (v1_major > v2_major ? +1 : -1) : \
                                     (v1_minor != v2_minor) ? (v1_minor > v2_minor ? +1 : -1) : \
@@ -67,6 +67,7 @@ typedef struct  _BseMidiNotifierClass   BseMidiNotifierClass;
 typedef struct  _BseMidiReceiver        BseMidiReceiver;
 typedef struct  _BseMidiSynth           BseMidiSynth;
 typedef struct  _BseMidiSynthClass      BseMidiSynthClass;
+typedef struct  _BseMidiContext         BseMidiContext;
 typedef struct  _BseObject              BseObject;
 typedef struct  _BseObjectClass         BseObjectClass;
 typedef struct  _BsePart		BsePart;
@@ -104,6 +105,7 @@ typedef struct  _BseWaveRepoClass       BseWaveRepoClass;
 
 
 /* --- BSE aux structures --- */
+typedef struct  _BseExportNode          BseExportNode;
 typedef struct  _BseGlobals             BseGlobals;
 typedef struct  _BsePixdata             BsePixdata;
 typedef struct  _BsePlugin              BsePlugin;
@@ -164,6 +166,15 @@ typedef gboolean      (*BseCategoryForeach)  (const gchar       *category_path,
 
 
 
+/* --- i18n and gettext helpers --- */
+#define _(str)		dgettext (BSE_GETTEXT_DOMAIN, str)
+#ifdef gettext_noop
+#  define N_(str)	gettext_noop (str)
+#else
+#  define N_(str)	(str)
+#endif
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
