@@ -3,17 +3,13 @@
 
 
 /* --- bseexports.h --- */
-  { "BseFileHandlerType", G_TYPE_ENUM, &BSE_TYPE_ID (BseFileHandlerType), bse_file_handler_type_values },
-
-/* --- bsebindata.h --- */
-  { "BseBinDataType", G_TYPE_ENUM, &BSE_TYPE_ID (BseBinDataType), bse_bin_data_type_values },
+  { "BseExportNodeType", G_TYPE_ENUM, &BSE_TYPE_ID (BseExportNodeType), bse_export_node_type_values },
 
 /* --- bsebiquadfilter.h --- */
   { "BseBiquadFilterType", G_TYPE_ENUM, &BSE_TYPE_ID (BseBiquadFilterType), bse_biquad_filter_type_values },
   { "BseBiquadFilterNorm", G_TYPE_ENUM, &BSE_TYPE_ID (BseBiquadFilterNorm), bse_biquad_filter_norm_values },
 
 /* --- bseenums.h --- */
-  { "BseEndianType", G_TYPE_ENUM, &BSE_TYPE_ID (BseEndianType), bse_endian_type_values },
   { "BseRegistrationType", G_TYPE_ENUM, &BSE_TYPE_ID (BseRegistrationType), bse_registration_type_values },
   { "BseInterpolType", G_TYPE_ENUM, &BSE_TYPE_ID (BseInterpolType), bse_interpol_type_values },
   { "BseLoopType", G_TYPE_ENUM, &BSE_TYPE_ID (BseLoopType), bse_loop_type_values },
@@ -26,7 +22,6 @@
 
 /* --- bsemidievent.h --- */
   { "BseMidiEventType", G_TYPE_ENUM, &BSE_TYPE_ID (BseMidiEventType), bse_midi_event_type_values },
-  { "BseMidiSignalType", G_TYPE_ENUM, &BSE_TYPE_ID (BseMidiSignalType), bse_midi_signal_type_values },
 
 /* --- bseproject.h --- */
   { "BseProjectState", G_TYPE_ENUM, &BSE_TYPE_ID (BseProjectState), bse_project_state_values },
