@@ -3,8 +3,8 @@
 
 
 /* --- bseexports.h --- */
-#define BSE_TYPE_FILE_HANDLER_TYPE	    (BSE_TYPE_ID (BseFileHandlerType))
-extern GType BSE_TYPE_ID (BseFileHandlerType);
+#define BSE_TYPE_EXPORT_NODE_TYPE	    (BSE_TYPE_ID (BseExportNodeType))
+extern GType BSE_TYPE_ID (BseExportNodeType);
 
 /* --- bsebiquadfilter.h --- */
 #define BSE_TYPE_BIQUAD_FILTER_TYPE	    (BSE_TYPE_ID (BseBiquadFilterType))
@@ -53,9 +53,6 @@ extern GType BSE_TYPE_ID (BseStandardOscWaveType);
  ** Generated data (by mktypes.pl --externs)
  **/
 
-/* --- bseamplifier.c --- */
-extern GType bse_type_builtin_id_BseAmplifier;
-
 /* --- bsebiquadfilter.c --- */
 extern GType bse_type_builtin_id_BseBiquadFilter;
 
@@ -80,8 +77,8 @@ extern GType bse_type_builtin_id_BseItem;
 /* --- bsejanitor.c --- */
 extern GType bse_type_builtin_id_BseJanitor;
 
-/* --- bsemidiicontroller.c --- */
-extern GType bse_type_builtin_id_BseMidiIController;
+/* --- bsemidicontroller.c --- */
+extern GType bse_type_builtin_id_BseMidiController;
 
 /* --- bsemididevice.c --- */
 extern GType bse_type_builtin_id_BseMidiDevice;
@@ -146,14 +143,14 @@ extern GType bse_type_builtin_id_BseStandardOsc;
 /* --- bsestorage.c --- */
 extern GType bse_type_builtin_id_BseStorage;
 
-/* --- bsesubinstrument.c --- */
-extern GType bse_type_builtin_id_BseSubInstrument;
+/* --- bseinstrumentoutput.c --- */
+extern GType bse_type_builtin_id_BseInstrumentOutput;
 
 /* --- bsesubiport.c --- */
 extern GType bse_type_builtin_id_BseSubIPort;
 
-/* --- bsesubkeyboard.c --- */
-extern GType bse_type_builtin_id_BseSubKeyboard;
+/* --- bseinstrumentinput.c --- */
+extern GType bse_type_builtin_id_BseInstrumentInput;
 
 /* --- bsesuboport.c --- */
 extern GType bse_type_builtin_id_BseSubOPort;
@@ -191,6 +188,9 @@ extern GType bse_type_builtin_id_BseLadspaModule;
 /* --- bsepcmwriter.c --- */
 extern GType bse_type_builtin_id_BsePcmWriter;
 
+/* --- bsemidiinput.c --- */
+extern GType bse_type_builtin_id_BseMidiInput;
+
 /**
  ** Generated data ends here
  **/
@@ -198,7 +198,6 @@ extern GType bse_type_builtin_id_BsePcmWriter;
 /*-------- begin ../sfi/sfidl generated code --------*/
 
 
-
 typedef struct _BseIntSeq BseIntSeq;
 typedef struct _BseNoteSeq BseNoteSeq;
 typedef struct _BseStringSeq BseStringSeq;
@@ -505,6 +504,12 @@ struct _BseSampleFileInfo {
   SfiInt error;
 };
 struct _BseGConfig {
+  gchar* sample_path;
+  gchar* effect_path;
+  gchar* instrument_path;
+  gchar* script_path;
+  gchar* plugin_path;
+  gchar* ladspa_path;
   SfiInt synth_block_size;
   SfiInt synth_mixing_freq;
   SfiBool invert_sustain;
