@@ -252,7 +252,7 @@ bcontext_queue_signal (BContext    *bcontext,
 static GParamSpec*
 bglue_pspec_to_serializable (GParamSpec *pspec)
 {
-  if (BSE_IS_PARAM_SPEC_ENUM (pspec))
+  if (G_IS_PARAM_SPEC_ENUM (pspec))
     {
       GType etype = G_PARAM_SPEC_VALUE_TYPE (pspec);
       pspec = sfi_pspec_choice_from_enum (pspec);
@@ -556,7 +556,7 @@ bglue_describe_proc (SfiGlueContext *context,
       p->blurb = g_strdup (proc->blurb);
       p->help = g_strdup (proc->help);
       p->authors = g_strdup (proc->authors);
-      p->copyright = g_strdup (proc->copyright);
+      p->license = g_strdup (proc->license);
       if (proc->n_out_pspecs)
 	{
 	  GParamSpec *pspec = bglue_pspec_to_serializable (proc->out_pspecs[0]);
@@ -606,7 +606,7 @@ bglue_list_method_names (SfiGlueContext *context,
   prefix = g_strdup_printf ("%s+", g_type_name (type));
   l = strlen (prefix);
   
-  cseq = bse_categories_match_typed ("/Method/" "*", BSE_TYPE_PROCEDURE);
+  cseq = bse_categories_match_typed ("/Methods/" "*", BSE_TYPE_PROCEDURE);
   p = g_new (gchar*, cseq->n_cats + 1);
   n_procs = 0;
   for (i = 0; i < cseq->n_cats; i++)
@@ -709,7 +709,6 @@ bglue_exec_proc (SfiGlueContext *context,
       
       if (error)
         g_message ("while executing \"%s\": %s\n", proc->name, bse_error_blurb (error));
-      
       if (proc->n_out_pspecs)
 	retval = bglue_value_to_serializable (ovalues + 0);
       for (i = 0; i < proc->n_out_pspecs; i++)
