@@ -16,7 +16,6 @@
 
 
 /* --- get-type --- */
-static GType type_id_get_type = 0;
 static void
 get_type_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 31 "bseitem.proc"
@@ -31,7 +30,7 @@ get_type_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **ou
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 37 "bseitem.proc"
 }  }
 static BseErrorType
@@ -58,7 +57,6 @@ get_type_exec (BseProcedureClass *proc,
 }
 
 /* --- get-type-name --- */
-static GType type_id_get_type_name = 0;
 static void
 get_type_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 54 "bseitem.proc"
@@ -74,7 +72,7 @@ get_type_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 61 "bseitem.proc"
 }  }
 static BseErrorType
@@ -101,7 +99,6 @@ get_type_name_exec (BseProcedureClass *proc,
 }
 
 /* --- get-type-blurb --- */
-static GType type_id_get_type_blurb = 0;
 static void
 get_type_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 78 "bseitem.proc"
@@ -117,7 +114,7 @@ get_type_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 85 "bseitem.proc"
 }  }
 static BseErrorType
@@ -144,7 +141,6 @@ get_type_blurb_exec (BseProcedureClass *proc,
 }
 
 /* --- get-parent --- */
-static GType type_id_get_parent = 0;
 static void
 get_parent_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 102 "bseitem.proc"
@@ -159,7 +155,7 @@ get_parent_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 108 "bseitem.proc"
 }  }
 static BseErrorType
@@ -186,7 +182,6 @@ get_parent_exec (BseProcedureClass *proc,
 }
 
 /* --- get-project --- */
-static GType type_id_get_project = 0;
 static void
 get_project_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 125 "bseitem.proc"
@@ -201,7 +196,7 @@ get_project_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 131 "bseitem.proc"
 }  }
 static BseErrorType
@@ -228,7 +223,6 @@ get_project_exec (BseProcedureClass *proc,
 }
 
 /* --- get-uname-path --- */
-static GType type_id_get_uname_path = 0;
 static void
 get_uname_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 148 "bseitem.proc"
@@ -243,7 +237,7 @@ get_uname_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 154 "bseitem.proc"
 }  }
 static BseErrorType
@@ -274,7 +268,6 @@ get_uname_path_exec (BseProcedureClass *proc,
 }
 
 /* --- internal --- */
-static GType type_id_internal = 0;
 static void
 internal_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 175 "bseitem.proc"
@@ -289,7 +282,7 @@ internal_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **ou
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 181 "bseitem.proc"
 }  }
 static BseErrorType
@@ -316,7 +309,6 @@ internal_exec (BseProcedureClass *proc,
 }
 
 /* --- use --- */
-static GType type_id_use = 0;
 static void
 use_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 198 "bseitem.proc"
@@ -331,7 +323,7 @@ use_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_psp
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 204 "bseitem.proc"
 }  }
 static BseErrorType
@@ -362,7 +354,6 @@ use_exec (BseProcedureClass *proc,
 }
 
 /* --- unuse --- */
-static GType type_id_unuse = 0;
 static void
 unuse_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 224 "bseitem.proc"
@@ -375,7 +366,7 @@ unuse_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_p
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 228 "bseitem.proc"
 }  }
 static BseErrorType
@@ -405,7 +396,6 @@ unuse_exec (BseProcedureClass *proc,
 }
 
 /* --- set-name --- */
-static GType type_id_set_name = 0;
 static void
 set_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 248 "bseitem.proc"
@@ -420,7 +410,7 @@ set_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **ou
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 254 "bseitem.proc"
 }  }
 static BseErrorType
@@ -450,7 +440,6 @@ set_name_exec (BseProcedureClass *proc,
 
 
 /* --- get-name --- */
-static GType type_id_get_name = 0;
 static void
 get_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 274 "bseitem.proc"
@@ -465,7 +454,7 @@ get_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **ou
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 280 "bseitem.proc"
 }  }
 static BseErrorType
@@ -492,7 +481,6 @@ get_name_exec (BseProcedureClass *proc,
 }
 
 /* --- get-name-or-type --- */
-static GType type_id_get_name_or_type = 0;
 static void
 get_name_or_type_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 297 "bseitem.proc"
@@ -507,7 +495,7 @@ get_name_or_type_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 303 "bseitem.proc"
 }  }
 static BseErrorType
@@ -539,7 +527,6 @@ get_name_or_type_exec (BseProcedureClass *proc,
 }
 
 /* --- common-ancestor --- */
-static GType type_id_common_ancestor = 0;
 static void
 common_ancestor_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 325 "bseitem.proc"
@@ -556,7 +543,7 @@ common_ancestor_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 333 "bseitem.proc"
 }  }
 static BseErrorType
@@ -584,7 +571,6 @@ common_ancestor_exec (BseProcedureClass *proc,
 }
 
 /* --- get-seqid --- */
-static GType type_id_get_seqid = 0;
 static void
 get_seqid_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 351 "bseitem.proc"
@@ -601,7 +587,7 @@ get_seqid_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 359 "bseitem.proc"
 }  }
 static BseErrorType
@@ -628,7 +614,6 @@ get_seqid_exec (BseProcedureClass *proc,
 }
 
 /* --- check-is-a --- */
-static GType type_id_check_is_a = 0;
 static void
 check_is_a_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 376 "bseitem.proc"
@@ -643,7 +628,7 @@ check_is_a_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 384 "bseitem.proc"
 }  }
 static BseErrorType
@@ -678,7 +663,6 @@ check_is_a_exec (BseProcedureClass *proc,
 }
 
 /* --- list-proxies --- */
-static GType type_id_list_proxies = 0;
 static void
 list_proxies_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 408 "bseitem.proc"
@@ -694,7 +678,7 @@ list_proxies_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 415 "bseitem.proc"
 }  }
 static BseErrorType
@@ -722,7 +706,6 @@ list_proxies_exec (BseProcedureClass *proc,
 }
 
 /* --- get-icon --- */
-static GType type_id_get_icon = 0;
 static void
 get_icon_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 433 "bseitem.proc"
@@ -737,7 +720,7 @@ get_icon_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **ou
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 439 "bseitem.proc"
 }  }
 static BseErrorType
@@ -764,7 +747,6 @@ get_icon_exec (BseProcedureClass *proc,
 }
 
 /* --- group-undo --- */
-static GType type_id_group_undo = 0;
 static void
 group_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 456 "bseitem.proc"
@@ -779,7 +761,7 @@ group_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 462 "bseitem.proc"
 }  }
 static BseErrorType
@@ -808,7 +790,6 @@ group_undo_exec (BseProcedureClass *proc,
 }
 
 /* --- ungroup-undo --- */
-static GType type_id_ungroup_undo = 0;
 static void
 ungroup_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 482 "bseitem.proc"
@@ -821,7 +802,7 @@ ungroup_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 486 "bseitem.proc"
 }  }
 static BseErrorType
@@ -849,7 +830,6 @@ ungroup_undo_exec (BseProcedureClass *proc,
 }
 
 /* --- undo --- */
-static GType type_id_undo = 0;
 static void
 undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 505 "bseitem.proc"
@@ -862,7 +842,7 @@ undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_ps
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 509 "bseitem.proc"
 }  }
 static BseErrorType
@@ -890,7 +870,6 @@ undo_exec (BseProcedureClass *proc,
 }
 
 /* --- redo --- */
-static GType type_id_redo = 0;
 static void
 redo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 528 "bseitem.proc"
@@ -903,7 +882,7 @@ redo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_ps
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 532 "bseitem.proc"
 }  }
 static BseErrorType
@@ -931,7 +910,6 @@ redo_exec (BseProcedureClass *proc,
 }
 
 /* --- clear-undo --- */
-static GType type_id_clear_undo = 0;
 static void
 clear_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 551 "bseitem.proc"
@@ -944,7 +922,7 @@ clear_undo_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 555 "bseitem.proc"
 }  }
 static BseErrorType
@@ -972,7 +950,6 @@ clear_undo_exec (BseProcedureClass *proc,
 }
 
 /* --- undo-depth --- */
-static GType type_id_undo_depth = 0;
 static void
 undo_depth_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 574 "bseitem.proc"
@@ -987,7 +964,7 @@ undo_depth_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 580 "bseitem.proc"
 }  }
 static BseErrorType
@@ -1020,7 +997,6 @@ undo_depth_exec (BseProcedureClass *proc,
 }
 
 /* --- redo-depth --- */
-static GType type_id_redo_depth = 0;
 static void
 redo_depth_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 603 "bseitem.proc"
@@ -1035,7 +1011,7 @@ redo_depth_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 609 "bseitem.proc"
 }  }
 static BseErrorType
@@ -1068,7 +1044,6 @@ redo_depth_exec (BseProcedureClass *proc,
 }
 
 /* --- fixme-set-parasite --- */
-static GType type_id_fixme_set_parasite = 0;
 static void
 fixme_set_parasite_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 632 "bseitem.proc"
@@ -1081,7 +1056,7 @@ fixme_set_parasite_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPara
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 637 "bseitem.proc"
 }  }
 static BseErrorType
@@ -1110,7 +1085,6 @@ fixme_set_parasite_exec (BseProcedureClass *proc,
 }
 
 /* --- fixme-get-parasite --- */
-static GType type_id_fixme_get_parasite = 0;
 static void
 fixme_get_parasite_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 656 "bseitem.proc"
@@ -1123,7 +1097,7 @@ fixme_get_parasite_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPara
 #line 27 "bseitem.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 28 "bseitem.proc"
-  proc->copyright = "Copyright (C) 2001-2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 661 "bseitem.proc"
 }  }
 static BseErrorType
@@ -1151,37 +1125,141 @@ fixme_get_parasite_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { &type_id_get_type, "BseItem+get-type", NULL, 0, get_type_setup, get_type_exec, NULL, "/Method/BseItem/General/Get Type", { 0, }, },
-  { &type_id_get_type_name, "BseItem+get-type-name", NULL, 0, get_type_name_setup, get_type_name_exec, NULL, "/Method/BseItem/General/Get Type Name", { 0, }, },
-  { &type_id_get_type_blurb, "BseItem+get-type-blurb", NULL, 0, get_type_blurb_setup, get_type_blurb_exec, NULL, "/Method/BseItem/General/Get Type Blurb", { 0, }, },
-  { &type_id_get_parent, "BseItem+get-parent", NULL, 0, get_parent_setup, get_parent_exec, NULL, "/Method/BseItem/General/Get Parent", { 0, }, },
-  { &type_id_get_project, "BseItem+get-project", NULL, 0, get_project_setup, get_project_exec, NULL, "/Method/BseItem/General/Get Project", { 0, }, },
-  { &type_id_get_uname_path, "BseItem+get-uname-path", NULL, 0, get_uname_path_setup, get_uname_path_exec, NULL, "/Method/BseItem/General/Get Uname Path", { 0, }, },
-  { &type_id_internal, "BseItem+internal", NULL, 0, internal_setup, internal_exec, NULL, "/Method/BseItem/General/Internal", { 0, }, },
-  { &type_id_use, "BseItem+use", NULL, 0, use_setup, use_exec, NULL, "/Method/BseItem/General/Use", { 0, }, },
-  { &type_id_unuse, "BseItem+unuse", NULL, 0, unuse_setup, unuse_exec, NULL, "/Method/BseItem/General/Unuse", { 0, }, },
-  { &type_id_set_name, "BseItem+set-name", NULL, 0, set_name_setup, set_name_exec, NULL, "/Method/BseItem/General/Set Name", { 0, }, },
-  { &type_id_get_name, "BseItem+get-name", NULL, 0, get_name_setup, get_name_exec, NULL, "/Method/BseItem/General/Get Name", { 0, }, },
-  { &type_id_get_name_or_type, "BseItem+get-name-or-type", NULL, 0, get_name_or_type_setup, get_name_or_type_exec, NULL, "/Method/BseItem/General/Get Name Or Type", { 0, }, },
-  { &type_id_common_ancestor, "BseItem+common-ancestor", NULL, 0, common_ancestor_setup, common_ancestor_exec, NULL, "/Method/BseItem/General/Common Ancestor", { 0, }, },
-  { &type_id_get_seqid, "BseItem+get-seqid", NULL, 0, get_seqid_setup, get_seqid_exec, NULL, "/Method/BseItem/General/Get Seqid", { 0, }, },
-  { &type_id_check_is_a, "BseItem+check-is-a", "Check whether an item has a certain type.", 0, check_is_a_setup, check_is_a_exec, NULL, "/Method/BseItem/General/Check Is A", { 0, }, },
-  { &type_id_list_proxies, "BseItem+list-proxies", NULL, 0, list_proxies_setup, list_proxies_exec, NULL, "/Method/BseItem/General/List Proxies", { 0, }, },
-  { &type_id_get_icon, "BseItem+get-icon", NULL, 0, get_icon_setup, get_icon_exec, NULL, "/Method/BseItem/General/Get Icon", { 0, }, },
-  { &type_id_group_undo, "BseItem+group-undo", NULL, 0, group_undo_setup, group_undo_exec, NULL, "/Method/BseItem/General/Group Undo", { 0, }, },
-  { &type_id_ungroup_undo, "BseItem+ungroup-undo", NULL, 0, ungroup_undo_setup, ungroup_undo_exec, NULL, "/Method/BseItem/General/Ungroup Undo", { 0, }, },
-  { &type_id_undo, "BseItem+undo", NULL, 0, undo_setup, undo_exec, NULL, "/Method/BseItem/General/Undo", { 0, }, },
-  { &type_id_redo, "BseItem+redo", NULL, 0, redo_setup, redo_exec, NULL, "/Method/BseItem/General/Redo", { 0, }, },
-  { &type_id_clear_undo, "BseItem+clear-undo", NULL, 0, clear_undo_setup, clear_undo_exec, NULL, "/Method/BseItem/General/Clear Undo", { 0, }, },
-  { &type_id_undo_depth, "BseItem+undo-depth", NULL, 0, undo_depth_setup, undo_depth_exec, NULL, "/Method/BseItem/General/Undo Depth", { 0, }, },
-  { &type_id_redo_depth, "BseItem+redo-depth", NULL, 0, redo_depth_setup, redo_depth_exec, NULL, "/Method/BseItem/General/Redo Depth", { 0, }, },
-  { &type_id_fixme_set_parasite, "BseItem+fixme-set-parasite", NULL, 0, fixme_set_parasite_setup, fixme_set_parasite_exec, NULL, "/Method/BseItem/General/Fixme Set Parasite", { 0, }, },
-  { &type_id_fixme_get_parasite, "BseItem+fixme-get-parasite", NULL, 0, fixme_get_parasite_setup, fixme_get_parasite_exec, NULL, "/Method/BseItem/General/Fixme Get Parasite", { 0, }, },
-  { NULL, },
+static BseExportNodeProc __enode_get_type = {
+  { NULL, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-type", "/Methods/BseItem/General/Get Type", NULL },
+  0, get_type_setup, get_type_exec, 
 };
-BSE_EXPORTS_END;
+static BseExportNodeProc __enode_get_type_name = {
+  { (BseExportNode*) &__enode_get_type, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-type-name", "/Methods/BseItem/General/Get Type Name", NULL },
+  0, get_type_name_setup, get_type_name_exec, 
+};
+static BseExportNodeProc __enode_get_type_blurb = {
+  { (BseExportNode*) &__enode_get_type_name, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-type-blurb", "/Methods/BseItem/General/Get Type Blurb", NULL },
+  0, get_type_blurb_setup, get_type_blurb_exec, 
+};
+static BseExportNodeProc __enode_get_parent = {
+  { (BseExportNode*) &__enode_get_type_blurb, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-parent", "/Methods/BseItem/General/Get Parent", NULL },
+  0, get_parent_setup, get_parent_exec, 
+};
+static BseExportNodeProc __enode_get_project = {
+  { (BseExportNode*) &__enode_get_parent, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-project", "/Methods/BseItem/General/Get Project", NULL },
+  0, get_project_setup, get_project_exec, 
+};
+static BseExportNodeProc __enode_get_uname_path = {
+  { (BseExportNode*) &__enode_get_project, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-uname-path", "/Methods/BseItem/General/Get Uname Path", NULL },
+  0, get_uname_path_setup, get_uname_path_exec, 
+};
+static BseExportNodeProc __enode_internal = {
+  { (BseExportNode*) &__enode_get_uname_path, BSE_EXPORT_NODE_PROC,
+    "BseItem+internal", "/Methods/BseItem/General/Internal", NULL },
+  0, internal_setup, internal_exec, 
+};
+static BseExportNodeProc __enode_use = {
+  { (BseExportNode*) &__enode_internal, BSE_EXPORT_NODE_PROC,
+    "BseItem+use", "/Methods/BseItem/General/Use", NULL },
+  0, use_setup, use_exec, 
+};
+static BseExportNodeProc __enode_unuse = {
+  { (BseExportNode*) &__enode_use, BSE_EXPORT_NODE_PROC,
+    "BseItem+unuse", "/Methods/BseItem/General/Unuse", NULL },
+  0, unuse_setup, unuse_exec, 
+};
+static BseExportNodeProc __enode_set_name = {
+  { (BseExportNode*) &__enode_unuse, BSE_EXPORT_NODE_PROC,
+    "BseItem+set-name", "/Methods/BseItem/General/Set Name", NULL },
+  0, set_name_setup, set_name_exec, 
+};
+static BseExportNodeProc __enode_get_name = {
+  { (BseExportNode*) &__enode_set_name, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-name", "/Methods/BseItem/General/Get Name", NULL },
+  0, get_name_setup, get_name_exec, 
+};
+static BseExportNodeProc __enode_get_name_or_type = {
+  { (BseExportNode*) &__enode_get_name, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-name-or-type", "/Methods/BseItem/General/Get Name Or Type", NULL },
+  0, get_name_or_type_setup, get_name_or_type_exec, 
+};
+static BseExportNodeProc __enode_common_ancestor = {
+  { (BseExportNode*) &__enode_get_name_or_type, BSE_EXPORT_NODE_PROC,
+    "BseItem+common-ancestor", "/Methods/BseItem/General/Common Ancestor", NULL },
+  0, common_ancestor_setup, common_ancestor_exec, 
+};
+static BseExportNodeProc __enode_get_seqid = {
+  { (BseExportNode*) &__enode_common_ancestor, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-seqid", "/Methods/BseItem/General/Get Seqid", NULL },
+  0, get_seqid_setup, get_seqid_exec, 
+};
+static BseExportNodeProc __enode_check_is_a = {
+  { (BseExportNode*) &__enode_get_seqid, BSE_EXPORT_NODE_PROC,
+    "BseItem+check-is-a", "/Methods/BseItem/General/Check Is A", "Check whether an item has a certain type." },
+  0, check_is_a_setup, check_is_a_exec, 
+};
+static BseExportNodeProc __enode_list_proxies = {
+  { (BseExportNode*) &__enode_check_is_a, BSE_EXPORT_NODE_PROC,
+    "BseItem+list-proxies", "/Methods/BseItem/General/List Proxies", NULL },
+  0, list_proxies_setup, list_proxies_exec, 
+};
+static BseExportNodeProc __enode_get_icon = {
+  { (BseExportNode*) &__enode_list_proxies, BSE_EXPORT_NODE_PROC,
+    "BseItem+get-icon", "/Methods/BseItem/General/Get Icon", NULL },
+  0, get_icon_setup, get_icon_exec, 
+};
+static BseExportNodeProc __enode_group_undo = {
+  { (BseExportNode*) &__enode_get_icon, BSE_EXPORT_NODE_PROC,
+    "BseItem+group-undo", "/Methods/BseItem/General/Group Undo", NULL },
+  0, group_undo_setup, group_undo_exec, 
+};
+static BseExportNodeProc __enode_ungroup_undo = {
+  { (BseExportNode*) &__enode_group_undo, BSE_EXPORT_NODE_PROC,
+    "BseItem+ungroup-undo", "/Methods/BseItem/General/Ungroup Undo", NULL },
+  0, ungroup_undo_setup, ungroup_undo_exec, 
+};
+static BseExportNodeProc __enode_undo = {
+  { (BseExportNode*) &__enode_ungroup_undo, BSE_EXPORT_NODE_PROC,
+    "BseItem+undo", "/Methods/BseItem/General/Undo", NULL },
+  0, undo_setup, undo_exec, 
+};
+static BseExportNodeProc __enode_redo = {
+  { (BseExportNode*) &__enode_undo, BSE_EXPORT_NODE_PROC,
+    "BseItem+redo", "/Methods/BseItem/General/Redo", NULL },
+  0, redo_setup, redo_exec, 
+};
+static BseExportNodeProc __enode_clear_undo = {
+  { (BseExportNode*) &__enode_redo, BSE_EXPORT_NODE_PROC,
+    "BseItem+clear-undo", "/Methods/BseItem/General/Clear Undo", NULL },
+  0, clear_undo_setup, clear_undo_exec, 
+};
+static BseExportNodeProc __enode_undo_depth = {
+  { (BseExportNode*) &__enode_clear_undo, BSE_EXPORT_NODE_PROC,
+    "BseItem+undo-depth", "/Methods/BseItem/General/Undo Depth", NULL },
+  0, undo_depth_setup, undo_depth_exec, 
+};
+static BseExportNodeProc __enode_redo_depth = {
+  { (BseExportNode*) &__enode_undo_depth, BSE_EXPORT_NODE_PROC,
+    "BseItem+redo-depth", "/Methods/BseItem/General/Redo Depth", NULL },
+  0, redo_depth_setup, redo_depth_exec, 
+};
+static BseExportNodeProc __enode_fixme_set_parasite = {
+  { (BseExportNode*) &__enode_redo_depth, BSE_EXPORT_NODE_PROC,
+    "BseItem+fixme-set-parasite", "/Methods/BseItem/General/Fixme Set Parasite", NULL },
+  0, fixme_set_parasite_setup, fixme_set_parasite_exec, 
+};
+static BseExportNodeProc __enode_fixme_get_parasite = {
+  { (BseExportNode*) &__enode_fixme_set_parasite, BSE_EXPORT_NODE_PROC,
+    "BseItem+fixme-get-parasite", "/Methods/BseItem/General/Fixme Get Parasite", NULL },
+  0, fixme_get_parasite_setup, fixme_get_parasite_exec, 
+};
+BseExportNode* bse__builtin_init_bseitem_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bseitem_gen_proc_c (void)
+{
+  return (BseExportNode*) &__enode_fixme_get_parasite;
+}
 
 /**
  ** Generated data ends here
