@@ -15,7 +15,6 @@
 
 
 /* --- trigger-action --- */
-static GType type_id_trigger_action = 0;
 static void
 trigger_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 29 "bsejanitor.proc"
@@ -31,7 +30,7 @@ trigger_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 36 "bsejanitor.proc"
  }
 static BseErrorType
@@ -59,7 +58,6 @@ trigger_action_exec (BseProcedureClass *proc,
 }
 
 /* --- get-script-name --- */
-static GType type_id_get_script_name = 0;
 static void
 get_script_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 54 "bsejanitor.proc"
@@ -75,7 +73,7 @@ get_script_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 61 "bsejanitor.proc"
  }
 static BseErrorType
@@ -102,7 +100,6 @@ get_script_name_exec (BseProcedureClass *proc,
 }
 
 /* --- get-proc-name --- */
-static GType type_id_get_proc_name = 0;
 static void
 get_proc_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 78 "bsejanitor.proc"
@@ -118,7 +115,7 @@ get_proc_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 85 "bsejanitor.proc"
  }
 static BseErrorType
@@ -145,7 +142,6 @@ get_proc_name_exec (BseProcedureClass *proc,
 }
 
 /* --- n-actions --- */
-static GType type_id_n_actions = 0;
 static void
 n_actions_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 102 "bsejanitor.proc"
@@ -161,7 +157,7 @@ n_actions_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 109 "bsejanitor.proc"
  }
 static BseErrorType
@@ -188,7 +184,6 @@ n_actions_exec (BseProcedureClass *proc,
 }
 
 /* --- get-action --- */
-static GType type_id_get_action = 0;
 static void
 get_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 126 "bsejanitor.proc"
@@ -206,7 +201,7 @@ get_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 135 "bsejanitor.proc"
  }
 static BseErrorType
@@ -237,7 +232,6 @@ get_action_exec (BseProcedureClass *proc,
 }
 
 /* --- get-action-name --- */
-static GType type_id_get_action_name = 0;
 static void
 get_action_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 156 "bsejanitor.proc"
@@ -255,7 +249,7 @@ get_action_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 165 "bsejanitor.proc"
  }
 static BseErrorType
@@ -286,7 +280,6 @@ get_action_name_exec (BseProcedureClass *proc,
 }
 
 /* --- get-action-blurb --- */
-static GType type_id_get_action_blurb = 0;
 static void
 get_action_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 186 "bsejanitor.proc"
@@ -304,7 +297,7 @@ get_action_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 195 "bsejanitor.proc"
  }
 static BseErrorType
@@ -335,7 +328,6 @@ get_action_blurb_exec (BseProcedureClass *proc,
 }
 
 /* --- kill --- */
-static GType type_id_kill = 0;
 static void
 kill_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 216 "bsejanitor.proc"
@@ -349,7 +341,7 @@ kill_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_ps
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 221 "bsejanitor.proc"
  }
 static BseErrorType
@@ -370,19 +362,17 @@ kill_exec (BseProcedureClass *proc,
   
 #line 232 "bsejanitor.proc"
   
-  if (!self->kill_pending)
-    bse_janitor_queue_kill (self);
+  bse_janitor_kill (self);
   
   return BSE_ERROR_NONE;
 }
 
 /* --- add-action --- */
-static GType type_id_add_action = 0;
 static void
 add_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 239 "bsejanitor.proc"
+#line 238 "bsejanitor.proc"
  {
-#line 241 "bsejanitor.proc"
+#line 240 "bsejanitor.proc"
   *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
 				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
   *(in_pspecs++) = sfi_pspec_string ("action", "Action", NULL,
@@ -392,39 +382,39 @@ add_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
   *(in_pspecs++) = sfi_pspec_string ("blurb", "Blurb", NULL,
 			    NULL, SFI_PARAM_DEFAULT);
 }
-#line 240 "bsejanitor.proc"
+#line 239 "bsejanitor.proc"
   proc->help = "Install a user action for script control.";
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
-#line 250 "bsejanitor.proc"
+  proc->license = "GNU General Public License";
+#line 249 "bsejanitor.proc"
  }
 static BseErrorType
-#line 250 "bsejanitor.proc"
+#line 249 "bsejanitor.proc"
 add_action_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 253 "bsejanitor.proc"
+#line 252 "bsejanitor.proc"
 {
-#line 254 "bsejanitor.proc"
+#line 253 "bsejanitor.proc"
   
   BseJanitor       *self   = bse_value_get_object (in_values++);
   const gchar      *action = sfi_value_get_string (in_values++);
   const gchar      *name   = sfi_value_get_string (in_values++);
   const gchar      *blurb  = sfi_value_get_string (in_values++);
   
-#line 260 "bsejanitor.proc"
+#line 259 "bsejanitor.proc"
   
   if (!BSE_IS_JANITOR (self) || !action || !name)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 264 "bsejanitor.proc"
+#line 263 "bsejanitor.proc"
   
-  if (!self->port || self->kill_pending)
+  if (!self->port || self->close_pending)
     return BSE_ERROR_PROC_EXECUTION;
   
-#line 268 "bsejanitor.proc"
+#line 267 "bsejanitor.proc"
   
   bse_janitor_add_action (self, action, name, blurb);
   
@@ -432,48 +422,47 @@ add_action_exec (BseProcedureClass *proc,
 }
 
 /* --- remove-action --- */
-static GType type_id_remove_action = 0;
 static void
 remove_action_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 274 "bsejanitor.proc"
+#line 273 "bsejanitor.proc"
  {
-#line 276 "bsejanitor.proc"
+#line 275 "bsejanitor.proc"
   *(in_pspecs++) = bse_param_spec_object ("janitor", "Janitor", NULL,
 				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
   *(in_pspecs++) = sfi_pspec_string ("action", "Action", NULL,
 			    NULL, SFI_PARAM_DEFAULT);
 }
-#line 275 "bsejanitor.proc"
+#line 274 "bsejanitor.proc"
   proc->help = "Remove a previously installed user action from script control.";
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
-#line 281 "bsejanitor.proc"
+  proc->license = "GNU General Public License";
+#line 280 "bsejanitor.proc"
  }
 static BseErrorType
-#line 281 "bsejanitor.proc"
+#line 280 "bsejanitor.proc"
 remove_action_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 284 "bsejanitor.proc"
+#line 283 "bsejanitor.proc"
 {
-#line 285 "bsejanitor.proc"
+#line 284 "bsejanitor.proc"
   
   BseJanitor  *self = bse_value_get_object (in_values++);
   const gchar *action = sfi_value_get_string (in_values++);
   
-#line 289 "bsejanitor.proc"
+#line 288 "bsejanitor.proc"
   
   if (!BSE_IS_JANITOR (self) || !action)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 293 "bsejanitor.proc"
+#line 292 "bsejanitor.proc"
   
-  if (!self->port || self->kill_pending)
+  if (!self->port || self->close_pending)
     return BSE_ERROR_PROC_EXECUTION;
   
-#line 297 "bsejanitor.proc"
+#line 296 "bsejanitor.proc"
   
   bse_janitor_remove_action (self, action);
   
@@ -481,38 +470,37 @@ remove_action_exec (BseProcedureClass *proc,
 }
 
 /* --- bse-janitor-get-specific --- */
-static GType type_id_bse_janitor_get_specific = 0;
 static void
 bse_janitor_get_specific_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 303 "bsejanitor.proc"
+#line 302 "bsejanitor.proc"
  {
-#line 305 "bsejanitor.proc"
+#line 304 "bsejanitor.proc"
   *(out_pspecs++)   = bse_param_spec_object ("janitor", "Janitor", NULL,
 				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
 }
-#line 304 "bsejanitor.proc"
+#line 303 "bsejanitor.proc"
   proc->help = "Retrieve the connection dependant janitor object.";
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
-#line 308 "bsejanitor.proc"
+  proc->license = "GNU General Public License";
+#line 307 "bsejanitor.proc"
  }
 static BseErrorType
-#line 308 "bsejanitor.proc"
+#line 307 "bsejanitor.proc"
 bse_janitor_get_specific_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 311 "bsejanitor.proc"
+#line 310 "bsejanitor.proc"
 {
   BseJanitor *self = bse_janitor_get_current ();
   
-#line 314 "bsejanitor.proc"
+#line 313 "bsejanitor.proc"
   
-  if (!self || !self->port || self->kill_pending)
+  if (!self || !self->port || self->close_pending)
     return BSE_ERROR_PROC_EXECUTION;
 
-#line 318 "bsejanitor.proc"
+#line 317 "bsejanitor.proc"
   
   bse_value_set_object (out_values++, self);
   
@@ -520,12 +508,11 @@ bse_janitor_get_specific_exec (BseProcedureClass *proc,
 }
 
 /* --- set-msg --- */
-static GType type_id_set_msg = 0;
 static void
 set_msg_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 324 "bsejanitor.proc"
+#line 323 "bsejanitor.proc"
  {
-#line 326 "bsejanitor.proc"
+#line 325 "bsejanitor.proc"
   *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
 				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
   *(in_pspecs++)    = bse_param_spec_genum ("msg_type", "Message Type", NULL,
@@ -533,35 +520,35 @@ set_msg_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out
 				SFI_PARAM_DEFAULT);
   *(in_pspecs++)    = sfi_pspec_string ("message", "Message", NULL,
 			    NULL, SFI_PARAM_DEFAULT);
-#line 325 "bsejanitor.proc"
+#line 324 "bsejanitor.proc"
   proc->help = "Alter script status message.";
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
-#line 333 "bsejanitor.proc"
+  proc->license = "GNU General Public License";
+#line 332 "bsejanitor.proc"
 }  }
 static BseErrorType
-#line 333 "bsejanitor.proc"
+#line 332 "bsejanitor.proc"
 set_msg_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 336 "bsejanitor.proc"
+#line 335 "bsejanitor.proc"
 {
-#line 337 "bsejanitor.proc"
+#line 336 "bsejanitor.proc"
   
   BseJanitor    *self = bse_value_get_object (in_values++);
   BseUserMsgType mtype   = g_value_get_enum (in_values++);
   const gchar   *message = sfi_value_get_string (in_values++);
   
-#line 342 "bsejanitor.proc"
+#line 341 "bsejanitor.proc"
   
   if (!BSE_IS_JANITOR (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 346 "bsejanitor.proc"
+#line 345 "bsejanitor.proc"
   
-  if (!self->port || self->kill_pending)
+  if (!self->port || self->close_pending)
     return BSE_ERROR_PROC_EXECUTION;
   if (!message)
     {
@@ -569,9 +556,9 @@ set_msg_exec (BseProcedureClass *proc,
       mtype = BSE_USER_MSG_INFO;
     }
   
-#line 355 "bsejanitor.proc"
+#line 354 "bsejanitor.proc"
   
-  g_object_set (self,
+  bse_item_set (self,
 		"user_msg_type", mtype,
 		"user_msg", message,
 		NULL);
@@ -580,48 +567,47 @@ set_msg_exec (BseProcedureClass *proc,
 }
 
 /* --- progress --- */
-static GType type_id_progress = 0;
 static void
 progress_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 364 "bsejanitor.proc"
+#line 363 "bsejanitor.proc"
  {
-#line 366 "bsejanitor.proc"
+#line 365 "bsejanitor.proc"
   *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
 				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
   *(in_pspecs++)    = sfi_pspec_real ("progress", "Progress", NULL,
 			  -1, -1, 1.0, 0.1,
 			  SFI_PARAM_DEFAULT);
-#line 365 "bsejanitor.proc"
+#line 364 "bsejanitor.proc"
   proc->help = "Indicate progress (from 0.0 to 1.0 or -1 for unknown amount).";
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
-#line 371 "bsejanitor.proc"
+  proc->license = "GNU General Public License";
+#line 370 "bsejanitor.proc"
 }  }
 static BseErrorType
-#line 371 "bsejanitor.proc"
+#line 370 "bsejanitor.proc"
 progress_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 374 "bsejanitor.proc"
+#line 373 "bsejanitor.proc"
 {
-#line 375 "bsejanitor.proc"
+#line 374 "bsejanitor.proc"
   
   BseJanitor *self = bse_value_get_object (in_values++);
   gfloat progress  = sfi_value_get_real (in_values++);
   
-#line 379 "bsejanitor.proc"
+#line 378 "bsejanitor.proc"
   
   if (!BSE_IS_JANITOR (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 383 "bsejanitor.proc"
+#line 382 "bsejanitor.proc"
   
-  if (!self->port || self->kill_pending)
+  if (!self->port || self->close_pending)
     return BSE_ERROR_PROC_EXECUTION;
   
-#line 387 "bsejanitor.proc"
+#line 386 "bsejanitor.proc"
   
   bse_janitor_progress (self, progress);
   
@@ -629,12 +615,11 @@ progress_exec (BseProcedureClass *proc,
 }
 
 /* --- exit --- */
-static GType type_id_exit = 0;
 static void
 exit_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 393 "bsejanitor.proc"
+#line 392 "bsejanitor.proc"
  {
-#line 395 "bsejanitor.proc"
+#line 394 "bsejanitor.proc"
   *(in_pspecs++)    = bse_param_spec_object ("janitor", "Janitor", NULL,
 				 BSE_TYPE_JANITOR, SFI_PARAM_DEFAULT);
   *(in_pspecs++)    = bse_param_spec_genum ("msg_type", "Message Type", NULL,
@@ -642,65 +627,121 @@ exit_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_ps
 				SFI_PARAM_DEFAULT);
   *(in_pspecs++)    = sfi_pspec_string ("message", "Message", NULL,
 			    NULL, SFI_PARAM_DEFAULT);
-#line 394 "bsejanitor.proc"
+#line 393 "bsejanitor.proc"
   proc->help = "Exit a script, leaving a message.";
 #line 25 "bsejanitor.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 26 "bsejanitor.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
-#line 402 "bsejanitor.proc"
+  proc->license = "GNU General Public License";
+#line 401 "bsejanitor.proc"
 }  }
 static BseErrorType
-#line 402 "bsejanitor.proc"
+#line 401 "bsejanitor.proc"
 exit_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 405 "bsejanitor.proc"
+#line 404 "bsejanitor.proc"
 {
-#line 406 "bsejanitor.proc"
+#line 405 "bsejanitor.proc"
   
   BseJanitor *self       = bse_value_get_object (in_values++);
   BseUserMsgType mtype   = g_value_get_enum (in_values++);
   const gchar   *message = sfi_value_get_string (in_values++);
   
-#line 411 "bsejanitor.proc"
+#line 410 "bsejanitor.proc"
   
   if (!BSE_IS_JANITOR (self) || !message)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 415 "bsejanitor.proc"
+#line 414 "bsejanitor.proc"
   
-  if (!BSE_IS_JANITOR (self) || !self->port || self->kill_pending)
+  if (!BSE_IS_JANITOR (self) || !self->port || self->close_pending)
     return BSE_ERROR_PROC_EXECUTION;
   
-#line 419 "bsejanitor.proc"
+#line 418 "bsejanitor.proc"
   
   bse_server_user_message (bse_server_get (), mtype, message);
-  bse_janitor_queue_kill (self);
+  bse_janitor_close (self);
   
   return BSE_ERROR_NONE;
 }
 
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { &type_id_trigger_action, "BseJanitor+trigger-action", NULL, 0, trigger_action_setup, trigger_action_exec, NULL, "/Method/BseJanitor/General/Trigger Action", { 0, }, },
-  { &type_id_get_script_name, "BseJanitor+get-script-name", NULL, 0, get_script_name_setup, get_script_name_exec, NULL, "/Method/BseJanitor/General/Get Script Name", { 0, }, },
-  { &type_id_get_proc_name, "BseJanitor+get-proc-name", NULL, 0, get_proc_name_setup, get_proc_name_exec, NULL, "/Method/BseJanitor/General/Get Proc Name", { 0, }, },
-  { &type_id_n_actions, "BseJanitor+n-actions", NULL, 0, n_actions_setup, n_actions_exec, NULL, "/Method/BseJanitor/General/N Actions", { 0, }, },
-  { &type_id_get_action, "BseJanitor+get-action", NULL, 0, get_action_setup, get_action_exec, NULL, "/Method/BseJanitor/General/Get Action", { 0, }, },
-  { &type_id_get_action_name, "BseJanitor+get-action-name", NULL, 0, get_action_name_setup, get_action_name_exec, NULL, "/Method/BseJanitor/General/Get Action Name", { 0, }, },
-  { &type_id_get_action_blurb, "BseJanitor+get-action-blurb", NULL, 0, get_action_blurb_setup, get_action_blurb_exec, NULL, "/Method/BseJanitor/General/Get Action Blurb", { 0, }, },
-  { &type_id_kill, "BseJanitor+kill", NULL, 0, kill_setup, kill_exec, NULL, "/Method/BseJanitor/General/Kill", { 0, }, },
-  { &type_id_add_action, "BseJanitor+add-action", NULL, 0, add_action_setup, add_action_exec, NULL, "/Method/BseJanitor/General/Add Action", { 0, }, },
-  { &type_id_remove_action, "BseJanitor+remove-action", NULL, 0, remove_action_setup, remove_action_exec, NULL, "/Method/BseJanitor/General/Remove Action", { 0, }, },
-  { &type_id_bse_janitor_get_specific, "bse-janitor-get-specific", NULL, 0, bse_janitor_get_specific_setup, bse_janitor_get_specific_exec, NULL, "/Proc/Script Utils/Specific Janitor", { 0, }, },
-  { &type_id_set_msg, "BseJanitor+set-msg", NULL, 0, set_msg_setup, set_msg_exec, NULL, "/Method/BseJanitor/General/Set Msg", { 0, }, },
-  { &type_id_progress, "BseJanitor+progress", NULL, 0, progress_setup, progress_exec, NULL, "/Method/BseJanitor/General/Progress", { 0, }, },
-  { &type_id_exit, "BseJanitor+exit", NULL, 0, exit_setup, exit_exec, NULL, "/Method/BseJanitor/General/Exit", { 0, }, },
-  { NULL, },
+static BseExportNodeProc __enode_trigger_action = {
+  { NULL, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+trigger-action", "/Methods/BseJanitor/General/Trigger Action", NULL },
+  0, trigger_action_setup, trigger_action_exec, 
 };
-BSE_EXPORTS_END;
+static BseExportNodeProc __enode_get_script_name = {
+  { (BseExportNode*) &__enode_trigger_action, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+get-script-name", "/Methods/BseJanitor/General/Get Script Name", NULL },
+  0, get_script_name_setup, get_script_name_exec, 
+};
+static BseExportNodeProc __enode_get_proc_name = {
+  { (BseExportNode*) &__enode_get_script_name, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+get-proc-name", "/Methods/BseJanitor/General/Get Proc Name", NULL },
+  0, get_proc_name_setup, get_proc_name_exec, 
+};
+static BseExportNodeProc __enode_n_actions = {
+  { (BseExportNode*) &__enode_get_proc_name, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+n-actions", "/Methods/BseJanitor/General/N Actions", NULL },
+  0, n_actions_setup, n_actions_exec, 
+};
+static BseExportNodeProc __enode_get_action = {
+  { (BseExportNode*) &__enode_n_actions, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+get-action", "/Methods/BseJanitor/General/Get Action", NULL },
+  0, get_action_setup, get_action_exec, 
+};
+static BseExportNodeProc __enode_get_action_name = {
+  { (BseExportNode*) &__enode_get_action, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+get-action-name", "/Methods/BseJanitor/General/Get Action Name", NULL },
+  0, get_action_name_setup, get_action_name_exec, 
+};
+static BseExportNodeProc __enode_get_action_blurb = {
+  { (BseExportNode*) &__enode_get_action_name, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+get-action-blurb", "/Methods/BseJanitor/General/Get Action Blurb", NULL },
+  0, get_action_blurb_setup, get_action_blurb_exec, 
+};
+static BseExportNodeProc __enode_kill = {
+  { (BseExportNode*) &__enode_get_action_blurb, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+kill", "/Methods/BseJanitor/General/Kill", NULL },
+  0, kill_setup, kill_exec, 
+};
+static BseExportNodeProc __enode_add_action = {
+  { (BseExportNode*) &__enode_kill, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+add-action", "/Methods/BseJanitor/General/Add Action", NULL },
+  0, add_action_setup, add_action_exec, 
+};
+static BseExportNodeProc __enode_remove_action = {
+  { (BseExportNode*) &__enode_add_action, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+remove-action", "/Methods/BseJanitor/General/Remove Action", NULL },
+  0, remove_action_setup, remove_action_exec, 
+};
+static BseExportNodeProc __enode_bse_janitor_get_specific = {
+  { (BseExportNode*) &__enode_remove_action, BSE_EXPORT_NODE_PROC,
+    "bse-janitor-get-specific", "/Proc/Janitor/Get Specific", NULL },
+  0, bse_janitor_get_specific_setup, bse_janitor_get_specific_exec, 
+};
+static BseExportNodeProc __enode_set_msg = {
+  { (BseExportNode*) &__enode_bse_janitor_get_specific, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+set-msg", "/Methods/BseJanitor/General/Set Msg", NULL },
+  0, set_msg_setup, set_msg_exec, 
+};
+static BseExportNodeProc __enode_progress = {
+  { (BseExportNode*) &__enode_set_msg, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+progress", "/Methods/BseJanitor/General/Progress", NULL },
+  0, progress_setup, progress_exec, 
+};
+static BseExportNodeProc __enode_exit = {
+  { (BseExportNode*) &__enode_progress, BSE_EXPORT_NODE_PROC,
+    "BseJanitor+exit", "/Methods/BseJanitor/General/Exit", NULL },
+  0, exit_setup, exit_exec, 
+};
+BseExportNode* bse__builtin_init_bsejanitor_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bsejanitor_gen_proc_c (void)
+{
+  return (BseExportNode*) &__enode_exit;
+}
 
 /**
  ** Generated data ends here
