@@ -13,7 +13,6 @@
 
 
 /* --- current-time --- */
-static GType type_id_current_time = 0;
 static void
 current_time_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 27 "bsemidinotifier.proc"
@@ -29,7 +28,7 @@ current_time_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 23 "bsemidinotifier.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bsemidinotifier.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU General Public License";
 #line 34 "bsemidinotifier.proc"
  }
 static BseErrorType
@@ -62,12 +61,16 @@ current_time_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { &type_id_current_time, "BseMidiNotifier+current-time", NULL, 0, current_time_setup, current_time_exec, NULL, "/Method/BseMidiNotifier/General/Current Time", { 0, }, },
-  { NULL, },
+static BseExportNodeProc __enode_current_time = {
+  { NULL, BSE_EXPORT_NODE_PROC,
+    "BseMidiNotifier+current-time", "/Methods/BseMidiNotifier/General/Current Time", NULL },
+  0, current_time_setup, current_time_exec, 
 };
-BSE_EXPORTS_END;
+BseExportNode* bse__builtin_init_bsemidinotifier_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bsemidinotifier_gen_proc_c (void)
+{
+  return (BseExportNode*) &__enode_current_time;
+}
 
 /**
  ** Generated data ends here
