@@ -11,7 +11,6 @@
 #line 25 "bseobject.proc"
 
 /* --- is-a --- */
-static GType type_id_is_a = 0;
 static void
 is_a_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 26 "bseobject.proc"
@@ -28,7 +27,7 @@ is_a_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_ps
 #line 23 "bseobject.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 24 "bseobject.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 34 "bseobject.proc"
 }  }
 static BseErrorType
@@ -57,12 +56,16 @@ is_a_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { &type_id_is_a, "BseObject+is-a", NULL, 0, is_a_setup, is_a_exec, NULL, "/Method/BseObject/General/Is A", { 0, }, },
-  { NULL, },
+static BseExportNodeProc __enode_is_a = {
+  { NULL, BSE_EXPORT_NODE_PROC,
+    "BseObject+is-a", "/Methods/BseObject/General/Is A", NULL },
+  0, is_a_setup, is_a_exec, 
 };
-BSE_EXPORTS_END;
+BseExportNode* bse__builtin_init_bseobject_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bseobject_gen_proc_c (void)
+{
+  return (BseExportNode*) &__enode_is_a;
+}
 
 /**
  ** Generated data ends here
