@@ -37,7 +37,7 @@ extern void     bse_type_register_procedure_info  (GTypeInfo                *inf
 static void     bse_procedure_base_init           (BseProcedureClass        *proc);
 static void     bse_procedure_base_finalize       (BseProcedureClass        *proc);
 static void     bse_procedure_init                (BseProcedureClass        *proc,
-                                                   const BseExportProcedure *pspec);
+                                                   const BseExportNodeProc  *pnode);
 
 
 /* --- functions --- */
@@ -68,7 +68,7 @@ bse_procedure_base_init (BseProcedureClass *proc)
   proc->private_id = 0;
   proc->help = NULL;
   proc->authors = NULL;
-  proc->copyright = NULL;
+  proc->license = NULL;
   proc->n_in_pspecs = 0;
   proc->in_pspecs = NULL;
   proc->n_out_pspecs = 0;
@@ -85,8 +85,14 @@ bse_procedure_base_finalize (BseProcedureClass *proc)
   proc->blurb = NULL;
   proc->help = NULL;
   proc->authors = NULL;
-  proc->copyright = NULL;
+  proc->license = NULL;
   
+  /* give up type references */
+  for (i = 0; proc->class_refs[i]; i++)
+    g_type_class_unref (proc->class_refs[i]);
+  g_free (proc->class_refs);
+  proc->class_refs = NULL;
+
   for (i = 0; i < proc->n_in_pspecs; i++)
     g_param_spec_unref (proc->in_pspecs[i]);
   g_free (proc->in_pspecs);
@@ -98,12 +104,12 @@ bse_procedure_base_finalize (BseProcedureClass *proc)
 }
 
 static void
-bse_procedure_init (BseProcedureClass        *proc,
-                    const BseExportProcedure *pspec)
+bse_procedure_init (BseProcedureClass       *proc,
+                    const BseExportNodeProc *pnode)
 {
   GParamSpec *in_pspecs[BSE_PROCEDURE_MAX_IN_PARAMS + 8];
   GParamSpec *out_pspecs[BSE_PROCEDURE_MAX_OUT_PARAMS + 8];
-  guint i;
+  guint i, j;
   gchar *const_name, *const_blurb;
   
   memset (in_pspecs, 0, sizeof (in_pspecs));
@@ -111,14 +117,14 @@ bse_procedure_init (BseProcedureClass        *proc,
   
   proc->name = g_type_name (BSE_PROCEDURE_TYPE (proc));
   proc->blurb = bse_type_blurb (BSE_PROCEDURE_TYPE (proc));
-  proc->private_id = pspec->private_id;
+  proc->private_id = pnode->private_id;
   
   /* init procedure class from plugin,
    * paranoia check certain class members
    */
   const_name = proc->name;
   const_blurb = proc->blurb;
-  pspec->init (proc, in_pspecs, out_pspecs);
+  pnode->init (proc, in_pspecs, out_pspecs);
   if (proc->name != const_name)
     {
       proc->name = const_name;
@@ -141,8 +147,7 @@ bse_procedure_init (BseProcedureClass        *proc,
       g_warning ("procedure \"%s\" messes with reserved class members", proc->name);
     }
   
-  /* check input parameters and setup specifications
-   */
+  /* check input parameters and setup specifications */
   for (i = 0; i < BSE_PROCEDURE_MAX_IN_PARAMS; i++)
     if (in_pspecs[i])
       {
@@ -163,8 +168,7 @@ bse_procedure_init (BseProcedureClass        *proc,
   memcpy (proc->in_pspecs, in_pspecs, sizeof (in_pspecs[0]) * proc->n_in_pspecs);
   proc->in_pspecs[proc->n_in_pspecs] = NULL;
   
-  /* check output parameters and setup specifications
-   */
+  /* check output parameters and setup specifications */
   for (i = 0; i < BSE_PROCEDURE_MAX_OUT_PARAMS; i++)
     if (out_pspecs[i])
       {
@@ -184,20 +188,30 @@ bse_procedure_init (BseProcedureClass        *proc,
   proc->out_pspecs = g_new (GParamSpec*, proc->n_out_pspecs + 1);
   memcpy (proc->out_pspecs, out_pspecs, sizeof (out_pspecs[0]) * proc->n_out_pspecs);
   proc->out_pspecs[proc->n_out_pspecs] = NULL;
-  
-  proc->execute = pspec->exec;
+
+  /* keep type references */
+  proc->class_refs = g_new (GTypeClass*, proc->n_in_pspecs + proc->n_out_pspecs + 1);
+  j = 0;
+  for (i = 0; i < proc->n_in_pspecs; i++)
+    if (G_TYPE_IS_CLASSED ((G_PARAM_SPEC_VALUE_TYPE (proc->in_pspecs[i]))))
+      proc->class_refs[j++] = g_type_class_ref (G_PARAM_SPEC_VALUE_TYPE (proc->in_pspecs[i]));
+  for (i = 0; i < proc->n_out_pspecs; i++)
+    if (G_TYPE_IS_CLASSED ((G_PARAM_SPEC_VALUE_TYPE (proc->out_pspecs[i]))))
+      proc->class_refs[j++] = g_type_class_ref (G_PARAM_SPEC_VALUE_TYPE (proc->out_pspecs[i]));
+  proc->class_refs[j++] = NULL;
+
+  /* hookup execute method */
+  proc->execute = pnode->exec;
 }
 
 void
-bse_procedure_complete_info (const BseExportSpec *spec,
-                             GTypeInfo         *info)
+bse_procedure_complete_info (const BseExportNodeProc *pnode,
+                             GTypeInfo               *info)
 {
-  const BseExportProcedure *pspec = &spec->s_proc;
-  
   info->class_size = sizeof (BseProcedureClass);
   info->class_init = (GClassInitFunc) bse_procedure_init;
-  info->class_finalize = (GClassFinalizeFunc) pspec->unload;
-  info->class_data = pspec;
+  info->class_finalize = (GClassFinalizeFunc) NULL;
+  info->class_data = pnode;
 }
 
 const gchar*
