@@ -24,7 +24,10 @@
 #include "bsewaverepo.h"
 #include "bsessequencer.h"
 #include "bseserver.h"
+#include "bseundostack.h"
 #include "bsemain.h"
+#include "bsestandardsynths.h"
+#include "bsemidireceiver.h"
 #include "gslcommon.h"
 #include "gslengine.h"
 #include <string.h>
@@ -34,17 +37,38 @@
 #include <errno.h>
 
 
+typedef struct {
+  GType    base_type;
+  gboolean intern_children;
+  guint    max_items;
+  GSList  *items;
+} StorageTrap;
+
+
 /* --- macros --- */
 #define parse_or_return         bse_storage_scanner_parse_or_return
 #define peek_or_return          bse_storage_scanner_peek_or_return
 #define	DEBUG			sfi_debug
 
+enum {
+  PARAM_0,
+  PARAM_DIRTY
+};
+
 
 /* --- prototypes --- */
 static void	bse_project_class_init		(BseProjectClass	*class);
 static void	bse_project_class_finalize	(BseProjectClass	*class);
 static void	bse_project_init		(BseProject		*project,
 						 gpointer		 rclass);
+static void     bse_project_set_property        (GObject                *object,
+                                                 guint                   param_id,
+                                                 const GValue           *value,
+                                                 GParamSpec             *pspec);
+static void     bse_project_get_property        (GObject                *object,
+                                                 guint                   param_id,
+                                                 GValue                 *value,
+                                                 GParamSpec             *pspec);
 static void	bse_project_finalize		(GObject		*object);
 static void	bse_project_release_children	(BseContainer		*container);
 static void	bse_project_dispose		(GObject		*object);
@@ -59,14 +83,17 @@ static BseItem* bse_project_retrieve_child	(BseContainer           *container,
 						 GType                   child_type,
 						 const gchar            *uname);
 static void	bse_project_prepare		(BseSource		*source);
+static gboolean project_check_restore		(BseContainer           *container,
+						 const gchar            *child_type);
+static BseUndoStack* bse_project_get_undo       (BseItem                *item);
 
 
 /* --- variables --- */
 static GTypeClass *parent_class = NULL;
-static guint       signal_complete_restore = 0;
 static guint       signal_state_changed = 0;
 static GSList     *plist_auto_stop_SL = NULL;
 static guint       handler_id_auto_stop_check_SL = 0;
+static GQuark      quark_storage_trap = 0;
 
 
 /* --- functions --- */
@@ -97,26 +124,34 @@ bse_project_class_init (BseProjectClass *class)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   BseObjectClass *object_class = BSE_OBJECT_CLASS (class);
+  BseItemClass *item_class = BSE_ITEM_CLASS (class);
   BseSourceClass *source_class = BSE_SOURCE_CLASS (class);
   BseContainerClass *container_class = BSE_CONTAINER_CLASS (class);
   
   parent_class = g_type_class_peek_parent (class);
-  
+  quark_storage_trap = g_quark_from_static_string ("bse-project-storage-trap");
+
+  gobject_class->set_property = bse_project_set_property;
+  gobject_class->get_property = bse_project_get_property;
   gobject_class->dispose = bse_project_dispose;
   gobject_class->finalize = bse_project_finalize;
 
+  item_class->get_undo = bse_project_get_undo;
+
   source_class->prepare = bse_project_prepare;
 
   container_class->add_item = bse_project_add_item;
   container_class->remove_item = bse_project_remove_item;
   container_class->forall_items = bse_project_forall_items;
+  container_class->check_restore = project_check_restore;
   container_class->retrieve_child = bse_project_retrieve_child;
   container_class->release_children = bse_project_release_children;
-  
-  signal_complete_restore = bse_object_class_add_signal (object_class, "complete-restore",
-							 G_TYPE_NONE,
-							 2, G_TYPE_POINTER, // FIXME TYPE_OBJECT
-							 G_TYPE_BOOLEAN);
+
+  bse_object_class_add_param (object_class, "State",
+                              PARAM_DIRTY,
+                              sfi_pspec_bool ("dirty", NULL, "Whether project needs saving",
+                                              FALSE, "r"));
+
   signal_state_changed = bse_object_class_add_signal (object_class, "state-changed",
 						      G_TYPE_NONE,
 						      1, BSE_TYPE_PROJECT_STATE);
@@ -128,29 +163,85 @@ bse_project_class_finalize (BseProjectClass *class)
 }
 
 static void
-bse_project_init (BseProject *project,
+undo_notify (BseProject     *project,
+             BseUndoStack   *ustack,
+             gboolean        step_added)
+{
+  g_object_notify (project, "dirty");
+  if (step_added && !project->in_redo)
+    bse_undo_stack_clear (project->redo_stack);
+}
+
+static void
+redo_notify (BseProject     *project,
+             BseUndoStack   *ustack,
+             gboolean        step_added)
+{
+  g_object_notify (project, "dirty");
+}
+
+static void
+bse_project_init (BseProject *self,
 		  gpointer    rclass)
 {
-  BseObject *object;
   BseWaveRepo *wrepo;
 
-  object = BSE_OBJECT (project);
-
-  project->state = BSE_PROJECT_INACTIVE;
-  project->supers = NULL;
-  project->items = NULL;
-  project->deactivate_usecs = 3 * 1000000;
+  self->state = BSE_PROJECT_INACTIVE;
+  self->supers = NULL;
+  self->items = NULL;
+  self->in_undo = FALSE;
+  self->in_redo = FALSE;
+  self->undo_stack = bse_undo_stack_new (self, undo_notify);
+  self->redo_stack = bse_undo_stack_new (self, redo_notify);
+  self->deactivate_usecs = 3 * 1000000;
+  self->midi_receiver = bse_midi_receiver_new ("BseProjectReceiver");
+  bse_midi_receiver_enter_farm (self->midi_receiver);
 
   /* we always have a wave-repo */
-  wrepo = g_object_new (BSE_TYPE_WAVE_REPO,
-			"uname", "Wave-Repository",
-			NULL);
-  bse_container_add_item (BSE_CONTAINER (project), BSE_ITEM (wrepo));
-  g_object_unref (wrepo);
+  wrepo = bse_container_new_child (BSE_CONTAINER (self), BSE_TYPE_WAVE_REPO,
+                                   "uname", "Wave-Repository",
+                                   NULL);
   /* with fixed uname */
   BSE_OBJECT_SET_FLAGS (wrepo, BSE_OBJECT_FLAG_FIXED_UNAME);
 }
 
+static void
+bse_project_set_property (GObject                *object,
+                          guint                   param_id,
+                          const GValue           *value,
+                          GParamSpec             *pspec)
+{
+  BseProject *self = BSE_PROJECT (object);
+
+  switch (param_id)
+    {
+    case PARAM_DIRTY:
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
+      break;
+    }
+}
+
+static void
+bse_project_get_property (GObject                *object,
+                          guint                   param_id,
+                          GValue                 *value,
+                          GParamSpec             *pspec)
+{
+  BseProject *self = BSE_PROJECT (object);
+
+  switch (param_id)
+    {
+    case PARAM_DIRTY:
+      sfi_value_set_bool (value, bse_undo_stack_depth (self->undo_stack) > 0);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
+      break;
+    }
+}
+
 static void
 bse_project_release_children (BseContainer *container)
 {
@@ -168,7 +259,12 @@ bse_project_release_children (BseContainer *container)
 static void
 bse_project_dispose (GObject *object)
 {
-  // BseProject *project = BSE_PROJECT (object);
+  BseProject *self = BSE_PROJECT (object);
+
+  bse_project_deactivate (self);
+
+  bse_undo_stack_limit (self->undo_stack, 0);
+  bse_undo_stack_limit (self->redo_stack, 0);
 
   /* chain parent class' handler */
   G_OBJECT_CLASS (parent_class)->dispose (object);
@@ -183,20 +279,33 @@ bse_project_finalize (GObject *object)
   plist_auto_stop_SL = g_slist_remove (plist_auto_stop_SL, self);
   BSE_SEQUENCER_UNLOCK ();
 
+  bse_midi_receiver_unref (self->midi_receiver);
+  self->midi_receiver = NULL;
+
   /* chain parent class' handler */
   G_OBJECT_CLASS (parent_class)->finalize (object);
+
+  bse_undo_stack_destroy (self->undo_stack);
+  bse_undo_stack_destroy (self->redo_stack);
+}
+
+static BseUndoStack*
+bse_project_get_undo (BseItem *item)
+{
+  BseProject *self = BSE_PROJECT (item);
+  return self->in_undo ? self->redo_stack : self->undo_stack;
 }
 
 static void
 bse_project_add_item (BseContainer *container,
 		      BseItem      *item)
 {
-  BseProject *project = BSE_PROJECT (container);
+  BseProject *self = BSE_PROJECT (container);
 
   if (BSE_IS_SUPER (item))
-    project->supers = g_slist_append (project->supers, item);
+    self->supers = g_slist_append (self->supers, item);
   else
-    project->items = g_slist_append (project->items, item);
+    self->items = g_slist_append (self->items, item);
 
   /* chain parent class' add_item handler */
   BSE_CONTAINER_CLASS (parent_class)->add_item (container, item);
@@ -206,15 +315,15 @@ static void
 bse_project_remove_item (BseContainer *container,
 			 BseItem      *item)
 {
-  BseProject *project = BSE_PROJECT (container);
+  BseProject *self = BSE_PROJECT (container);
 
   /* chain parent class' remove_item handler */
   BSE_CONTAINER_CLASS (parent_class)->remove_item (container, item);
 
   if (BSE_IS_SUPER (item))
-    project->supers = g_slist_remove (project->supers, item);
+    self->supers = g_slist_remove (self->supers, item);
   else
-    project->items = g_slist_remove (project->items, item);
+    self->items = g_slist_remove (self->items, item);
 }
 
 static void
@@ -222,10 +331,10 @@ bse_project_forall_items (BseContainer      *container,
 			  BseForallItemsFunc func,
 			  gpointer           data)
 {
-  BseProject *project = BSE_PROJECT (container);
+  BseProject *self = BSE_PROJECT (container);
   GSList *slist;
 
-  slist = project->supers;
+  slist = self->supers;
   while (slist)
     {
       BseItem *item;
@@ -236,7 +345,7 @@ bse_project_forall_items (BseContainer      *container,
 	return;
     }
 
-  slist = project->items;
+  slist = self->items;
   while (slist)
     {
       BseItem *item;
@@ -253,21 +362,32 @@ bse_project_retrieve_child (BseContainer *container,
 			    GType         child_type,
 			    const gchar  *uname)
 {
-  BseProject *project = BSE_PROJECT (container);
+  BseProject *self = BSE_PROJECT (container);
 
   /* always hand out the same wave repo */
   if (g_type_is_a (child_type, BSE_TYPE_WAVE_REPO))
     {
       GSList *slist;
 
-      for (slist = project->supers; slist; slist = slist->next)
+      for (slist = self->supers; slist; slist = slist->next)
 	if (g_type_is_a (G_OBJECT_TYPE (slist->data), BSE_TYPE_WAVE_REPO))
 	  return slist->data;
       DEBUG ("%s: eeeeeek! wave-repo not found\n", G_STRLOC);
       return NULL;	/* shouldn't happen */
     }
   else
-    return BSE_CONTAINER_CLASS (parent_class)->retrieve_child (container, child_type, uname);
+    {
+      BseItem *item = BSE_CONTAINER_CLASS (parent_class)->retrieve_child (container, child_type, uname);
+      StorageTrap *strap = g_object_get_qdata (self, quark_storage_trap);
+      if (item && strap)
+	{
+          if (strap->intern_children)
+            bse_item_set_internal (item, TRUE);
+	  strap->items = g_slist_prepend (strap->items, item);
+	  strap->max_items--;
+	}
+      return item;
+    }
 }
 
 static gboolean
@@ -292,55 +412,83 @@ add_item_upaths (BseItem *item,
 }
 
 BseStringSeq*
-bse_project_list_upaths (BseProject *project,
+bse_project_list_upaths (BseProject *self,
 			 GType       item_type)
 {
   gpointer data[3];
   BseStringSeq *sseq;
 
-  g_return_val_if_fail (BSE_IS_PROJECT (project), NULL);
+  g_return_val_if_fail (BSE_IS_PROJECT (self), NULL);
   g_return_val_if_fail (g_type_is_a (item_type, BSE_TYPE_ITEM), NULL);
 
   sseq = bse_string_seq_new ();
   data[0] = sseq;
   data[1] = (gpointer) item_type;
-  data[2] = project;
-  bse_container_forall_items (BSE_CONTAINER (project), add_item_upaths, data);
+  data[2] = self;
+  bse_container_forall_items (BSE_CONTAINER (self), add_item_upaths, data);
 
   return sseq;
 }
 
+static GSList*
+compute_missing_supers (BseProject *self,
+                        BseStorage *storage)
+{
+  BseItem *project_item = BSE_ITEM (self);
+  GSList *targets = NULL, *missing = sfi_ppool_slist (storage->referenced_items);
+  while (missing)
+    {
+      BseItem *item = g_slist_pop_head (&missing);
+      BseSuper *super = bse_item_get_super (item);
+      if (BSE_ITEM (super)->parent == project_item &&
+          !sfi_ppool_lookup (storage->stored_items, super))
+        targets = g_slist_prepend (targets, super);
+    }
+  return targets;
+}
+
 BseErrorType
-bse_project_store_bse (BseProject  *project,
+bse_project_store_bse (BseProject  *self,
+                       BseSuper    *super,
 		       const gchar *bse_file,
 		       gboolean     self_contained)
 {
   BseStorage *storage;
-  gint fd;
+  GSList *slist = NULL;
   gchar *string;
-  BseMagicFlags mflags;
-  GSList *slist;
-  guint l;
+  guint l, flags;
+  gint fd;
   
-  g_return_val_if_fail (BSE_IS_PROJECT (project), BSE_ERROR_INTERNAL);
+  g_return_val_if_fail (BSE_IS_PROJECT (self), BSE_ERROR_INTERNAL);
+  if (super)
+    {
+      g_return_val_if_fail (BSE_IS_SUPER (super), BSE_ERROR_INTERNAL);
+      g_return_val_if_fail (BSE_ITEM (super)->parent == BSE_ITEM (self), BSE_ERROR_INTERNAL);
+    }
   g_return_val_if_fail (bse_file != NULL, BSE_ERROR_INTERNAL);
 
   fd = open (bse_file, O_WRONLY | O_CREAT | O_EXCL, 0666);
   if (fd < 0)
-    return (errno == EEXIST ? BSE_ERROR_FILE_EXISTS : BSE_ERROR_FILE_IO);
+    return bse_error_from_errno (errno, BSE_ERROR_FILE_OPEN_FAILED);
 
   storage = g_object_new (BSE_TYPE_STORAGE, NULL);
-  bse_storage_prepare_write (storage, BSE_STORAGE_SKIP_DEFAULTS);
+  flags = BSE_STORAGE_SKIP_DEFAULTS;
   if (self_contained)
-    BSE_OBJECT_SET_FLAGS (storage, BSE_STORAGE_FLAG_SELF_CONTAINED);
-  bse_storage_store_item (storage, project);
+    flags |= BSE_STORAGE_SELF_CONTAINED;
+  bse_storage_prepare_write (storage, flags);
 
-  mflags = storage->wblocks ? BSE_MAGIC_BSE_BIN_EXTENSION : 0;
-  for (slist = project->supers; slist; slist = slist->next)
-    if (BSE_IS_SONG (slist->data))
-      mflags |= BSE_MAGIC_BSE_SONG;
+  slist = g_slist_prepend (slist, super ? (void*) super : (void*) self);
+  while (slist)
+    {
+      BseItem *item = g_slist_pop_head (&slist);
+      if (item == (BseItem*) self)
+        bse_storage_store_item (storage, item);
+      else
+        bse_storage_store_child (storage, item);
+      slist = g_slist_concat (compute_missing_supers (self, storage), slist);
+    }
 
-  string = g_strdup_printf ("; BseProject\n"); /* %010o mflags */
+  string = g_strdup_printf ("; BseProject\n\n"); /* %010o mflags */
   do
     l = write (fd, string, strlen (string));
   while (l < 0 && errno == EINTR);
@@ -354,40 +502,27 @@ bse_project_store_bse (BseProject  *project,
 }
 
 BseErrorType
-bse_project_restore (BseProject *project,
+bse_project_restore (BseProject *self,
 		     BseStorage *storage)
 {
   GScanner *scanner;
   GTokenType expected_token = G_TOKEN_NONE;
   
-  g_return_val_if_fail (BSE_IS_PROJECT (project), BSE_ERROR_INTERNAL);
+  g_return_val_if_fail (BSE_IS_PROJECT (self), BSE_ERROR_INTERNAL);
   g_return_val_if_fail (BSE_IS_STORAGE (storage), BSE_ERROR_INTERNAL);
-  g_return_val_if_fail (BSE_STORAGE_READABLE (storage), BSE_ERROR_INTERNAL);
 
-  scanner = storage->scanner;
+  scanner = bse_storage_get_scanner (storage);
+  g_return_val_if_fail (scanner != NULL, BSE_ERROR_INTERNAL);
 
-  g_object_ref (project);
-  
-  while (!bse_storage_input_eof (storage) && expected_token == G_TOKEN_NONE)
-    {
-      g_scanner_get_next_token (scanner);
-      if (scanner->token == G_TOKEN_EOF)
-	break;
-      else if (scanner->token == '(')
-	expected_token = bse_storage_parse_statement (storage, project);
-      else
-	expected_token = G_TOKEN_EOF; /* wanted '(' */
-    }
+  g_object_ref (self);
 
+  expected_token = bse_storage_restore_item (storage, BSE_ITEM (self));
   if (expected_token != G_TOKEN_NONE)
     bse_storage_unexp_token (storage, expected_token);
 
   bse_storage_resolve_item_links (storage);
 
-  expected_token = expected_token != G_TOKEN_NONE;
-  g_signal_emit (project, signal_complete_restore, 0, storage, expected_token);
-  
-  g_object_unref (project);
+  g_object_unref (self);
 
   return (scanner->parse_errors >= scanner->max_parse_errors ?
 	  BSE_ERROR_PARSE_ERROR :
@@ -400,18 +535,18 @@ bse_project_upath_resolver (gpointer     func_data,
 			    const gchar *upath,
 			    gchar      **error_p)
 {
-  BseProject *project = func_data;
+  BseProject *self = func_data;
   gpointer item = NULL;
 
   if (error_p)
     *error_p = NULL;
-  g_return_val_if_fail (BSE_IS_PROJECT (project), NULL);
+  g_return_val_if_fail (BSE_IS_PROJECT (self), NULL);
   g_return_val_if_fail (upath != NULL, NULL);
 
   /* FIXME: need error handling, warnings.... */
 
   if (g_type_is_a (required_type, BSE_TYPE_ITEM))
-    item = bse_container_resolve_upath (BSE_CONTAINER (project), upath);
+    item = bse_container_resolve_upath (BSE_CONTAINER (self), upath);
   else if (error_p)
     *error_p = g_strdup_printf ("unable to resolve object of type `%s' from upath: %s", g_type_name (required_type), upath);
   
@@ -419,16 +554,16 @@ bse_project_upath_resolver (gpointer     func_data,
 }
 
 BseItem*
-bse_project_lookup_typed_item (BseProject  *project,
+bse_project_lookup_typed_item (BseProject  *self,
 			       GType	    item_type,
 			       const gchar *uname)
 {
   BseItem *item;
 
-  g_return_val_if_fail (BSE_IS_PROJECT (project), NULL);
+  g_return_val_if_fail (BSE_IS_PROJECT (self), NULL);
   g_return_val_if_fail (uname != NULL, NULL);
 
-  item = bse_container_lookup_item (BSE_CONTAINER (project), uname);
+  item = bse_container_lookup_item (BSE_CONTAINER (self), uname);
   if (item && G_OBJECT_TYPE (item) == item_type)
     return item;
 
@@ -436,26 +571,83 @@ bse_project_lookup_typed_item (BseProject  *project,
 }
 
 BseWaveRepo*
-bse_project_get_wave_repo (BseProject *project)
+bse_project_get_wave_repo (BseProject *self)
 {
   GSList *slist;
 
-  g_return_val_if_fail (BSE_IS_PROJECT (project), NULL);
+  g_return_val_if_fail (BSE_IS_PROJECT (self), NULL);
 
-  for (slist = project->supers; slist; slist = slist->next)
+  for (slist = self->supers; slist; slist = slist->next)
     if (BSE_IS_WAVE_REPO (slist->data))
       return slist->data;
   return NULL;
 }
 
+static gboolean
+project_check_restore (BseContainer *container,
+		       const gchar  *child_type)
+{
+  if (BSE_CONTAINER_CLASS (parent_class)->check_restore (container, child_type))
+    {
+      StorageTrap *strap = g_object_get_qdata (container, quark_storage_trap);
+      if (!strap)
+	return TRUE;
+      if (!g_type_is_a (g_type_from_name (child_type), strap->base_type))
+	return FALSE;
+      if (strap->max_items < 1)
+	return FALSE;
+      return TRUE;
+    }
+  else
+    return FALSE;
+}
+
+gpointer
+bse_project_create_intern_synth (BseProject  *self,
+				 const gchar *synth_name,
+				 GType        check_type)
+{
+  BseItem *synth = NULL;
+  gchar *bse_synth;
+
+  g_return_val_if_fail (BSE_IS_PROJECT (self), NULL);
+  g_return_val_if_fail (synth_name != NULL, NULL);
+
+  bse_synth = bse_standard_synth_inflate (synth_name, NULL);
+  if (bse_synth)
+    {
+      BseStorage *storage = g_object_new (BSE_TYPE_STORAGE, NULL);
+      BseErrorType error = BSE_ERROR_NONE;
+      StorageTrap strap = { 0, TRUE, }, *old_strap = g_object_get_qdata (self, quark_storage_trap);
+      bse_storage_input_text (storage, bse_synth, "<builtin-lib>");
+      g_object_set_qdata (self, quark_storage_trap, &strap);
+      strap.max_items = 1;
+      strap.base_type = check_type;
+      strap.items = NULL;
+      if (!error)
+	error = bse_project_restore (self, storage);
+      bse_storage_reset (storage);
+      g_object_unref (storage);
+      g_free (bse_synth);
+      if (error || !strap.items)
+	g_warning ("failed to create internal synth \"%s\": %s",
+		   synth_name, bse_error_blurb (error ? error : BSE_ERROR_NO_ENTRY));
+      else
+	synth = strap.items->data;
+      g_slist_free (strap.items);
+      g_object_set_qdata (self, quark_storage_trap, old_strap);
+    }
+  return synth;
+}
+
 static void
 bse_project_prepare (BseSource *source)
 {
-  BseProject *project = BSE_PROJECT (source);
+  BseProject *self = BSE_PROJECT (source);
   GSList *slist;
   
   /* make sure Wave repositories are prepared first */
-  for (slist = project->supers; slist; slist = slist->next)
+  for (slist = self->supers; slist; slist = slist->next)
     if (BSE_IS_WAVE_REPO (slist->data))
       bse_source_prepare (slist->data);
 
@@ -537,12 +729,11 @@ bse_project_activate (BseProject *self)
       BseSuper *super = BSE_SUPER (slist->data);
       if (BSE_SUPER_NEEDS_CONTEXT (super))
 	{
-	  BseSNet *snet = BSE_SNET (super);	// FIXME: merge this snet functionality into super
-	  super->context_handle = bse_snet_create_context (snet,
-							   bse_server_get_midi_receiver (bse_server_get (),
-											 "default"),
-							   0,
-							   trans);
+          BseMidiContext mcontext = { 0, 0, 0 };
+	  BseSNet *snet = BSE_SNET (super);
+          mcontext.midi_receiver = self->midi_receiver;
+          mcontext.midi_channel = 1; /* midi channel default */
+	  super->context_handle = bse_snet_create_context (snet, mcontext, trans);
 	  bse_source_connect_context (BSE_SOURCE (snet), super->context_handle, trans);
 	}
       else
@@ -575,12 +766,11 @@ bse_project_start_playback (BseProject *self)
 	   BSE_SUPER_NEEDS_SEQUENCER_CONTEXT (super)) &&
 	  super->context_handle == ~0)
 	{
-	  BseSNet *snet = BSE_SNET (super);	// FIXME: merge this snet functionality into super
-	  super->context_handle = bse_snet_create_context (snet,
-							   bse_server_get_midi_receiver (bse_server_get (),
-											 "default"),
-							   0,
-							   trans);
+          BseMidiContext mcontext = { 0, 0, 0 };
+          BseSNet *snet = BSE_SNET (super);
+          mcontext.midi_receiver = self->midi_receiver;
+          mcontext.midi_channel = 1; /* midi channel default */
+          super->context_handle = bse_snet_create_context (snet, mcontext, trans);
 	  bse_source_connect_context (BSE_SOURCE (snet), super->context_handle, trans);
 	  seen_synth++;
 	}
