@@ -20,7 +20,7 @@
 #include        "bseprocedure.h"
 #include        "bsemain.h"
 #include        "bsestandardsynths.h"
-#include        "PKG_config.h"
+#include        "topconfig.h"
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<string.h>
@@ -85,6 +85,9 @@ show_nodes (GType        type,
       fputs ("]", f_out);
     }
 
+  if (G_TYPE_IS_ABSTRACT (type))
+    fputs ("\t(abstract)", f_out);
+
   if (feature_channels && g_type_is_a (type, BSE_TYPE_SOURCE))
     {
       BseSourceClass *class = g_type_class_ref (type);
@@ -125,7 +128,7 @@ show_cats (void)
   BseCategorySeq *cseq;
   guint i;
 
-  cseq = bse_categories_match ("*");
+  cseq = bse_categories_match_typed ("*", 0);
   for (i = 0; i < cseq->n_cats; i++)
     fprintf (f_out, "%s\t(%s)\n",
 	     cseq->cats[i]->category,
@@ -209,14 +212,17 @@ main (gint   argc,
   gboolean gen_procdoc = 0;
   gboolean list_synths = 0;
   gchar *show_synth = NULL;
+  gchar *root_name = NULL;
   guint i;
   gchar *iindent = "";
-  
+  SfiRec *config;
+
   f_out = stdout;
 
   g_thread_init (NULL);
 
-  bse_init_intern (&argc, &argv, NULL);
+  sfi_init ();
+  config = sfi_rec_new();
   
   root = BSE_TYPE_OBJECT;
 
@@ -259,7 +265,7 @@ main (gint   argc,
 	{
 	  i++;
 	  if (i < argc)
-	    root = g_type_from_name (argv[i]);
+	    root_name = argv[i];
 	}
       else if (strcmp ("-n", argv[i]) == 0)
 	{
@@ -299,7 +305,7 @@ main (gint   argc,
 	}
       else if (strcmp ("-p", argv[i]) == 0)
 	{
-	  // bse_ladspa_plugin_test ();
+          sfi_rec_set_bool (config, "load-core-plugins", TRUE);
 	}
       else if (strcmp ("-h", argv[i]) == 0)
 	{
@@ -312,6 +318,12 @@ main (gint   argc,
       else
 	return help (argv[i]);
     }
+
+  bse_init_intern (&argc, &argv, config);
+
+  if (root_name)
+    root = g_type_from_name (root_name);
+
   if (!gen_froots && !gen_tree && !gen_cats && !gen_procdoc && !list_synths && !show_synth)
     return help (argv[i-1]);
 
@@ -349,10 +361,10 @@ main (gint   argc,
     }
   if (show_synth)
     {
-      gchar *text = bse_standard_synth_lookup (show_synth, NULL);
+      gchar *text = bse_standard_synth_inflate (show_synth, NULL);
       g_print ("%s", text);
       g_free (text);
     }
-  
+
   return 0;
 }
