@@ -17,7 +17,7 @@
  */
 #include "bsescripthelper.h"
 
-#include "PKG_config.h"
+#include "topconfig.h"
 #include "bsecategories.h"
 #include "bseserver.h"
 #include "bseglue.h"
@@ -44,18 +44,6 @@ static GQuark quark_script_args = 0;
 
 
 /* --- functions --- */
-static SfiRing*
-string_list_copy_deep (SfiRing *ring)
-{
-  return sfi_ring_copy_deep (ring, (SfiRingDataFunc) g_strdup, NULL);
-}
-
-static void
-string_list_free_deep (SfiRing *ring)
-{
-  sfi_ring_free_deep (ring, g_free);
-}
-
 static void
 bse_script_procedure_init (BseScriptProcedureClass *class,
 			   BseScriptData           *sdata)
@@ -68,7 +56,7 @@ bse_script_procedure_init (BseScriptProcedureClass *class,
   proc->blurb = sdata->blurb;
   proc->help = sdata->help;
   proc->authors = sdata->authors;
-  proc->copyright = sdata->copyright;
+  proc->license = sdata->license;
   class->sdata = sdata;
   proc->execute = bse_script_procedure_exec;
   
@@ -100,7 +88,7 @@ bse_script_proc_register (const gchar *script_file,
 			  const gchar *blurb,
 			  const gchar *help,
 			  const gchar *authors,
-			  const gchar *copyright,
+			  const gchar *license,
 			  SfiRing     *params)
 {
   GTypeInfo script_info = {
@@ -134,15 +122,16 @@ bse_script_proc_register (const gchar *script_file,
   sdata->blurb = g_strdup (blurb);
   sdata->help = g_strdup (help);
   sdata->authors = g_strdup (authors);
-  sdata->copyright = g_strdup (copyright);
-  sdata->params = string_list_copy_deep (params);
+  sdata->license = g_strdup (license);
+  sdata->params = sfi_ring_copy_deep (params, (SfiRingDataFunc) g_strdup, NULL);
+
   script_info.class_data = sdata;
   
   tname = g_strconcat ("bse-script-", name, NULL);
   type = g_type_register_static (BSE_TYPE_PROCEDURE, tname, &script_info, 0);
   g_free (tname);
   if (type && category && category[0])
-    bse_categories_register (category, type);
+    bse_categories_register (category, type, NULL);
   return type;
 }
 
@@ -169,7 +158,7 @@ bse_script_procedure_exec (BseProcedureClass *proc,
   error = bse_server_run_remote (server, shellpath,
 				 params, sdata->script_file, proc->name, &janitor);
   g_free (shellpath);
-  string_list_free_deep (params);
+  sfi_ring_free_deep (params, g_free);
   
   if (error)
     g_message ("failed to start script \"%s::%s\": %s",
@@ -238,12 +227,19 @@ bse_script_check_client_msg (SfiGlueDecoder *decoder,
   return NULL;
 }
 
-GSList*
-bse_script_dir_list_files (const gchar *dir_list)
+SfiRing*
+bse_script_path_list_files (void)
 {
-  GSList *slist = bse_search_path_list_files (dir_list, "*.scm", NULL, G_FILE_TEST_IS_REGULAR);
-  
-  return g_slist_sort (slist, (GCompareFunc) strcmp);
+  SfiRing *ring1, *ring2 = NULL;
+
+  ring1 = sfi_file_crawler_list_files (BSE_PATH_SCRIPTS, "*.scm", G_FILE_TEST_IS_REGULAR);
+  ring1 = sfi_ring_sort (ring1, (GCompareFunc) strcmp);
+
+  if (BSE_GCONFIG (script_path) && BSE_GCONFIG (script_path)[0])
+    ring2 = sfi_file_crawler_list_files (BSE_GCONFIG (script_path), "*.scm", G_FILE_TEST_IS_REGULAR);
+  ring2 = sfi_ring_sort (ring2, (GCompareFunc) strcmp);
+
+  return sfi_ring_concat (ring1, ring2);
 }
 
 BseErrorType
@@ -263,7 +259,7 @@ bse_script_file_register (const gchar *file_name,
   error = bse_server_run_remote (server, shellpath,
 				 params, file_name, proc_name, janitor_p);
   g_free (shellpath);
-  string_list_free_deep (params);
+  sfi_ring_free_deep (params, g_free);
   
   return error;
 }
@@ -285,7 +281,7 @@ make_sname (const gchar *string)
   return cname;
 }
 
-#define PARAM_HINTS	SFI_PARAM_DEFAULT SFI_PARAM_LAX_VALIDATION
+#define PARAM_HINTS	SFI_PARAM_DEFAULT ":lax-validation:"
 
 static GParamSpec*
 bse_script_param_spec (gchar       *pspec_desc,
