@@ -18,7 +18,6 @@
 
 
 /* --- create-part --- */
-static GType type_id_create_part = 0;
 static void
 create_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 33 "bsesong.proc"
@@ -33,7 +32,7 @@ create_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
 #line 29 "bsesong.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 30 "bsesong.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 39 "bsesong.proc"
 }  }
 static BseErrorType
@@ -69,7 +68,6 @@ create_part_exec (BseProcedureClass *proc,
 }
 
 /* --- remove-part --- */
-static GType type_id_remove_part = 0;
 static void
 remove_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 64 "bsesong.proc"
@@ -84,7 +82,7 @@ remove_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
 #line 29 "bsesong.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 30 "bsesong.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 70 "bsesong.proc"
 }  }
 static BseErrorType
@@ -130,7 +128,6 @@ remove_part_exec (BseProcedureClass *proc,
 }
 
 /* --- create-track --- */
-static GType type_id_create_track = 0;
 static void
 create_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 102 "bsesong.proc"
@@ -145,7 +142,7 @@ create_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 29 "bsesong.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 30 "bsesong.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 108 "bsesong.proc"
 }  }
 static BseErrorType
@@ -186,7 +183,6 @@ create_track_exec (BseProcedureClass *proc,
 }
 
 /* --- remove-track --- */
-static GType type_id_remove_track = 0;
 static void
 remove_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 138 "bsesong.proc"
@@ -201,7 +197,7 @@ remove_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 #line 29 "bsesong.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 30 "bsesong.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 144 "bsesong.proc"
 }  }
 static BseErrorType
@@ -248,7 +244,6 @@ remove_track_exec (BseProcedureClass *proc,
 }
 
 /* --- find-track-for-part --- */
-static GType type_id_find_track_for_part = 0;
 static void
 find_track_for_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 177 "bsesong.proc"
@@ -265,7 +260,7 @@ find_track_for_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPar
 #line 29 "bsesong.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 30 "bsesong.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 185 "bsesong.proc"
 }  }
 static BseErrorType
@@ -313,7 +308,6 @@ find_track_for_part_exec (BseProcedureClass *proc,
 }
 
 /* --- synthesize-note --- */
-static GType type_id_synthesize_note = 0;
 static void
 synthesize_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 222 "bsesong.proc"
@@ -330,13 +324,13 @@ synthesize_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
   *(in_pspecs++)    = bse_param_spec_fine_tune ("fine_tune", "Fine Tune", "Fine tune in cents per semitone");
   *(in_pspecs++)    = sfi_pspec_real ("velocity", "Velocity", NULL,
 			  1.0, 0, 1.0, 0.01,
-			  SFI_PARAM_DEFAULT SFI_PARAM_HINT_SCALE);
+			  SFI_PARAM_DEFAULT ":scale");
 #line 223 "bsesong.proc"
   proc->help = "Synthesize a note on a song of an active project.";
 #line 29 "bsesong.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 30 "bsesong.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 236 "bsesong.proc"
 }  }
 static BseErrorType
@@ -363,18 +357,18 @@ synthesize_note_exec (BseProcedureClass *proc,
   
 #line 253 "bsesong.proc"
   
-  if (BSE_SOURCE_PREPARED (self) && track->midi_receiver_SL)
+  if (BSE_SOURCE_PREPARED (self) && self->midi_receiver_SL)
     {
       gfloat freq = BSE_KAMMER_FREQUENCY_f *
 		    BSE_SEMITONE_FACTOR (note) *
 		    BSE_FINE_TUNE_FACTOR (fine_tune);
       SfiTime tstamp = gsl_tick_stamp () + gsl_engine_block_size () * 2;
       BseMidiEvent *eon, *eoff;
-      eon  = bse_midi_event_note_on (0, tstamp, freq, velocity);
-      eoff = bse_midi_event_note_off (0, tstamp + duration, freq);
-      bse_midi_receiver_push_event (track->midi_receiver_SL, eon);
-      bse_midi_receiver_push_event (track->midi_receiver_SL, eoff);
-      bse_midi_receiver_process_events (track->midi_receiver_SL, tstamp + duration);
+      eon  = bse_midi_event_note_on (track->midi_channel_SL, tstamp, freq, velocity);
+      eoff = bse_midi_event_note_off (track->midi_channel_SL, tstamp + duration, freq);
+      bse_midi_receiver_push_event (self->midi_receiver_SL, eon);
+      bse_midi_receiver_push_event (self->midi_receiver_SL, eoff);
+      bse_midi_receiver_process_events (self->midi_receiver_SL, tstamp + duration);
       bse_project_keep_activated (BSE_PROJECT (BSE_ITEM (self)->parent), tstamp + duration);
     }
   
@@ -382,7 +376,6 @@ synthesize_note_exec (BseProcedureClass *proc,
 }
 
 /* --- get-timing --- */
-static GType type_id_get_timing = 0;
 static void
 get_timing_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 272 "bsesong.proc"
@@ -396,7 +389,7 @@ get_timing_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 29 "bsesong.proc"
   proc->authors = "Tim Janik <timj@gtk.org>";
 #line 30 "bsesong.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
+  proc->license = "GNU Lesser General Public License";
 #line 277 "bsesong.proc"
 }  }
 static BseErrorType
@@ -429,18 +422,46 @@ get_timing_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { &type_id_create_part, "BseSong+create-part", NULL, 0, create_part_setup, create_part_exec, NULL, "/Method/BseSong/General/Create Part", { 0, }, },
-  { &type_id_remove_part, "BseSong+remove-part", NULL, 0, remove_part_setup, remove_part_exec, NULL, "/Method/BseSong/General/Remove Part", { 0, }, },
-  { &type_id_create_track, "BseSong+create-track", NULL, 0, create_track_setup, create_track_exec, NULL, "/Method/BseSong/General/Create Track", { 0, }, },
-  { &type_id_remove_track, "BseSong+remove-track", NULL, 0, remove_track_setup, remove_track_exec, NULL, "/Method/BseSong/General/Remove Track", { 0, }, },
-  { &type_id_find_track_for_part, "BseSong+find-track-for-part", NULL, 0, find_track_for_part_setup, find_track_for_part_exec, NULL, "/Method/BseSong/General/Find Track For Part", { 0, }, },
-  { &type_id_synthesize_note, "BseSong+synthesize-note", NULL, 0, synthesize_note_setup, synthesize_note_exec, NULL, "/Method/BseSong/General/Synthesize Note", { 0, }, },
-  { &type_id_get_timing, "BseSong+get-timing", NULL, 0, get_timing_setup, get_timing_exec, NULL, "/Method/BseSong/General/Get Timing", { 0, }, },
-  { NULL, },
+static BseExportNodeProc __enode_create_part = {
+  { NULL, BSE_EXPORT_NODE_PROC,
+    "BseSong+create-part", "/Methods/BseSong/General/Create Part", NULL },
+  0, create_part_setup, create_part_exec, 
 };
-BSE_EXPORTS_END;
+static BseExportNodeProc __enode_remove_part = {
+  { (BseExportNode*) &__enode_create_part, BSE_EXPORT_NODE_PROC,
+    "BseSong+remove-part", "/Methods/BseSong/General/Remove Part", NULL },
+  0, remove_part_setup, remove_part_exec, 
+};
+static BseExportNodeProc __enode_create_track = {
+  { (BseExportNode*) &__enode_remove_part, BSE_EXPORT_NODE_PROC,
+    "BseSong+create-track", "/Methods/BseSong/General/Create Track", NULL },
+  0, create_track_setup, create_track_exec, 
+};
+static BseExportNodeProc __enode_remove_track = {
+  { (BseExportNode*) &__enode_create_track, BSE_EXPORT_NODE_PROC,
+    "BseSong+remove-track", "/Methods/BseSong/General/Remove Track", NULL },
+  0, remove_track_setup, remove_track_exec, 
+};
+static BseExportNodeProc __enode_find_track_for_part = {
+  { (BseExportNode*) &__enode_remove_track, BSE_EXPORT_NODE_PROC,
+    "BseSong+find-track-for-part", "/Methods/BseSong/General/Find Track For Part", NULL },
+  0, find_track_for_part_setup, find_track_for_part_exec, 
+};
+static BseExportNodeProc __enode_synthesize_note = {
+  { (BseExportNode*) &__enode_find_track_for_part, BSE_EXPORT_NODE_PROC,
+    "BseSong+synthesize-note", "/Methods/BseSong/General/Synthesize Note", NULL },
+  0, synthesize_note_setup, synthesize_note_exec, 
+};
+static BseExportNodeProc __enode_get_timing = {
+  { (BseExportNode*) &__enode_synthesize_note, BSE_EXPORT_NODE_PROC,
+    "BseSong+get-timing", "/Methods/BseSong/General/Get Timing", NULL },
+  0, get_timing_setup, get_timing_exec, 
+};
+BseExportNode* bse__builtin_init_bsesong_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bsesong_gen_proc_c (void)
+{
+  return (BseExportNode*) &__enode_get_timing;
+}
 
 /**
  ** Generated data ends here
