@@ -141,6 +141,7 @@ struct _BseSourceClass
 			 guint		 ichannel,
 			 BseSource	*osource,
 			 guint		 ochannel);
+  GslClass *gsl_class;
 };
 
 
@@ -211,6 +212,16 @@ void		bse_source_access_modules	(BseSource	*source,
 						 gpointer	 data,
 						 GslFreeFunc	 data_free_func,
 						 GslTrans	*trans);
+BseErrorType    bse_source_check_input          (BseSource      *source,
+                                                 guint           ichannel,
+                                                 BseSource      *osource,
+                                                 guint           ochannel);
+void       bse_source_backup_ichannels_to_undo  (BseSource      *source);
+void       bse_source_backup_ochannels_to_undo  (BseSource      *source);
+void       bse_source_input_backup_to_undo      (BseSource      *source,
+                                                 guint           ichannel,
+                                                 BseSource      *osource,
+                                                 guint           ochannel);
 /* convenience */
 guint		bse_source_class_add_ichannel	(BseSourceClass	*source_class,
 						 const gchar	*name,
@@ -221,6 +232,8 @@ guint		bse_source_class_add_jchannel	(BseSourceClass	*source_class,
 guint		bse_source_class_add_ochannel	(BseSourceClass	*source_class,
 						 const gchar	*name,
 						 const gchar	*blurb);
+void    	bse_source_class_cache_gsl_class(BseSourceClass	*source_class,
+						 const GslClass *gsl_class);
 void		bse_source_set_context_module	(BseSource	*source,
 						 guint		 context_handle,
 						 GslModule	*module);
