@@ -19,7 +19,6 @@
 #include "bseitem.h"
 #include "gsldatahandle.h"
 #include "gsldatautils.h"
-#include "bseconfig.h"
 #include "bseproject.h"
 #include "bseparasite.h"
 #include <unistd.h>
@@ -127,6 +126,8 @@ bse_storage_init (BseStorage *self)
 {
   /* writing */
   self->wstore = NULL;
+  self->stored_items = NULL;
+  self->referenced_items = NULL;
   /* reading */
   self->rstore = NULL;
   self->item_links = NULL;
@@ -193,8 +194,6 @@ bse_storage_reset (BseStorage *self)
       bse_storage_resolve_item_links (self);
       g_hash_table_destroy (self->path_table);
       self->path_table = NULL;
-      if (self->rstore->fd >= 0)
-        close (self->rstore->fd);
       sfi_rstore_destroy (self->rstore);
       self->rstore = NULL;
     }
@@ -202,7 +201,13 @@ bse_storage_reset (BseStorage *self)
   if (self->wstore)
     sfi_wstore_destroy (self->wstore);
   self->wstore = NULL;
-  
+  if (self->stored_items)
+    sfi_ppool_destroy (self->stored_items);
+  self->stored_items = NULL;
+  if (self->referenced_items)
+    sfi_ppool_destroy (self->referenced_items);
+  self->referenced_items = NULL;
+
   self->major_version = BSE_MAJOR_VERSION;
   self->minor_version = BSE_MINOR_VERSION;
   self->micro_version = BSE_MICRO_VERSION;
@@ -255,6 +260,8 @@ bse_storage_prepare_write (BseStorage    *self,
 
   bse_storage_reset (self);
   self->wstore = sfi_wstore_new ();
+  self->stored_items = sfi_ppool_new ();
+  self->referenced_items = sfi_ppool_new ();
   mode &= BSE_STORAGE_MODE_MASK;
   if (mode & BSE_STORAGE_DBLOCK_CONTAINED)
     mode |= BSE_STORAGE_SELF_CONTAINED;
@@ -284,18 +291,14 @@ BseErrorType
 bse_storage_input_file (BseStorage  *self,
                         const gchar *file_name)
 {
-  gint fd;
-  
   g_return_val_if_fail (BSE_IS_STORAGE (self), BSE_ERROR_INTERNAL);
   g_return_val_if_fail (file_name != NULL, BSE_ERROR_INTERNAL);
 
   bse_storage_reset (self);
-  fd = open (file_name, O_RDONLY, 0);
-  if (fd < 0)
+  self->rstore = sfi_rstore_new_open (file_name);
+  if (!self->rstore)
     return bse_error_from_errno (errno, BSE_ERROR_FILE_OPEN_FAILED);
-  self->rstore = sfi_rstore_new ();
   self->rstore->parser_this = self;
-  sfi_rstore_input_fd (self->rstore, fd, file_name);
   self->path_table = g_hash_table_new_full (uname_child_hash, uname_child_equals, NULL, uname_child_free);
 
   return BSE_ERROR_NONE;
@@ -672,6 +675,9 @@ restore_container_child (BseContainer *container,
     return bse_storage_warn_skip (self, "failed to create object from (invalid?) handle: \"%s\"",
                                   scanner->value.v_string);
 
+  /* provide compatibility setup (e.g. property defaults) */
+  bse_item_compat_setup (item, self->major_version, self->minor_version, self->micro_version);
+
   storage_path_table_insert (self, container, uname, item);
 
   /* restore_item reads out closing parenthesis */
@@ -755,6 +761,20 @@ bse_storage_parse_rest (BseStorage     *self,
   return sfi_rstore_parse_until (self->rstore, ')', context_data, (SfiStoreParser) try_statement, user_data);
 }
 
+gboolean
+bse_storage_check_parse_negate (BseStorage *self)
+{
+  g_return_val_if_fail (BSE_IS_STORAGE (self), FALSE);
+
+  if (g_scanner_peek_next_token (bse_storage_get_scanner (self)) == '-')
+    {
+      g_scanner_get_next_token (bse_storage_get_scanner (self));
+      return TRUE;
+    }
+  else
+    return FALSE;
+}
+
 void
 bse_storage_put_param (BseStorage   *self,
                        const GValue *value,
@@ -803,6 +823,8 @@ bse_storage_put_item_link (BseStorage *self,
       common_ancestor = bse_item_common_ancestor (from_item, to_item);
       g_return_if_fail (BSE_IS_CONTAINER (common_ancestor));
 
+      sfi_ppool_set (self->referenced_items, to_item);
+
       /* figure number of parent backup levels to reach common ancestor */
       for (tmp = from_item; tmp != common_ancestor; tmp = tmp->parent)
         pbackup++;
@@ -1015,7 +1037,7 @@ store_item_properties (BseItem    *item,
     {
       GParamSpec *pspec = pspecs[n];
 
-      if (sfi_pspec_test_hint (pspec, SFI_PARAM_SERVE_STORAGE))
+      if (sfi_pspec_check_option (pspec, "S")) /* check serializable */
         {
           GValue value = { 0, };
 
@@ -1040,6 +1062,8 @@ bse_storage_store_item (BseStorage *self,
   g_object_ref (self);
   g_object_ref (item);
 
+  sfi_ppool_set (self->stored_items, item);
+
   store_item_properties (item, self);
 
   BSE_OBJECT_GET_CLASS (item)->store_private (BSE_OBJECT (item), self);
@@ -1111,7 +1135,7 @@ bse_storage_putr (BseStorage     *self,
   g_return_if_fail (BSE_IS_STORAGE (self));
   g_return_if_fail (self->wstore);
 
-  if (hints && strstr (hints, ":"SFI_PARAM_FLOAT))
+  if (hints && g_option_check (hints, "f"))     /* check float option */
     bse_storage_putf (self, vreal);
   else
     bse_storage_putd (self, vreal);
@@ -1233,8 +1257,6 @@ wstore_data_handle_reader (gpointer data,
   if (n < 0)    /* bail out */
     {
       bse_storage_error (wh->storage, "failed to read from data handle");
-      G_BREAKPOINT ();
-      n = gsl_data_handle_read (wh->dhandle, pos / wh->bpv, blength / sizeof (gfloat), buffer);
       return -EIO;
     }
 
