@@ -69,6 +69,9 @@ struct _BseStorage
   BseObject           parent_instance;
   /* writing */
   SfiWStore          *wstore;
+  SfiUPool           *stored_items2;
+  SfiPPool           *stored_items;
+  SfiPPool           *referenced_items;
   /* parsing */
   SfiRStore          *rstore;
   guint               major_version;
@@ -178,6 +181,7 @@ GTokenType   bse_storage_parse_rest             (BseStorage             *self,
                                                  gpointer                context_data,
                                                  BseTryStatement         try_statement,
                                                  gpointer                user_data);
+gboolean     bse_storage_check_parse_negate     (BseStorage             *self);
 
 
 /* --- short-hands --- */
