@@ -22,7 +22,7 @@
 #include "bsecsynth.h"
 #include "bseproject.h"
 #include "bsemidireceiver.h"
-#include "./icons/inoutport.c"
+#include "./icons/subsynth.c"
 #include "gslengine.h"
 
 #include <string.h>
@@ -90,9 +90,9 @@ BSE_BUILTIN_TYPE (BseSubSynth)
     (GInstanceInitFunc) bse_sub_synth_init,
   };
   static const BsePixdata pixdata = {
-    INOUTPORT_IMAGE_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
-    INOUTPORT_IMAGE_WIDTH, INOUTPORT_IMAGE_HEIGHT,
-    INOUTPORT_IMAGE_RLE_PIXEL_DATA,
+    SUBSYNTH_IMAGE_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
+    SUBSYNTH_IMAGE_WIDTH, SUBSYNTH_IMAGE_HEIGHT,
+    SUBSYNTH_IMAGE_RLE_PIXEL_DATA,
   };
   GType type = bse_type_register_static (BSE_TYPE_SOURCE,
                                          "BseSubSynth",
@@ -174,7 +174,8 @@ bse_sub_synth_init (BseSubSynth *synth)
   guint i;
   
   synth->snet = NULL;
-  
+  synth->null_shortcut = FALSE;
+
   for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
     {
       synth->input_ports[i] = g_strdup_printf ("synth_in_%u", i + 1);
@@ -193,7 +194,6 @@ bse_sub_synth_do_dispose (GObject *object)
       g_object_unref (self->snet);
       self->snet = NULL;
     }
-  bse_sub_synth_set_midi_receiver (self, NULL, 0);
   for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
     {
       g_free (self->input_ports[i]);
@@ -357,18 +357,21 @@ bse_sub_synth_get_property (GObject    *object,
 }
 
 void
-bse_sub_synth_set_midi_receiver (BseSubSynth     *self,
-				 BseMidiReceiver *midi_receiver,
-				 guint            midi_channel)
+bse_sub_synth_set_midi_channel (BseSubSynth     *self,
+                                guint            midi_channel)
 {
   g_return_if_fail (BSE_IS_SUB_SYNTH (self));
   
-  if (self->midi_receiver)
-    bse_midi_receiver_unref (self->midi_receiver);
-  self->midi_receiver = midi_receiver;
   self->midi_channel = midi_channel;
-  if (self->midi_receiver)
-    bse_midi_receiver_ref (self->midi_receiver);
+}
+
+void
+bse_sub_synth_set_null_shortcut (BseSubSynth *self,
+                                 gboolean     enabled)
+{
+  g_return_if_fail (BSE_IS_SUB_SYNTH (self));
+
+  self->null_shortcut = enabled != FALSE;
 }
 
 typedef struct {
@@ -387,8 +390,8 @@ bse_sub_synth_context_create (BseSource *source,
   ModData *mdata_out = g_new0 (ModData, 1);
   GslModule *imodule = gsl_module_new_virtual (BSE_SUB_SYNTH_N_IOPORTS, mdata_in, g_free);
   GslModule *omodule = gsl_module_new_virtual (BSE_SUB_SYNTH_N_IOPORTS, mdata_out, g_free);
-  guint foreign_context_handle = 0;
-  
+  guint foreign_context_handle = 0, shortcut = FALSE;
+
   /* create new context for foreign synth */
   if (snet && g_slist_find (recursion_stack, source))
     {
@@ -397,20 +400,18 @@ bse_sub_synth_context_create (BseSource *source,
     }
   else if (snet)
     {
-      BseMidiReceiver *midi_receiver = self->midi_receiver;
-      guint midi_channel = self->midi_channel;
-      
-      if (!midi_receiver)
-	{
-	  BseItem *parent = BSE_ITEM (self)->parent;
-	  midi_receiver = bse_snet_get_midi_receiver (BSE_SNET (parent), context_handle, &midi_channel);
-	}
+      BseItem *parent = BSE_ITEM (self)->parent;
+      BseMidiContext mcontext = bse_snet_get_midi_context (BSE_SNET (parent), context_handle);
+      if (self->midi_channel)
+	mcontext.midi_channel = self->midi_channel;
       recursion_stack = g_slist_prepend (recursion_stack, self);
-      foreign_context_handle = bse_snet_create_context (snet, midi_receiver, midi_channel, trans);
+      foreign_context_handle = bse_snet_create_context (snet, mcontext, trans);
       recursion_stack = g_slist_remove (recursion_stack, self);
       g_assert (foreign_context_handle > 0);
     }
-  
+  else
+    shortcut = self->null_shortcut;
+
   mdata_in->synth_context_handle = foreign_context_handle;
   mdata_out->synth_context_handle = foreign_context_handle;
   
@@ -422,6 +423,13 @@ bse_sub_synth_context_create (BseSource *source,
   gsl_trans_add (trans, gsl_job_integrate (imodule));
   gsl_trans_add (trans, gsl_job_integrate (omodule));
   
+  if (shortcut)
+    {
+      guint i;
+      for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
+        gsl_trans_add (trans, gsl_job_connect (imodule, i, omodule, i));
+    }
+
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->context_create (source, context_handle, trans);
 }
