@@ -4,42 +4,42 @@
  **/
 #line 1 "bsewaveosc.proc"
 
-#include        <bse/bseplugin.h>
-#include        <bse/bsewaveosc.h>
-#include        <bse/bseprocedure.h>
+#include <bse/bseplugin.h>
+#include <bse/bsewaveosc.h>
+#include <bse/bseprocedure.h>
+#include <bse/bseeditablesample.h>
 
-#line 24 "bsewaveosc.proc"
+#line 25 "bsewaveosc.proc"
 
 
 /* --- request-pcm-position --- */
-static GType type_id_request_pcm_position = 0;
 static void
 request_pcm_position_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 26 "bsewaveosc.proc"
+#line 27 "bsewaveosc.proc"
  {
-#line 28 "bsewaveosc.proc"
+#line 29 "bsewaveosc.proc"
   *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
 				 BSE_TYPE_WAVE_OSC, SFI_PARAM_DEFAULT);
-#line 27 "bsewaveosc.proc"
+#line 28 "bsewaveosc.proc"
   proc->help = "Request emission of the ::notify_pcm_position signal.";
-#line 22 "bsewaveosc.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
 #line 23 "bsewaveosc.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
-#line 30 "bsewaveosc.proc"
+  proc->authors = "Tim Janik <timj@gtk.org>";
+#line 24 "bsewaveosc.proc"
+  proc->license = "GNU General Public License";
+#line 31 "bsewaveosc.proc"
 }  }
 static BseErrorType
-#line 30 "bsewaveosc.proc"
+#line 31 "bsewaveosc.proc"
 request_pcm_position_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 33 "bsewaveosc.proc"
-{
 #line 34 "bsewaveosc.proc"
+{
+#line 35 "bsewaveosc.proc"
   
   BseWaveOsc *self = bse_value_get_object (in_values++);
   
-#line 37 "bsewaveosc.proc"
+#line 38 "bsewaveosc.proc"
   
   if (!BSE_IS_WAVE_OSC (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -50,38 +50,37 @@ request_pcm_position_exec (BseProcedureClass *proc,
 }
 
 /* --- pcm-seek-perc --- */
-static GType type_id_pcm_seek_perc = 0;
 static void
 pcm_seek_perc_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 46 "bsewaveosc.proc"
+#line 47 "bsewaveosc.proc"
  {
-#line 48 "bsewaveosc.proc"
+#line 49 "bsewaveosc.proc"
   *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
 				 BSE_TYPE_WAVE_OSC, SFI_PARAM_DEFAULT);
   *(in_pspecs++) = sfi_pspec_real ("pos_perc", NULL, NULL,
 			  0, 0, 100, 1,
 			  SFI_PARAM_DEFAULT);
-#line 47 "bsewaveosc.proc"
+#line 48 "bsewaveosc.proc"
   proc->help = "Seek oscillator to a given pcm percentage during playback.";
-#line 22 "bsewaveosc.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
 #line 23 "bsewaveosc.proc"
-  proc->copyright = "Copyright (C) 2002 Tim Janik";
-#line 53 "bsewaveosc.proc"
+  proc->authors = "Tim Janik <timj@gtk.org>";
+#line 24 "bsewaveosc.proc"
+  proc->license = "GNU General Public License";
+#line 54 "bsewaveosc.proc"
 }  }
 static BseErrorType
-#line 53 "bsewaveosc.proc"
+#line 54 "bsewaveosc.proc"
 pcm_seek_perc_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 56 "bsewaveosc.proc"
-{
 #line 57 "bsewaveosc.proc"
+{
+#line 58 "bsewaveosc.proc"
   
   BseWaveOsc *self = bse_value_get_object (in_values++);
   gfloat      pos  = sfi_value_get_real (in_values++);
   
-#line 61 "bsewaveosc.proc"
+#line 62 "bsewaveosc.proc"
   
   if (!BSE_IS_WAVE_OSC (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -91,14 +90,67 @@ pcm_seek_perc_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
+/* --- set-from-editable-sample --- */
+static void
+set_from_editable_sample_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 71 "bsewaveosc.proc"
+ {
+#line 73 "bsewaveosc.proc"
+  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
+				 BSE_TYPE_WAVE_OSC, SFI_PARAM_DEFAULT);
+  *(in_pspecs++) = bse_param_spec_object ("esample", NULL, "Editable Sample",
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
+#line 72 "bsewaveosc.proc"
+  proc->help = "Set wave to play from editable sample, bypassing undo and storage mechanisms.";
+#line 23 "bsewaveosc.proc"
+  proc->authors = "Tim Janik <timj@gtk.org>";
+#line 24 "bsewaveosc.proc"
+  proc->license = "GNU General Public License";
+#line 77 "bsewaveosc.proc"
+}  }
+static BseErrorType
+#line 77 "bsewaveosc.proc"
+set_from_editable_sample_exec (BseProcedureClass *proc,
+	const GValue      *in_values,
+	GValue            *out_values)
+#line 80 "bsewaveosc.proc"
+{
+#line 81 "bsewaveosc.proc"
+  
+  BseWaveOsc *self           = bse_value_get_object (in_values++);
+  BseEditableSample *esample = bse_value_get_object (in_values++);
+
+#line 85 "bsewaveosc.proc"
+  
+  if (!BSE_IS_WAVE_OSC (self))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  
+  bse_wave_osc_set_from_esample (self, esample);
+  
+  return BSE_ERROR_NONE;
+}
+
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { &type_id_request_pcm_position, "BseWaveOsc+request-pcm-position", NULL, 0, request_pcm_position_setup, request_pcm_position_exec, NULL, "/Method/BseWaveOsc/General/Request Pcm Position", { 0, }, },
-  { &type_id_pcm_seek_perc, "BseWaveOsc+pcm-seek-perc", NULL, 0, pcm_seek_perc_setup, pcm_seek_perc_exec, NULL, "/Method/BseWaveOsc/General/Pcm Seek Perc", { 0, }, },
-  { NULL, },
+static BseExportNodeProc __enode_request_pcm_position = {
+  { NULL, BSE_EXPORT_NODE_PROC,
+    "BseWaveOsc+request-pcm-position", "/Methods/BseWaveOsc/General/Request Pcm Position", NULL },
+  0, request_pcm_position_setup, request_pcm_position_exec, 
 };
-BSE_EXPORTS_END;
+static BseExportNodeProc __enode_pcm_seek_perc = {
+  { (BseExportNode*) &__enode_request_pcm_position, BSE_EXPORT_NODE_PROC,
+    "BseWaveOsc+pcm-seek-perc", "/Methods/BseWaveOsc/General/Pcm Seek Perc", NULL },
+  0, pcm_seek_perc_setup, pcm_seek_perc_exec, 
+};
+static BseExportNodeProc __enode_set_from_editable_sample = {
+  { (BseExportNode*) &__enode_pcm_seek_perc, BSE_EXPORT_NODE_PROC,
+    "BseWaveOsc+set-from-editable-sample", "/Methods/BseWaveOsc/General/Set From Editable Sample", NULL },
+  0, set_from_editable_sample_setup, set_from_editable_sample_exec, 
+};
+BseExportNode* bse__builtin_init_bsewaveosc_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bsewaveosc_gen_proc_c (void)
+{
+  return (BseExportNode*) &__enode_set_from_editable_sample;
+}
 
 /**
  ** Generated data ends here
