@@ -20,6 +20,21 @@
 #include "gslcommon.h"
 #include "gslopnode.h"
 #include "gslopmaster.h"
+#include <fcntl.h>
+#include <errno.h>
+#include <unistd.h>
+
+
+#define	DEBUG	sfi_debug_keyfunc ("engine")
+
+/* some systems don't have ERESTART (which is what linux returns for system
+ * calls on pipes which are being interrupted). most probably just use EINTR,
+ * and maybe some can return both. so we check for both in the below code,
+ * and alias ERESTART to EINTR if it's not present.
+ */
+#ifndef ERESTART
+#define ERESTART        EINTR
+#endif
 
 
 /* --- prototypes --- */
@@ -29,8 +44,9 @@ static void wakeup_master (void);
 /* --- UserThread --- */
 /**
  * gsl_module_new
- * @klass:   the GslClass which determines the module's behaviour
- * @RETURNS: a newly created module
+ * @klass:     the GslClass which determines the module's behaviour
+ * @user_data: user data pointer
+ * @RETURNS:   a newly created module
  *
  * Create a new module with methods specified in @klass and
  * a user_data field set to @user_data. The returned module
@@ -52,30 +68,31 @@ gsl_module_new (const GslClass *klass,
       return NULL;
     }
   
-  node = gsl_new_struct0 (EngineNode, 1);
+  node = sfi_new_struct0 (EngineNode, 1);
   
   /* setup GslModule */
   node->module.klass = klass;
   node->module.user_data = user_data;
-  node->module.istreams = klass->n_istreams ? gsl_new_struct0 (GslIStream, ENGINE_NODE_N_ISTREAMS (node)) : NULL;
-  node->module.jstreams = klass->n_jstreams ? gsl_new_struct0 (GslJStream, ENGINE_NODE_N_JSTREAMS (node)) : NULL;
+  node->module.istreams = klass->n_istreams ? sfi_new_struct0 (GslIStream, ENGINE_NODE_N_ISTREAMS (node)) : NULL;
+  node->module.jstreams = klass->n_jstreams ? sfi_new_struct0 (GslJStream, ENGINE_NODE_N_JSTREAMS (node)) : NULL;
   node->module.ostreams = _engine_alloc_ostreams (ENGINE_NODE_N_OSTREAMS (node));
   
   /* setup EngineNode */
-  node->inputs = ENGINE_NODE_N_ISTREAMS (node) ? gsl_new_struct0 (EngineInput, ENGINE_NODE_N_ISTREAMS (node)) : NULL;
-  node->jinputs = ENGINE_NODE_N_JSTREAMS (node) ? gsl_new_struct0 (EngineJInput*, ENGINE_NODE_N_JSTREAMS (node)) : NULL;
-  node->outputs = ENGINE_NODE_N_OSTREAMS (node) ? gsl_new_struct0 (EngineOutput, ENGINE_NODE_N_OSTREAMS (node)) : NULL;
+  node->inputs = ENGINE_NODE_N_ISTREAMS (node) ? sfi_new_struct0 (EngineInput, ENGINE_NODE_N_ISTREAMS (node)) : NULL;
+  node->jinputs = ENGINE_NODE_N_JSTREAMS (node) ? sfi_new_struct0 (EngineJInput*, ENGINE_NODE_N_JSTREAMS (node)) : NULL;
+  node->outputs = ENGINE_NODE_N_OSTREAMS (node) ? sfi_new_struct0 (EngineOutput, ENGINE_NODE_N_OSTREAMS (node)) : NULL;
   node->output_nodes = NULL;
   node->integrated = FALSE;
-  gsl_rec_mutex_init (&node->rec_mutex);
+  sfi_rec_mutex_init (&node->rec_mutex);
   for (i = 0; i < ENGINE_NODE_N_OSTREAMS (node); i++)
     {
       node->outputs[i].buffer = node->module.ostreams[i].values;
       node->module.ostreams[i].sub_sample_pattern = gsl_engine_sub_sample_test (node->module.ostreams[i].values);
     }
   node->flow_jobs = NULL;
-  node->fjob_first = NULL;
-  node->fjob_last = NULL;
+  node->boundary_jobs = NULL;
+  node->tjob_first = NULL;
+  node->tjob_last = NULL;
   
   return &node->module;
 }
@@ -99,6 +116,30 @@ gsl_module_tick_stamp (GslModule *module)
   return ENGINE_NODE (module)->counter;
 }
 
+/**
+ * gsl_module_has_source
+ * @module:  a GSL engine module
+ * @istream: Index of input stream
+ * @RETURNS: whether the module has a possible input
+ *
+ * Check whether @istream may be disconnected via
+ * gsl_job_disconnect(). This is not an indication for whether
+ * @istream will be connected during process(), as the source
+ * may be a dangling virtual module, resulting in an unconnected
+ * input stream after the next scheduling phase.
+ * See also gsl_module_new_virtual().
+ * This function is MT-safe and may be called from any thread.
+ */
+gboolean
+gsl_module_has_source (GslModule *module,
+                       guint      istream)
+{
+  g_return_val_if_fail (module != NULL, FALSE);
+  g_return_val_if_fail (istream < module->klass->n_istreams, FALSE);
+  
+  return ENGINE_NODE (module)->inputs[istream].src_node != NULL;
+}
+
 /**
  * gsl_job_integrate
  * @module: The module to integrate
@@ -114,7 +155,7 @@ gsl_job_integrate (GslModule *module)
   
   g_return_val_if_fail (module != NULL, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_INTEGRATE;
   job->data.node = ENGINE_NODE (module);
   
@@ -137,7 +178,7 @@ gsl_job_discard (GslModule *module)
   
   g_return_val_if_fail (module != NULL, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_DISCARD;
   job->data.node = ENGINE_NODE (module);
   
@@ -160,7 +201,7 @@ gsl_job_kill_inputs (GslModule *module)
   
   g_return_val_if_fail (module != NULL, NULL);
 
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_KILL_INPUTS;
   job->data.node = ENGINE_NODE (module);
 
@@ -183,7 +224,7 @@ gsl_job_kill_outputs (GslModule *module)
   
   g_return_val_if_fail (module != NULL, NULL);
 
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_KILL_OUTPUTS;
   job->data.node = ENGINE_NODE (module);
 
@@ -217,7 +258,7 @@ gsl_job_connect (GslModule *src_module,
   g_return_val_if_fail (dest_module != NULL, NULL);
   g_return_val_if_fail (dest_istream < dest_module->klass->n_istreams, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_ICONNECT;
   job->data.connection.dest_node = ENGINE_NODE (dest_module);
   job->data.connection.dest_ijstream = dest_istream;
@@ -253,7 +294,7 @@ gsl_job_jconnect (GslModule *src_module,
   g_return_val_if_fail (dest_module != NULL, NULL);
   g_return_val_if_fail (dest_jstream < dest_module->klass->n_jstreams, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_JCONNECT;
   job->data.connection.dest_node = ENGINE_NODE (dest_module);
   job->data.connection.dest_ijstream = dest_jstream;
@@ -283,7 +324,7 @@ gsl_job_disconnect (GslModule *dest_module,
   g_return_val_if_fail (dest_module != NULL, NULL);
   g_return_val_if_fail (dest_istream < dest_module->klass->n_istreams, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_IDISCONNECT;
   job->data.connection.dest_node = ENGINE_NODE (dest_module);
   job->data.connection.dest_ijstream = dest_istream;
@@ -322,7 +363,7 @@ gsl_job_jdisconnect (GslModule *dest_module,
   g_return_val_if_fail (src_module != NULL, NULL);
   g_return_val_if_fail (src_ostream < src_module->klass->n_ostreams, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_JDISCONNECT;
   job->data.connection.dest_node = ENGINE_NODE (dest_module);
   job->data.connection.dest_ijstream = dest_jstream;
@@ -341,13 +382,40 @@ gsl_job_set_consumer (GslModule *module,
   g_return_val_if_fail (module != NULL, NULL);
   g_return_val_if_fail (ENGINE_MODULE_IS_VIRTUAL (module) == FALSE, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = is_toplevel_consumer ? ENGINE_JOB_SET_CONSUMER : ENGINE_JOB_UNSET_CONSUMER;
   job->data.node = ENGINE_NODE (module);
   
   return job;
 }
 
+/**
+ * gsl_job_force_reset
+ * @module: The module to be reset
+ * @Returns: New job suitable for gsl_trans_add()
+ *
+ * Forces an immediate reset of @module if its class
+ * provides a reset() implementation. This is usually
+ * not a good idea, as forcing an immediate reset can
+ * lead to multiple unnecessary reset() invocations.
+ * The logic used to invoke reset() automatically is
+ * usually good enough to cover all required cases.
+ * This function is MT-safe and may be called from any thread.
+ */
+GslJob*
+gsl_job_force_reset (GslModule *module)
+{
+  GslJob *job;
+  
+  g_return_val_if_fail (module != NULL, NULL);
+  
+  job = sfi_new_struct0 (GslJob, 1);
+  job->job_id = ENGINE_JOB_FORCE_RESET;
+  job->data.node = ENGINE_NODE (module);
+  
+  return job;
+}
+
 /**
  * GslAccessFunc
  * @module:	Module to operate on
@@ -362,9 +430,9 @@ gsl_job_set_consumer (GslModule *module,
 /**
  * gsl_job_access
  * @module: The module to access
- * @access_func: The accessor function
+ * @access_func: The accessor function (executed in master thread)
  * @data: Data passed in to the accessor
- * @free_func: Function to free @data
+ * @free_func: Function to free @data (executed in user thread)
  * @Returns: New job suitable for gsl_trans_add()
  *
  * Create a new transaction job which will invoke @access_func 
@@ -383,7 +451,7 @@ gsl_job_access (GslModule    *module,
   g_return_val_if_fail (module != NULL, NULL);
   g_return_val_if_fail (access_func != NULL, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_ACCESS;
   job->data.access.node = ENGINE_NODE (module);
   job->data.access.access_func = access_func;
@@ -411,37 +479,81 @@ gsl_job_access (GslModule    *module,
  * This function is MT-safe and may be called from any thread.
  */
 GslJob*
-gsl_flow_job_access (GslModule    *module,
+gsl_job_flow_access (GslModule    *module,
 		     guint64       tick_stamp,
 		     GslAccessFunc access_func,
 		     gpointer      data,
 		     GslFreeFunc   free_func)
 {
   GslJob *job;
-  EngineFlowJob *fjob;
+  EngineTimedJob *tjob;
 
   g_return_val_if_fail (module != NULL, NULL);
   g_return_val_if_fail (ENGINE_MODULE_IS_VIRTUAL (module) == FALSE, NULL);
   g_return_val_if_fail (tick_stamp < GSL_MAX_TICK_STAMP, NULL);
   g_return_val_if_fail (access_func != NULL, NULL);
   
-  fjob = (EngineFlowJob*) gsl_new_struct0 (EngineFlowJobAccess, 1);
-  fjob->fjob_id = ENGINE_FLOW_JOB_ACCESS;
-  fjob->any.tick_stamp = tick_stamp;
-  fjob->access.access_func = access_func;
-  fjob->access.data = data;
-  fjob->access.free_func = free_func;
+  tjob = sfi_new_struct0 (EngineTimedJob, 1);
+  tjob->tick_stamp = tick_stamp;
+  tjob->access_func = access_func;
+  tjob->data = data;
+  tjob->free_func = free_func;
 
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_FLOW_JOB;
-  job->data.flow_job.node = ENGINE_NODE (module);
-  job->data.flow_job.fjob = fjob;
+  job->data.timed_job.node = ENGINE_NODE (module);
+  job->data.timed_job.tjob = tjob;
   
   return job;
 }
 
 /**
- * gsl_job_suspend
+ * gsl_job_boundary_access
+ * @module:      The module to access
+ * @tick_stamp:  Engine time stamp
+ * @access_func: The accessor function
+ * @data:        Data passed in to the accessor
+ * @free_func:   Function to free @data
+ * @Returns:     New job suitable for gsl_trans_add()
+ *
+ * Create a new transaction job which inserts @access_func 
+ * with @data into the boundary job queue of @module.
+ * Boundary jobs are executed at block boundaries, after all
+ * ordinary jobs have been processed and before global time
+ * stamp counter passed @tick_stamp.
+ * This function is MT-safe and may be called from any thread.
+ */
+GslJob*
+gsl_job_boundary_access (GslModule    *module,
+                         guint64       tick_stamp,
+                         GslAccessFunc access_func,
+                         gpointer      data,
+                         GslFreeFunc   free_func)
+{
+  GslJob *job;
+  EngineTimedJob *tjob;
+
+  g_return_val_if_fail (module != NULL, NULL);
+  g_return_val_if_fail (ENGINE_MODULE_IS_VIRTUAL (module) == FALSE, NULL);
+  g_return_val_if_fail (tick_stamp < GSL_MAX_TICK_STAMP, NULL);
+  g_return_val_if_fail (access_func != NULL, NULL);
+  
+  tjob = sfi_new_struct0 (EngineTimedJob, 1);
+  tjob->tick_stamp = tick_stamp;
+  tjob->access_func = access_func;
+  tjob->data = data;
+  tjob->free_func = free_func;
+
+  job = sfi_new_struct0 (GslJob, 1);
+  job->job_id = ENGINE_JOB_BOUNDARY_JOB;
+  job->data.timed_job.node = ENGINE_NODE (module);
+  job->data.timed_job.tjob = tjob;
+  
+  return job;
+}
+
+/**
+ * gsl_job_suspend_now
  * @module: Module not currently suspended
  * @Returns: New job suitable for gsl_trans_add()
  *
@@ -453,56 +565,52 @@ gsl_flow_job_access (GslModule    *module,
  * This function is MT-safe and may be called from any thread.
  */
 GslJob*
-gsl_job_suspend (GslModule *module)
+gsl_job_suspend_now (GslModule *module)
 {
   GslJob *job;
 
   g_return_val_if_fail (module != NULL, NULL);
   g_return_val_if_fail (ENGINE_MODULE_IS_VIRTUAL (module) == FALSE, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_SUSPEND;
-  job->data.node = ENGINE_NODE (module);
+  job->data.tick.node = ENGINE_NODE (module);
+  job->data.tick.stamp = GSL_MAX_TICK_STAMP;
 
   return job;
 }
 
 /**
- * gsl_flow_job_resume
- * @module: Module not currently suspended
- * @Returns: New job suitable for gsl_trans_add()
+ * gsl_job_resume_at
+ * @module:     Module to resume
+ * @tick_stamp: Sample tick at which to resume @module
+ * @Returns:    New job suitable for gsl_trans_add()
  *
  * Create a new transaction job which inserts a resumption
- * event into the flow job queue of @module.
- * Flow jobs are jobs with limited impact on modules, which
- * are executed during flow system progress at specific times.
+ * event into the job queue of @module.
  * Once the time stamp counter of @module passed @tick_stamp,
- * its reset() method is called and the module is resumed,
- * causing it's process() method to be called again.
+ * if it is supended, its reset() method is called and the
+ * module is resumed, causing it's process() method to be
+ * called again.
  * Resuming a module also resumes all input modules it has,
- * unless those were explicitely suspended via gsl_job_suspend().
+ * unless those were explicitely suspended via gsl_job_suspend_now().
  * This function is MT-safe and may be called from any thread.
  */
 GslJob*
-gsl_flow_job_resume (GslModule *module,
-		     guint64    tick_stamp)
+gsl_job_resume_at (GslModule *module,
+                   guint64    tick_stamp)
 {
   GslJob *job;
-  EngineFlowJob *fjob;
   
   g_return_val_if_fail (module != NULL, NULL);
   g_return_val_if_fail (ENGINE_MODULE_IS_VIRTUAL (module) == FALSE, NULL);
   g_return_val_if_fail (tick_stamp < GSL_MAX_TICK_STAMP, NULL);
   
-  fjob = (EngineFlowJob*) gsl_new_struct0 (EngineFlowJobAny, 1);
-  fjob->fjob_id = ENGINE_FLOW_JOB_RESUME;
-  fjob->any.tick_stamp = tick_stamp;
-  
-  job = gsl_new_struct0 (GslJob, 1);
-  job->job_id = ENGINE_JOB_FLOW_JOB;
-  job->data.flow_job.node = ENGINE_NODE (module);
-  job->data.flow_job.fjob = fjob;
-  
+  job = sfi_new_struct0 (GslJob, 1);
+  job->job_id = ENGINE_JOB_RESUME;
+  job->data.tick.node = ENGINE_NODE (module);
+  job->data.tick.stamp = tick_stamp;
+
   return job;
 }
 
@@ -555,10 +663,11 @@ gsl_job_add_poll (GslPollFunc    poll_func,
   if (n_fds)
     g_return_val_if_fail (fds != NULL, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_ADD_POLL;
   job->data.poll.poll_func = poll_func;
   job->data.poll.data = data;
+  job->data.poll.free_func = free_func;
   job->data.poll.n_fds = n_fds;
   job->data.poll.fds = g_memdup (fds, sizeof (fds[0]) * n_fds);
   
@@ -583,16 +692,47 @@ gsl_job_remove_poll (GslPollFunc poll_func,
   
   g_return_val_if_fail (poll_func != NULL, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_REMOVE_POLL;
   job->data.poll.poll_func = poll_func;
   job->data.poll.data = data;
   job->data.poll.free_func = NULL;
+  job->data.poll.n_fds = 0;
   job->data.poll.fds = NULL;
   
   return job;
 }
 
+/**
+ * gsl_job_add_timer
+ * @timer_func: Timer function to add
+ * @data: Data of timer function
+ * @free_func: Function to free @data
+ * @Returns: New job suitable for gsl_trans_add()
+ *
+ * Create a new transaction job which adds a timer function
+ * to the engine. The timer function is called after the engine
+ * caused new tick stamp updates.
+ * This function is MT-safe and may be called from any thread.
+ */
+GslJob*
+gsl_job_add_timer (GslEngineTimerFunc timer_func,
+		   gpointer           data,
+		   GslFreeFunc        free_func)
+{
+  GslJob *job;
+
+  g_return_val_if_fail (timer_func != NULL, NULL);
+
+  job = sfi_new_struct0 (GslJob, 1);
+  job->job_id = ENGINE_JOB_ADD_TIMER;
+  job->data.timer.timer_func = timer_func;
+  job->data.timer.data = data;
+  job->data.timer.free_func = free_func;
+
+  return job;
+}
+
 /**
  * gsl_job_debug
  * @debug: Debug message
@@ -610,7 +750,7 @@ gsl_job_debug (const gchar *debug)
   
   g_return_val_if_fail (debug != NULL, NULL);
   
-  job = gsl_new_struct0 (GslJob, 1);
+  job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_DEBUG;
   job->data.debug = g_strdup (debug);
   
@@ -632,7 +772,7 @@ gsl_trans_open (void)
 {
   GslTrans *trans;
 
-  trans = gsl_new_struct0 (GslTrans, 1);
+  trans = sfi_new_struct0 (GslTrans, 1);
   
   trans->jobs_head = NULL;
   trans->jobs_tail = NULL;
@@ -666,21 +806,58 @@ gsl_trans_add (GslTrans *trans,
   trans->jobs_tail = job;
 }
 
+/**
+ * gsl_trans_merge
+ * @trans1:  open transaction
+ * @trans2:  open transaction
+ * @Returns: open transaction
+ *
+ * Merge two open transactions by appending the jobs of @trans2
+ * to the jobs of @trans1, returning the resulting transaction.
+ * This function is MT-safe and may be called from any thread.
+ */
+GslTrans*
+gsl_trans_merge (GslTrans *trans1,
+		 GslTrans *trans2)
+{
+  g_return_val_if_fail (trans1 != NULL, trans2);
+  g_return_val_if_fail (trans1->comitted == FALSE, trans2);
+  g_return_val_if_fail (trans2 != NULL, trans1);
+  g_return_val_if_fail (trans2->comitted == FALSE, trans1);
+
+  if (!trans1->jobs_head)
+    {
+      trans1->jobs_head = trans2->jobs_head;
+      trans1->jobs_tail = trans2->jobs_tail;
+      trans2->jobs_head = NULL;
+      trans2->jobs_tail = NULL;
+    }
+  else if (trans2->jobs_head)
+    {
+      trans1->jobs_tail->next = trans2->jobs_head;
+      trans1->jobs_tail = trans2->jobs_tail;
+      trans2->jobs_head = NULL;
+      trans2->jobs_tail = NULL;
+    }
+  gsl_trans_dismiss (trans2);
+  return trans1;
+}
+
 /**
  * gsl_trans_commit
- * @trans: Opened transaction
+ * @trans: open transaction
  *
  * Close the transaction and commit it to the engine. The engine
  * will execute the jobs contained in this transaction as soon as
  * it has completed its current processing cycle. The jobs will be
  * executed in the exact order they were added to the transaction.
+ * This function is MT-safe and may be called from any thread.
  */
 void
 gsl_trans_commit (GslTrans *trans)
 {
   g_return_if_fail (trans != NULL);
   g_return_if_fail (trans->comitted == FALSE);
-  g_return_if_fail (trans->cqt_next == NULL);
   
   if (trans->jobs_head)
     {
@@ -689,7 +866,78 @@ gsl_trans_commit (GslTrans *trans)
       wakeup_master ();
     }
   else
-    _engine_free_trans (trans);
+    gsl_trans_dismiss (trans);
+}
+
+typedef struct {
+  GslTrans *trans;
+  guint64   tick_stamp;
+  SfiCond   cond;
+  SfiMutex  mutex;
+} DTrans;
+
+static gboolean
+dtrans_timer (gpointer timer_data,
+	      guint64  stamp)
+{
+  DTrans *data = timer_data;
+  if (data->tick_stamp <= stamp)
+    {
+      if (!data->trans->jobs_head)
+	{
+	  /* this is sick, is this some perverted way of
+	   * trying to wait until @tick_stamp passed by?
+	   */
+	  gsl_trans_dismiss (data->trans);
+	}
+      else
+	gsl_trans_commit (data->trans);
+      SFI_SPIN_LOCK (&data->mutex);
+      data->trans = NULL;
+      SFI_SPIN_UNLOCK (&data->mutex);
+      sfi_cond_signal (&data->cond);
+      return FALSE;
+    }
+  return TRUE;
+}
+
+/**
+ * gsl_trans_commit_delayed
+ * @trans:      open transaction
+ * @tick_stamp: earliest stamp
+ *
+ * Commit the transaction like gsl_trans_commit(), but make sure
+ * that the commit happens no earlier than @tick_stamp. This
+ * function will block until the commit occoured, so it will not
+ * return any earlier than @tick_stamp.
+ * This function is MT-safe and may be called from any thread.
+ */ /* bullshit, this function can't be called from the master thread ;) */
+void
+gsl_trans_commit_delayed (GslTrans *trans,
+			  guint64   tick_stamp)
+{
+  g_return_if_fail (trans != NULL);
+  g_return_if_fail (trans->comitted == FALSE);
+
+  if (tick_stamp <= gsl_tick_stamp ())
+    gsl_trans_commit (trans);
+  else
+    {
+      GslTrans *wtrans = gsl_trans_open ();
+      DTrans data = { 0, };
+      data.trans = trans;
+      data.tick_stamp = tick_stamp;
+      sfi_cond_init (&data.cond);
+      sfi_mutex_init (&data.mutex);
+      gsl_trans_add (wtrans, gsl_job_add_timer (dtrans_timer, &data, NULL));
+      SFI_SPIN_LOCK (&data.mutex);
+      gsl_trans_commit (wtrans);
+      while (data.trans)
+	sfi_cond_wait (&data.cond, &data.mutex);
+      SFI_SPIN_UNLOCK (&data.mutex);
+      sfi_cond_destroy (&data.cond);
+      sfi_mutex_destroy (&data.mutex);
+    }
 }
 
 /**
@@ -705,7 +953,6 @@ gsl_trans_dismiss (GslTrans *trans)
 {
   g_return_if_fail (trans != NULL);
   g_return_if_fail (trans->comitted == FALSE);
-  g_return_if_fail (trans->cqt_next == NULL);
   
   _engine_free_trans (trans);
 }
@@ -856,17 +1103,21 @@ slave (gpointer data)
 }
 
 /* --- setup & trigger --- */
-static gboolean   gsl_engine_initialized = FALSE;
-static gboolean   gsl_engine_threaded = FALSE;
-static GslThread *master_thread = NULL;
-guint		gsl_externvar_bsize = 0;
-guint		gsl_externvar_sample_freq = 0;
-guint		gsl_externvar_sub_sample_mask = 0;
-guint		gsl_externvar_sub_sample_steps = 0;
+static gboolean		gsl_engine_initialized = FALSE;
+static gboolean		gsl_engine_threaded = FALSE;
+static SfiThread       *master_thread = NULL;
+static EngineMasterData master_data;
+guint			gsl_externvar_bsize = 0;
+guint			gsl_externvar_sample_freq = 0;
+guint			gsl_externvar_sub_sample_mask = 0;
+guint			gsl_externvar_sub_sample_steps = 0;
 
 /**
  * gsl_engine_init
- * @block_size: number of values to process block wise
+ * @run_threaded:    whether the engine should be run threaded
+ * @block_size:      number of values to process block wise
+ * @sample_freq:     mixing frequency
+ * @sub_sample_mask: not yet funcitonal
  *
  * Initialize the GSL engine, this function must be called prior to
  * any other engine related function and can only be invoked once.
@@ -895,13 +1146,33 @@ gsl_engine_init (gboolean run_threaded,
   _gsl_tick_stamp_set_leap (block_size);
   _gsl_tick_stamp_inc ();	/* ensure stamp validity (>0 and systime mark) */
   
-  ENG_DEBUG ("initialization: threaded=%s", gsl_engine_threaded ? "TRUE" : "FALSE");
+  DEBUG ("initialization: threaded=%s", gsl_engine_threaded ? "TRUE" : "FALSE");
   
   if (gsl_engine_threaded)
     {
-      master_thread = gsl_thread_new (_engine_master_thread, NULL);
+      gint err = pipe (master_data.wakeup_pipe);
+      master_data.user_thread = sfi_thread_self ();
+      if (!err)
+	{
+	  glong d_long = fcntl (master_data.wakeup_pipe[0], F_GETFL, 0);
+	  /* sfi_debug ("master_wpipe-readfd, blocking=%ld", d_long & O_NONBLOCK); */
+	  d_long |= O_NONBLOCK;
+	  err = fcntl (master_data.wakeup_pipe[0], F_SETFL, d_long);
+	}
+      if (!err)
+	{
+	  glong d_long = fcntl (master_data.wakeup_pipe[1], F_GETFL, 0);
+	  /* sfi_debug ("master_wpipe-writefd, blocking=%ld", d_long & O_NONBLOCK); */
+	  d_long |= O_NONBLOCK;
+	  err = fcntl (master_data.wakeup_pipe[1], F_SETFL, d_long);
+	}
+      if (err)
+	g_error ("failed to create wakeup pipe: %s", g_strerror (errno));
+      master_thread = sfi_thread_run ("Master", (SfiThreadFunc) _engine_master_thread, &master_data);
+      if (!master_thread)
+	g_error ("failed to create master thread");
       if (0)
-	gsl_thread_new (slave, NULL);
+	sfi_thread_run ("Slave", slave, NULL);
     }
 }
 
@@ -909,7 +1180,13 @@ static void
 wakeup_master (void)
 {
   if (master_thread)
-    gsl_thread_wakeup (master_thread);
+    {
+      guint8 data = 'W';
+      gint l;
+      do
+	l = write (master_data.wakeup_pipe[1], &data, 1);
+      while (l < 0 && (errno == EINTR || errno == ERESTART));
+    }
 }
 
 gboolean
@@ -983,7 +1260,7 @@ gsl_engine_tick_stamp_from_systime (guint64 systime)
   guint64 tick_stamp;
 
   /* FIXME: we should add special guards here
-   * for gsl_time_system() - ustamp.system_time ~> (44100 / gsl_engine_block_size ())
+   * for sfi_time_system() - ustamp.system_time ~> (44100 / gsl_engine_block_size ())
    */
 
   if (systime > ustamp.system_time)
@@ -1009,7 +1286,7 @@ gsl_engine_tick_stamp_from_systime (guint64 systime)
 	     "  last-update-systime   = %llu\n"
 	     "  last-update-tickstamp = %llu\n"
 	     "  sample-freq           = %u\n",
-	     tick_stamp, systime, gsl_time_system (), gsl_tick_stamp (),
+	     tick_stamp, systime, sfi_time_system (), gsl_tick_stamp (),
 	     ustamp.system_time, ustamp.tick_stamp,
 	     gsl_engine_sample_freq ());
 #endif
