@@ -20,6 +20,7 @@
 
 #include <bse/gslengine.h>
 
+#include <string.h>
 
 /* --- prototypes --- */
 static void	 bse_mult_init			(BseMult	*mult);
@@ -29,22 +30,16 @@ static void	 bse_mult_context_create	(BseSource	*source,
 						 GslTrans	*trans);
 
 
+/* --- Export to BSE --- */
+#include "./icons/multiply.c"
+BSE_REGISTER_OBJECT (BseMult, BseSource, "/Modules/Routing/Multiply", multiply_icon,
+                     "Mult is a channel multiplier for ring-modulating incoming signals",
+                     bse_mult_class_init, NULL, bse_mult_init);
+BSE_DEFINE_EXPORTS (BSE_PLUGIN_NAME);
+
+
 /* --- variables --- */
-static GType		 type_id_mult = 0;
 static gpointer		 parent_class = NULL;
-static const GTypeInfo type_info_mult = {
-  sizeof (BseMultClass),
-  
-  (GBaseInitFunc) NULL,
-  (GBaseFinalizeFunc) NULL,
-  (GClassInitFunc) bse_mult_class_init,
-  (GClassFinalizeFunc) NULL,
-  NULL /* class_data */,
-  
-  sizeof (BseMult),
-  0 /* n_preallocs */,
-  (GInstanceInitFunc) bse_mult_init,
-};
 
 
 /* --- functions --- */
@@ -83,8 +78,8 @@ multiply_process (GslModule *module,
 		  guint      n_values)
 {
   // = module->user_data;
-  BseSampleValue *wave_out = GSL_MODULE_OBUFFER (module, 0);
-  BseSampleValue *bound = wave_out + n_values;
+  gfloat *wave_out = GSL_MODULE_OBUFFER (module, 0);
+  gfloat *bound = wave_out + n_values;
   guint i;
   
   if (!module->ostreams[0].connected)
@@ -104,8 +99,8 @@ multiply_process (GslModule *module,
   for (i += 1; i < GSL_MODULE_N_ISTREAMS (module); i++)
     if (module->istreams[i].connected)
       {
-	const BseSampleValue *in = GSL_MODULE_IBUFFER (module, i);
-	BseSampleValue *out = wave_out;
+	const gfloat *in = GSL_MODULE_IBUFFER (module, i);
+	gfloat *out = wave_out;
 	
 	/* found 1+nth channel to multiply with */
 	do
@@ -143,20 +138,3 @@ bse_mult_context_create (BseSource *source,
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->context_create (source, context_handle, trans);
 }
-
-
-/* --- Export to BSE --- */
-#include "./icons/prod.c"
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_OBJECTS = {
-  { &type_id_mult, "BseMult", "BseSource",
-    "Mult is a channel multiplier for ring-modulating incoming signals",
-    &type_info_mult,
-    "/Modules/Routing/Mult",
-    { PROD_IMAGE_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
-      PROD_IMAGE_WIDTH, PROD_IMAGE_HEIGHT,
-      PROD_IMAGE_RLE_PIXEL_DATA, },
-  },
-  { NULL, },
-};
-BSE_EXPORTS_END;
