@@ -66,7 +66,18 @@ guint		g_strlenv	  (gchar	**str_array);
 gchar*		g_strdup_stripped (const gchar	 *string);
 gchar*		g_strdup_rstrip   (const gchar	 *string);
 gchar*		g_strdup_lstrip   (const gchar	 *string);
-     
+
+const gchar*    g_quark_intern        (const gchar   *string);
+const gchar*    g_quark_intern_static (const gchar   *string);
+
+gchar*          g_path_concat     (const gchar   *first_path,
+                                   ...);
+
+
+/* --- string options --- */
+gboolean        g_option_check    (const gchar   *option_string,
+                                   const gchar   *option);
+
 
 /* --- list extensions --- */
 gpointer	g_slist_pop_head	(GSList	     **slist_p);
@@ -86,28 +97,6 @@ gchar*  g_type_name_to_cupper           (const gchar    *type_name);
 gchar*  g_type_name_to_type_macro       (const gchar    *type_name);
 
 
-/* --- double array --- */
-typedef struct {
-  guint    n_values;
-  gdouble *values;
-  guint    n_prealloced;
-} GDArray;
-
-GDArray*	g_darray_new	(guint		 prealloc);
-void		g_darray_free	(GDArray	*darray);
-gdouble		g_darray_get	(GDArray	*darray,
-				 guint		 index);
-void		g_darray_insert	(GDArray        *darray,
-				 guint           index,
-				 gdouble	 value);
-void		g_darray_append	(GDArray        *darray,
-				 gdouble	 value);
-void		g_darray_set	(GDArray        *darray,
-				 guint           index,
-				 gdouble	 value);
-#define	g_darray_prepend(a,v)	g_darray_insert ((a), 0, (v))
-
-
 /* --- simple main loop source --- */
 typedef gboolean (*GSourcePending)  (gpointer	 data,
 				     gint	*timeout);
