@@ -1,5 +1,5 @@
 /* SFI - Synthesis Fusion Kit Interface
- * Copyright (C) 2002 Tim Janik
+ * Copyright (C) 2002, 2003 Tim Janik
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,10 +22,7 @@
 #include <sfi/sfiprimitives.h>
 #include <sfi/sfiparams.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
+G_BEGIN_DECLS
 
 /* Glue proxy (object handle) description in terms of
  * supported interfaces and property names
@@ -40,7 +37,7 @@ typedef struct {
 } SfiGlueIFace;
 
 gchar*		sfi_glue_base_iface	(void);
-gchar**		sfi_glue_iface_children	(const gchar	*iface_name);
+const gchar**	sfi_glue_iface_children	(const gchar	*iface_name);
 SfiGlueIFace*	sfi_glue_describe_iface	(const gchar	*iface_name);
 SfiGlueIFace*	sfi_glue_iface_ref	(SfiGlueIFace	*iface);
 void		sfi_glue_iface_unref	(SfiGlueIFace	*iface);
@@ -55,7 +52,7 @@ typedef struct {
   gchar       *blurb;
   gchar       *help;
   gchar       *authors;
-  gchar       *copyright;
+  gchar       *license;
   GParamSpec  *ret_param;
   guint        n_params;
   GParamSpec **params;
@@ -64,8 +61,8 @@ typedef struct {
 SfiGlueProc*	sfi_glue_describe_proc		(const gchar	*proc_name);
 SfiGlueProc*	sfi_glue_proc_ref		(SfiGlueProc	*proc);
 void		sfi_glue_proc_unref		(SfiGlueProc	*proc);
-gchar**		sfi_glue_list_proc_names	(void);
-gchar**		sfi_glue_list_method_names	(const gchar	*iface_name);
+const gchar**	sfi_glue_list_proc_names	(void);
+const gchar**	sfi_glue_list_method_names	(const gchar	*iface_name);
 
 GValue*		sfi_glue_call_seq		(const gchar	*proc_name,
 						 SfiSeq		*params);
@@ -211,6 +208,9 @@ void		sfi_glue_proc_add_param		(SfiGlueProc	*proc,
 						 GParamSpec	*param);
 void		sfi_glue_proc_add_ret_param	(SfiGlueProc	*proc,
 						 GParamSpec	*param);
+gboolean       _sfi_glue_proxy_request_notify	(SfiProxy        proxy,
+						 const gchar    *signal,
+						 gboolean        enable_notify);
 
 
 /* --- implementations --- */
@@ -228,10 +228,7 @@ sfi_glue_fetch_context (const gchar *floc)
   return context;
 }
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __SFI_GLUE_H__ */
 
